# THIS FILE WAS AUTOGENERATED BY make_vendor_list.py!
# pylint: disable=line-too-long,missing-docstring,too-many-lines
import datetime
from bios_pnp import pnp
VENDORS = {
    "BUT": pnp.Vendor(u"21ST CENTURY ENTERTAINMENT", "BUT", datetime.date(2002, 4, 25)),
    "TTL": pnp.Vendor(u"2-Tel B.V", "TTL", datetime.date(1999, 3, 20)),
    "TCM": pnp.Vendor(u"3Com Corporation", "TCM", datetime.date(1996, 11, 29)),
    "TDP": pnp.Vendor(u"3D Perception", "TDP", datetime.date(2002, 5, 16)),
    "VSD": pnp.Vendor(u"3M", "VSD", datetime.date(1998, 10, 16)),
    "NOD": pnp.Vendor(u"3NOD Digital Technology Co. Ltd.", "NOD", datetime.date(2014, 12, 11)),
    "NGS": pnp.Vendor(u"A D S Exports", "NGS", datetime.date(1998, 7, 16)),
    "API": pnp.Vendor(u"A Plus Info Corporation", "API", datetime.date(1996, 11, 29)),
    "ACG": pnp.Vendor(u"A&R Cambridge Ltd.", "ACG", datetime.date(2007, 6, 13)),
    "AVX": pnp.Vendor(u"A/Vaux Electronics", "AVX", datetime.date(2012, 8, 29)),
    "APV": pnp.Vendor(u"A+V Link", "APV", datetime.date(2010, 1, 27)),
    "TRU": pnp.Vendor(u"Aashima Technology B.V.", "TRU", datetime.date(1998, 5, 8)),
    "AAM": pnp.Vendor(u"Aava Mobile Oy", "AAM", datetime.date(2013, 8, 13)),
    "ABA": pnp.Vendor(u"ABBAHOME INC.", "ABA", datetime.date(1999, 11, 8)),
    "MEG": pnp.Vendor(u"Abeam Tech Ltd.", "MEG", datetime.date(1996, 11, 29)),
    "ATC": pnp.Vendor(u"Ably-Tech Corporation", "ATC", datetime.date(1996, 11, 29)),
    "ABC": pnp.Vendor(u"AboCom System Inc.", "ABC", datetime.date(1997, 3, 28)),
    "WTC": pnp.Vendor(u"ACC Microelectronics", "WTC", datetime.date(1996, 11, 29)),
    "AWC": pnp.Vendor(u"Access Works Comm Inc", "AWC", datetime.date(1996, 11, 29)),
    "PKA": pnp.Vendor(u"Acco UK Ltd.", "PKA", datetime.date(2003, 5, 12)),
    "ACC": pnp.Vendor(u"Accton Technology Corporation", "ACC", datetime.date(1996, 11, 29)),
    "ACU": pnp.Vendor(u"Acculogic", "ACU", datetime.date(1996, 11, 29)),
    "ASL": pnp.Vendor(u"AccuScene Corporation Ltd", "ASL", datetime.date(2007, 6, 13)),
    "ANT": pnp.Vendor(u"Ace CAD Enterprise Company Ltd", "ANT", datetime.date(1996, 11, 29)),
    "CHE": pnp.Vendor(u"Acer Inc", "CHE", datetime.date(1996, 11, 29)),
    "ALI": pnp.Vendor(u"Acer Labs", "ALI", datetime.date(1996, 11, 29)),
    "ANX": pnp.Vendor(u"Acer Netxus Inc", "ANX", datetime.date(1996, 11, 29)),
    "ACR": pnp.Vendor(u"Acer Technologies", "ACR", datetime.date(1996, 11, 29)),
    "ACK": pnp.Vendor(u"Acksys", "ACK", datetime.date(1996, 11, 29)),
    "ADC": pnp.Vendor(u"Acnhor Datacomm", "ADC", datetime.date(1996, 11, 29)),
    "CAL": pnp.Vendor(u"Acon", "CAL", datetime.date(1996, 11, 29)),
    "ALK": pnp.Vendor(u"Acrolink Inc", "ALK", datetime.date(1997, 3, 12)),
    "ACM": pnp.Vendor(u"Acroloop Motion Control Systems Inc", "ACM", datetime.date(1998, 3, 26)),
    "LAB": pnp.Vendor(u"ACT Labs Ltd", "LAB", datetime.date(1997, 9, 2)),
    "ACE": pnp.Vendor(u"Actek Engineering Pty Ltd", "ACE", datetime.date(1996, 11, 29)),
    "AEI": pnp.Vendor(u"Actiontec Electric Inc", "AEI", datetime.date(1996, 11, 29)),
    "ACV": pnp.Vendor(u"ActivCard S.A", "ACV", datetime.date(1998, 5, 8)),
    "ACB": pnp.Vendor(u"Aculab Ltd", "ACB", datetime.date(1996, 11, 29)),
    "ALM": pnp.Vendor(u"Acutec Ltd.", "ALM", datetime.date(1999, 11, 8)),
    "GLE": pnp.Vendor(u"AD electronics", "GLE", datetime.date(2000, 4, 19)),
    "ADM": pnp.Vendor(u"Ad Lib MultiMedia Inc", "ADM", datetime.date(1998, 4, 23)),
    "ADP": pnp.Vendor(u"Adaptec Inc", "ADP", datetime.date(1996, 11, 29)),
    "ADX": pnp.Vendor(u"Adax Inc", "ADX", datetime.date(1996, 11, 29)),
    "RSH": pnp.Vendor(u"ADC-Centre", "RSH", datetime.date(1999, 11, 8)),
    "AVE": pnp.Vendor(u"Add Value Enterpises (Asia) Pte Ltd", "AVE", datetime.date(1999, 1, 10)),
    "ADA": pnp.Vendor(u"Addi-Data GmbH", "ADA", datetime.date(1996, 11, 29)),
    "ADI": pnp.Vendor(u"ADI Systems Inc", "ADI", datetime.date(1996, 11, 29)),
    "DPM": pnp.Vendor(u"ADPM Synthesis sas", "DPM", datetime.date(2000, 8, 10)),
    "AXB": pnp.Vendor(u"Adrienne Electronics Corporation", "AXB", datetime.date(1997, 10, 7)),
    "ADT": pnp.Vendor(u"Adtek", "ADT", datetime.date(1996, 11, 29)),
    "ADK": pnp.Vendor(u"Adtek System Science Company Ltd", "ADK", datetime.date(1996, 11, 29)),
    "FLE": pnp.Vendor(u"ADTI Media, Inc", "FLE", datetime.date(2009, 9, 15)),
    "AND": pnp.Vendor(u"Adtran Inc", "AND", datetime.date(1996, 11, 29)),
    "AGM": pnp.Vendor(u"Advan Int'l Corporation", "AGM", datetime.date(1998, 5, 26)),
    "AVN": pnp.Vendor(u"Advance Computer Corporation", "AVN", datetime.date(2010, 6, 10)),
    "MSM": pnp.Vendor(u"Advanced Digital Systems", "MSM", datetime.date(1996, 11, 29)),
    "AED": pnp.Vendor(u"Advanced Electronic Designs, Inc.", "AED", datetime.date(2004, 7, 12)),
    "RJS": pnp.Vendor(u"Advanced Engineering", "RJS", datetime.date(1998, 6, 25)),
    "GRV": pnp.Vendor(u"Advanced Gravis", "GRV", datetime.date(1996, 11, 29)),
    "AIR": pnp.Vendor(u"Advanced Integ. Research Inc", "AIR", datetime.date(1996, 11, 29)),
    "ALR": pnp.Vendor(u"Advanced Logic", "ALR", datetime.date(1996, 11, 29)),
    "ADV": pnp.Vendor(u"Advanced Micro Devices Inc", "ADV", datetime.date(1996, 11, 29)),
    "EVE": pnp.Vendor(u"Advanced Micro Peripherals Ltd", "EVE", datetime.date(2011, 11, 18)),
    "AOE": pnp.Vendor(u"Advanced Optics Electronics, Inc.", "AOE", datetime.date(2004, 4, 20)),
    "ADD": pnp.Vendor(u"Advanced Peripheral Devices Inc", "ADD", datetime.date(1996, 11, 29)),
    "ABV": pnp.Vendor(u"Advanced Research Technology", "ABV", datetime.date(1997, 1, 16)),
    "PSA": pnp.Vendor(u"Advanced Signal Processing Technologies", "PSA", datetime.date(1999, 9, 13)),
    "AHC": pnp.Vendor(u"Advantech Co., Ltd.", "AHC", datetime.date(2007, 6, 13)),
    "ADH": pnp.Vendor(u"Aerodata Holdings Ltd", "ADH", datetime.date(1997, 11, 11)),
    "AEP": pnp.Vendor(u"Aetas Peripheral International", "AEP", datetime.date(1999, 11, 8)),
    "AET": pnp.Vendor(u"Aethra Telecomunicazioni S.r.l.", "AET", datetime.date(1996, 12, 13)),
    "CHS": pnp.Vendor(u"Agentur Chairos", "CHS", datetime.date(2001, 3, 15)),
    "AGT": pnp.Vendor(u"Agilent Technologies", "AGT", datetime.date(2001, 10, 8)),
    "ASI": pnp.Vendor(u"Ahead Systems", "ASI", datetime.date(1996, 11, 29)),
    "AIM": pnp.Vendor(u"AIMS Lab Inc", "AIM", datetime.date(1998, 3, 13)),
    "AYR": pnp.Vendor(u"Airlib, Inc", "AYR", datetime.date(2000, 2, 21)),
    "AWL": pnp.Vendor(u"Aironet Wireless Communications, Inc", "AWL", datetime.date(1998, 8, 11)),
    "AIW": pnp.Vendor(u"Aiwa Company Ltd", "AIW", datetime.date(1996, 11, 29)),
    "AJA": pnp.Vendor(u"AJA Video Systems, Inc.", "AJA", datetime.date(2007, 10, 11)),
    "AKE": pnp.Vendor(u"AKAMI Electric Co.,Ltd", "AKE", datetime.date(2010, 9, 3)),
    "AKB": pnp.Vendor(u"Akebia Ltd", "AKB", datetime.date(1996, 11, 29)),
    "AKI": pnp.Vendor(u"AKIA Corporation", "AKI", datetime.date(1998, 12, 23)),
    "ALH": pnp.Vendor(u"AL Systems", "ALH", datetime.date(1999, 1, 20)),
    "ALA": pnp.Vendor(u"Alacron Inc", "ALA", datetime.date(1996, 11, 29)),
    "ALN": pnp.Vendor(u"Alana Technologies", "ALN", datetime.date(2000, 1, 13)),
    "AOT": pnp.Vendor(u"Alcatel", "AOT", datetime.date(2001, 11, 6)),
    "ABE": pnp.Vendor(u"Alcatel Bell", "ABE", datetime.date(1996, 11, 29)),
    "ADB": pnp.Vendor(u"Aldebbaron", "ADB", datetime.date(2001, 3, 15)),
    "ALE": pnp.Vendor(u"Alenco BV", "ALE", datetime.date(2014, 5, 20)),
    "ALX": pnp.Vendor(u"ALEXON Co.,Ltd.", "ALX", datetime.date(1999, 9, 13)),
    "AFA": pnp.Vendor(u"Alfa Inc", "AFA", datetime.date(1996, 11, 29)),
    "ALO": pnp.Vendor(u"Algolith Inc.", "ALO", datetime.date(2005, 5, 2)),
    "AGO": pnp.Vendor(u"AlgolTek, Inc.", "AGO", datetime.date(2013, 10, 23)),
    "AIS": pnp.Vendor(u"Alien Internet Services", "AIS", datetime.date(2001, 6, 21)),
    "ABD": pnp.Vendor(u"Allen Bradley Company", "ABD", datetime.date(1996, 11, 29)),
    "ALL": pnp.Vendor(u"Alliance Semiconductor Corporation", "ALL", datetime.date(1996, 11, 29)),
    "ATI": pnp.Vendor(u"Allied Telesis KK", "ATI", datetime.date(1996, 11, 29)),
    "ATA": pnp.Vendor(u"Allied Telesyn International (Asia) Pte Ltd", "ATA", datetime.date(1997, 11, 10)),
    "ATK": pnp.Vendor(u"Allied Telesyn Int'l", "ATK", datetime.date(1996, 11, 29)),
    "ACO": pnp.Vendor(u"Allion Computer Inc.", "ACO", datetime.date(2000, 10, 23)),
    "XAD": pnp.Vendor(u"Alpha Data", "XAD", datetime.date(2009, 10, 8)),
    "ATD": pnp.Vendor(u"Alpha Telecom Inc", "ATD", datetime.date(1997, 9, 26)),
    "ATP": pnp.Vendor(u"Alpha-Top Corporation", "ATP", datetime.date(1996, 12, 4)),
    "ALV": pnp.Vendor(u"AlphaView LCD", "ALV", datetime.date(2008, 11, 1)),
    "APE": pnp.Vendor(u"Alpine Electronics, Inc.", "APE", datetime.date(2013, 1, 22)),
    "ALP": pnp.Vendor(u"Alps Electric Company Ltd", "ALP", datetime.date(1996, 11, 29)),
    "AUI": pnp.Vendor(u"Alps Electric Inc", "AUI", datetime.date(1996, 11, 29)),
    "ARC": pnp.Vendor(u"Alta Research Corporation", "ARC", datetime.date(1996, 11, 29)),
    "ALC": pnp.Vendor(u"Altec Corporation", "ALC", datetime.date(1998, 8, 4)),
    "ALJ": pnp.Vendor(u"Altec Lansing", "ALJ", datetime.date(2000, 1, 13)),
    "AIX": pnp.Vendor(u"ALTINEX, INC.", "AIX", datetime.date(2001, 4, 24)),
    "AIE": pnp.Vendor(u"Altmann Industrieelektronik", "AIE", datetime.date(1996, 11, 29)),
    "ACS": pnp.Vendor(u"Altos Computer Systems", "ACS", datetime.date(1996, 11, 29)),
    "AIL": pnp.Vendor(u"Altos India Ltd", "AIL", datetime.date(1996, 11, 29)),
    "CNC": pnp.Vendor(u"Alvedon Computers Ltd", "CNC", datetime.date(1998, 11, 6)),
    "AMB": pnp.Vendor(u"Ambient Technologies, Inc.", "AMB", datetime.date(1999, 5, 16)),
    "ALT": pnp.Vendor(u"Altra", "ALT", datetime.date(1996, 11, 29)),
    "AMD": pnp.Vendor(u"Amdek Corporation", "AMD", datetime.date(1996, 11, 29)),
    "AOL": pnp.Vendor(u"America OnLine", "AOL", datetime.date(1996, 11, 29)),
    "YOW": pnp.Vendor(u"American Biometric Company", "YOW", datetime.date(1999, 5, 16)),
    "AXP": pnp.Vendor(u"American Express", "AXP", datetime.date(1999, 7, 16)),
    "AXI": pnp.Vendor(u"American Magnetics", "AXI", datetime.date(2001, 3, 15)),
    "AMI": pnp.Vendor(u"American Megatrends Inc", "AMI", datetime.date(1996, 11, 29)),
    "MCA": pnp.Vendor(u"American Nuclear Systems Inc", "MCA", datetime.date(1997, 2, 12)),
    "CNB": pnp.Vendor(u"American Power Conversion", "CNB", datetime.date(2001, 3, 15)),
    "APC": pnp.Vendor(u"American Power Conversion", "APC", datetime.date(1996, 11, 29)),
    "AMN": pnp.Vendor(u"Amimon LTD.", "AMN", datetime.date(2007, 6, 13)),
    "AMO": pnp.Vendor(u"Amino Technologies PLC and Amino Communications Limited", "AMO", datetime.date(2011, 12, 9)),
    "AKL": pnp.Vendor(u"AMiT Ltd", "AKL", datetime.date(1997, 12, 2)),
    "AMP": pnp.Vendor(u"AMP Inc", "AMP", datetime.date(1996, 11, 29)),
    "AII": pnp.Vendor(u"Amptron International Inc.", "AII", datetime.date(2000, 5, 24)),
    "AMT": pnp.Vendor(u"AMT International Industry", "AMT", datetime.date(1996, 11, 29)),
    "AMR": pnp.Vendor(u"AmTRAN Technology Co., Ltd.", "AMR", datetime.date(2013, 6, 10)),
    "AMX": pnp.Vendor(u"AMX LLC", "AMX", datetime.date(2008, 7, 6)),
    "ANA": pnp.Vendor(u"Anakron", "ANA", datetime.date(1999, 11, 8)),
    "ADN": pnp.Vendor(u"Analog & Digital Devices Tel. Inc", "ADN", datetime.date(1997, 3, 14)),
    "ADS": pnp.Vendor(u"Analog Devices Inc", "ADS", datetime.date(1996, 11, 29)),
    "ANW": pnp.Vendor(u"Analog Way SAS", "ANW", datetime.date(2014, 1, 22)),
    "ANL": pnp.Vendor(u"Analogix Semiconductor, Inc", "ANL", datetime.date(2005, 10, 10)),
    "ABT": pnp.Vendor(u"Anchor Bay Technologies, Inc.", "ABT", datetime.date(2006, 2, 14)),
    "AAE": pnp.Vendor(u"Anatek Electronics Inc.", "AAE", datetime.date(2004, 5, 25)),
    "ACI": pnp.Vendor(u"Ancor Communications Inc", "ACI", datetime.date(1996, 11, 29)),
    "ANC": pnp.Vendor(u"Ancot", "ANC", datetime.date(1996, 11, 29)),
    "AML": pnp.Vendor(u"Anderson Multimedia Communications (HK) Limited", "AML", datetime.date(2003, 1, 3)),
    "ANP": pnp.Vendor(u"Andrew Network Production", "ANP", datetime.date(1996, 11, 29)),
    "ANI": pnp.Vendor(u"Anigma Inc", "ANI", datetime.date(1996, 11, 29)),
    "ANK": pnp.Vendor(u"Anko Electronic Company Ltd", "ANK", datetime.date(1998, 3, 24)),
    "AAT": pnp.Vendor(u"Ann Arbor Technologies", "AAT", datetime.date(2001, 4, 24)),
    "BBB": pnp.Vendor(u"an-najah university", "BBB", datetime.date(2001, 3, 15)),
    "ANO": pnp.Vendor(u"Anorad Corporation", "ANO", datetime.date(2000, 1, 13)),
    "ANR": pnp.Vendor(u"ANR Ltd", "ANR", datetime.date(1996, 11, 29)),
    "ANS": pnp.Vendor(u"Ansel Communication Company", "ANS", datetime.date(1996, 11, 29)),
    "AEC": pnp.Vendor(u"Antex Electronics Corporation", "AEC", datetime.date(1996, 11, 29)),
    "AOA": pnp.Vendor(u"AOpen Inc.", "AOA", datetime.date(2001, 11, 6)),
    "APX": pnp.Vendor(u"AP Designs Ltd", "APX", datetime.date(1997, 12, 8)),
    "DNG": pnp.Vendor(u"Apache Micro Peripherals Inc", "DNG", datetime.date(1997, 11, 11)),
    "APL": pnp.Vendor(u"Aplicom Oy", "APL", datetime.date(2005, 5, 2)),
    "APN": pnp.Vendor(u"Appian Tech Inc", "APN", datetime.date(1996, 11, 29)),
    "APP": pnp.Vendor(u"Apple Computer Inc", "APP", datetime.date(1996, 11, 29)),
    "APD": pnp.Vendor(u"AppliAdata", "APD", datetime.date(1996, 11, 29)),
    "ACT": pnp.Vendor(u"Applied Creative Technology", "ACT", datetime.date(1996, 11, 29)),
    "APM": pnp.Vendor(u"Applied Memory Tech", "APM", datetime.date(1996, 11, 29)),
    "ACL": pnp.Vendor(u"Apricot Computers", "ACL", datetime.date(1996, 11, 29)),
    "APR": pnp.Vendor(u"Aprilia s.p.a.", "APR", datetime.date(1999, 2, 22)),
    "ATJ": pnp.Vendor(u"ArchiTek Corporation", "ATJ", datetime.date(2014, 1, 22)),
    "ACH": pnp.Vendor(u"Archtek Telecom Corporation", "ACH", datetime.date(1997, 1, 15)),
    "ATL": pnp.Vendor(u"Arcus Technology Ltd", "ATL", datetime.date(1996, 11, 29)),
    "ARD": pnp.Vendor(u"AREC Inc.", "ARD", datetime.date(2013, 7, 8)),
    "ARS": pnp.Vendor(u"Arescom Inc", "ARS", datetime.date(1996, 11, 29)),
    "AGL": pnp.Vendor(u"Argolis", "AGL", datetime.date(2001, 3, 15)),
    "ARI": pnp.Vendor(u"Argosy Research Inc", "ARI", datetime.date(1997, 2, 24)),
    "ARG": pnp.Vendor(u"Argus Electronics Co., LTD", "ARG", datetime.date(2004, 6, 4)),
    "ACA": pnp.Vendor(u"Ariel Corporation", "ACA", datetime.date(1996, 12, 13)),
    "ARM": pnp.Vendor(u"Arima", "ARM", datetime.date(2004, 4, 7)),
    "ADE": pnp.Vendor(u"Arithmos, Inc.", "ADE", datetime.date(1999, 7, 16)),
    "ARK": pnp.Vendor(u"Ark Logic Inc", "ARK", datetime.date(1996, 11, 29)),
    "ARL": pnp.Vendor(u"Arlotto Comnet Inc", "ARL", datetime.date(1997, 4, 29)),
    "AMS": pnp.Vendor(u"ARMSTEL, Inc.", "AMS", datetime.date(2011, 2, 25)),
    "AIC": pnp.Vendor(u"Arnos Insturments & Computer Systems", "AIC", datetime.date(1996, 11, 29)),
    "ARR": pnp.Vendor(u"ARRIS Group, Inc.", "ARR", datetime.date(2015, 1, 27)),
    "IMB": pnp.Vendor(u"ART s.r.l.", "IMB", datetime.date(2012, 1, 27)),
    "AGI": pnp.Vendor(u"Artish Graphics Inc", "AGI", datetime.date(1996, 11, 29)),
    "NPA": pnp.Vendor(u"Arvanics", "NPA", datetime.date(2015, 3, 5)),
    "AKM": pnp.Vendor(u"Asahi Kasei Microsystems Company Ltd", "AKM", datetime.date(1996, 11, 29)),
    "ASN": pnp.Vendor(u"Asante Tech Inc", "ASN", datetime.date(1996, 11, 29)),
    "HER": pnp.Vendor(u"Ascom Business Systems", "HER", datetime.date(1999, 1, 20)),
    "ASC": pnp.Vendor(u"Ascom Strategic Technology Unit", "ASC", datetime.date(1996, 11, 29)),
    "ASM": pnp.Vendor(u"ASEM S.p.A.", "ASM", datetime.date(2001, 3, 15)),
    "AEM": pnp.Vendor(u"ASEM S.p.A.", "AEM", datetime.date(1996, 11, 29)),
    "ASE": pnp.Vendor(u"AseV Display Labs", "ASE", datetime.date(1998, 10, 16)),
    "ASH": pnp.Vendor(u"Ashton Bentley Concepts", "ASH", datetime.date(2013, 9, 20)),
    "AMA": pnp.Vendor(u"Asia Microelectronic Development Inc", "AMA", datetime.date(1997, 9, 24)),
    "ASK": pnp.Vendor(u"Ask A/S", "ASK", datetime.date(1996, 11, 29)),
    "DYN": pnp.Vendor(u"Askey Computer Corporation", "DYN", datetime.date(1997, 7, 22)),
    "ASP": pnp.Vendor(u"ASP Microelectronics Ltd", "ASP", datetime.date(1996, 11, 29)),
    "AKY": pnp.Vendor(u"Askey Computer Corporation", "AKY", datetime.date(1997, 4, 2)),
    "ACP": pnp.Vendor(u"Aspen Tech Inc", "ACP", datetime.date(1996, 11, 29)),
    "AST": pnp.Vendor(u"AST Research Inc", "AST", datetime.date(1996, 11, 29)),
    "JAC": pnp.Vendor(u"Astec Inc", "JAC", datetime.date(1996, 11, 29)),
    "ADL": pnp.Vendor(u"ASTRA Security Products Ltd", "ADL", datetime.date(1997, 7, 30)),
    "ATO": pnp.Vendor(u"ASTRO DESIGN, INC.", "ATO", datetime.date(2003, 6, 6)),
    "ASU": pnp.Vendor(u"Asuscom Network Inc", "ASU", datetime.date(1996, 11, 29)),
    "ATT": pnp.Vendor(u"AT&T", "ATT", datetime.date(1996, 11, 29)),
    "GIS": pnp.Vendor(u"AT&T Global Info Solutions", "GIS", datetime.date(1996, 11, 29)),
    "HSM": pnp.Vendor(u"AT&T Microelectronics", "HSM", datetime.date(1996, 11, 29)),
    "TME": pnp.Vendor(u"AT&T Microelectronics", "TME", datetime.date(1996, 11, 29)),
    "PDN": pnp.Vendor(u"AT&T Paradyne", "PDN", datetime.date(1996, 11, 29)),
    "AVJ": pnp.Vendor(u"Atelier Vision Corporation", "AVJ", datetime.date(2015, 2, 24)),
    "ATH": pnp.Vendor(u"Athena Informatica S.R.L.", "ATH", datetime.date(1997, 1, 29)),
    "ATN": pnp.Vendor(u"Athena Smartcard Solutions Ltd.", "ATN", datetime.date(1999, 9, 13)),
    "ATX": pnp.Vendor(u"Athenix Corporation", "ATX", datetime.date(1996, 11, 29)),
    "BUJ": pnp.Vendor(u"ATI Tech Inc", "BUJ", datetime.date(1996, 11, 29)),
    "CFG": pnp.Vendor(u"Atlantis", "CFG", datetime.date(1996, 11, 29)),
    "ATM": pnp.Vendor(u"ATM Ltd", "ATM", datetime.date(1996, 11, 29)),
    "AKP": pnp.Vendor(u"Atom Komplex Prylad", "AKP", datetime.date(2000, 10, 23)),
    "AMC": pnp.Vendor(u"Attachmate Corporation", "AMC", datetime.date(1996, 11, 29)),
    "FWA": pnp.Vendor(u"Attero Tech, LLC", "FWA", datetime.date(2010, 4, 20)),
    "APT": pnp.Vendor(u"Audio Processing Technology  Ltd", "APT", datetime.date(1997, 3, 18)),
    "ASX": pnp.Vendor(u"AudioScience", "ASX", datetime.date(1996, 11, 29)),
    "AUG": pnp.Vendor(u"August Home, Inc.", "AUG", datetime.date(2014, 6, 11)),
    "AVC": pnp.Vendor(u"Auravision Corporation", "AVC", datetime.date(1996, 11, 29)),
    "AUR": pnp.Vendor(u"Aureal Semiconductor", "AUR", datetime.date(1996, 11, 29)),
    "APS": pnp.Vendor(u"Autologic Inc", "APS", datetime.date(1996, 11, 29)),
    "CLT": pnp.Vendor(u"automated computer control systems", "CLT", datetime.date(1999, 9, 13)),
    "AUT": pnp.Vendor(u"Autotime Corporation", "AUT", datetime.date(2001, 10, 8)),
    "AUV": pnp.Vendor(u"Auvidea GmbH", "AUV", datetime.date(2014, 4, 21)),
    "AVL": pnp.Vendor(u"Avalue Technology Inc.", "AVL", datetime.date(2011, 11, 18)),
    "ALS": pnp.Vendor(u"Avance Logic Inc", "ALS", datetime.date(1996, 11, 29)),
    "AVA": pnp.Vendor(u"Avaya Communication", "AVA", datetime.date(2001, 3, 15)),
    "AEN": pnp.Vendor(u"Avencall", "AEN", datetime.date(2012, 1, 27)),
    "AVR": pnp.Vendor(u"AVer Information Inc.", "AVR", datetime.date(2010, 5, 7)),
    "AVD": pnp.Vendor(u"Avid Electronics Corporation", "AVD", datetime.date(1996, 11, 29)),
    "AVM": pnp.Vendor(u"AVM GmbH", "AVM", datetime.date(1996, 11, 29)),
    "AAA": pnp.Vendor(u"Avolites Ltd", "AAA", datetime.date(2012, 2, 17)),
    "AVO": pnp.Vendor(u"Avocent Corporation", "AVO", datetime.date(2000, 10, 23)),
    "AVT": pnp.Vendor(u"Avtek (Electronics) Pty Ltd", "AVT", datetime.date(1996, 11, 29)),
    "ACD": pnp.Vendor(u"AWETA BV", "ACD", datetime.date(1998, 1, 20)),
    "AXL": pnp.Vendor(u"Axel", "AXL", datetime.date(1996, 11, 29)),
    "AXC": pnp.Vendor(u"AXIOMTEK CO., LTD.", "AXC", datetime.date(2005, 5, 2)),
    "AXO": pnp.Vendor(u"Axonic Labs LLC", "AXO", datetime.date(2012, 6, 21)),
    "AXT": pnp.Vendor(u"Axtend Technologies Inc", "AXT", datetime.date(1997, 12, 1)),
    "AXX": pnp.Vendor(u"Axxon Computer Corporation", "AXX", datetime.date(1996, 11, 29)),
    "AXY": pnp.Vendor(u"AXYZ Automation Services, Inc", "AXY", datetime.date(1998, 8, 11)),
    "AYD": pnp.Vendor(u"Aydin Displays", "AYD", datetime.date(2007, 6, 13)),
    "AZM": pnp.Vendor(u"AZ Middelheim - Radiotherapy", "AZM", datetime.date(2003, 11, 14)),
    "AZT": pnp.Vendor(u"Aztech Systems Ltd", "AZT", datetime.date(1996, 11, 29)),
    "BBH": pnp.Vendor(u"B&Bh", "BBH", datetime.date(2003, 1, 17)),
    "SMR": pnp.Vendor(u"B.& V. s.r.l.", "SMR", datetime.date(1997, 3, 21)),
    "BFE": pnp.Vendor(u"B.F. Engineering Corporation", "BFE", datetime.date(1996, 11, 29)),
    "BUG": pnp.Vendor(u"B.U.G., Inc.", "BUG", datetime.date(2011, 8, 30)),
    "BNO": pnp.Vendor(u"Bang & Olufsen", "BNO", datetime.date(2003, 5, 16)),
    "BNK": pnp.Vendor(u"Banksia Tech Pty Ltd", "BNK", datetime.date(1996, 11, 29)),
    "BAN": pnp.Vendor(u"Banyan", "BAN", datetime.date(1996, 11, 29)),
    "BRC": pnp.Vendor(u"BARC", "BRC", datetime.date(2000, 8, 10)),
    "BDS": pnp.Vendor(u"Barco Display Systems", "BDS", datetime.date(1999, 9, 13)),
    "BCD": pnp.Vendor(u"Barco GmbH", "BCD", datetime.date(2011, 3, 7)),
    "BGB": pnp.Vendor(u"Barco Graphics N.V", "BGB", datetime.date(1996, 11, 29)),
    "BPS": pnp.Vendor(u"Barco, N.V.", "BPS", datetime.date(2000, 9, 12)),
    "DDS": pnp.Vendor(u"Barco, N.V.", "DDS", datetime.date(2000, 10, 23)),
    "BEO": pnp.Vendor(u"Baug & Olufsen", "BEO", datetime.date(1996, 11, 29)),
    "BCC": pnp.Vendor(u"Beaver Computer Corporaton", "BCC", datetime.date(1996, 11, 29)),
    "BEC": pnp.Vendor(u"Beckhoff Automation", "BEC", datetime.date(2002, 4, 25)),
    "BEI": pnp.Vendor(u"Beckworth Enterprises Inc", "BEI", datetime.date(1997, 7, 16)),
    "AGC": pnp.Vendor(u"Beijing Aerospace Golden Card Electronic Engineering Co.,Ltd.", "AGC", datetime.date(2001, 6, 21)),
    "AHS": pnp.Vendor(u"Beijing AnHeng SecoTech Information Technology Co., Ltd.", "AHS", datetime.date(2015, 3, 24)),
    "ANV": pnp.Vendor(u"Beijing ANTVR Technology Co., Ltd.", "ANV", datetime.date(2015, 8, 24)),
    "NRT": pnp.Vendor(u"Beijing Northern Radiantelecom Co.", "NRT", datetime.date(1999, 3, 20)),
    "BEK": pnp.Vendor(u"Beko Elektronik A.S.", "BEK", datetime.date(2005, 6, 15)),
    "BEL": pnp.Vendor(u"Beltronic Industrieelektronik GmbH", "BEL", datetime.date(2006, 9, 5)),
    "BMI": pnp.Vendor(u"Benson Medical Instruments Company", "BMI", datetime.date(1996, 12, 4)),
    "BUR": pnp.Vendor(u"Bernecker & Rainer Ind-Eletronik GmbH", "BUR", datetime.date(1996, 11, 29)),
    "INZ": pnp.Vendor(u"Best Buy", "INZ", datetime.date(2004, 6, 4)),
    "VPR": pnp.Vendor(u"Best Buy", "VPR", datetime.date(2002, 5, 16)),
    "BPU": pnp.Vendor(u"Best Power", "BPU", datetime.date(1996, 11, 29)),
    "BIA": pnp.Vendor(u"Biamp Systems Corporation", "BIA", datetime.date(2015, 5, 14)),
    "ICC": pnp.Vendor(u"BICC Data Networks Ltd", "ICC", datetime.date(1996, 11, 29)),
    "BIC": pnp.Vendor(u"Big Island Communications", "BIC", datetime.date(1997, 5, 13)),
    "BIL": pnp.Vendor(u"Billion Electric Company Ltd", "BIL", datetime.date(1996, 12, 11)),
    "BLN": pnp.Vendor(u"BioLink Technologies", "BLN", datetime.date(2000, 8, 10)),
    "BIO": pnp.Vendor(u"BioLink Technologies International, Inc.", "BIO", datetime.date(2000, 5, 24)),
    "BML": pnp.Vendor(u"BIOMED Lab", "BML", datetime.date(1997, 5, 22)),
    "BSL": pnp.Vendor(u"Biomedical Systems Laboratory", "BSL", datetime.date(1997, 10, 16)),
    "BMS": pnp.Vendor(u"BIOMEDISYS", "BMS", datetime.date(2000, 5, 24)),
    "BAC": pnp.Vendor(u"Biometric Access Corporation", "BAC", datetime.date(1998, 5, 19)),
    "BTO": pnp.Vendor(u"BioTao Ltd", "BTO", datetime.date(2012, 3, 21)),
    "BIT": pnp.Vendor(u"Bit 3 Computer", "BIT", datetime.date(1996, 11, 29)),
    "BTC": pnp.Vendor(u"Bit 3 Computer", "BTC", datetime.date(1996, 11, 29)),
    "BTF": pnp.Vendor(u"Bitfield Oy", "BTF", datetime.date(1996, 11, 29)),
    "BHZ": pnp.Vendor(u"BitHeadz, Inc.", "BHZ", datetime.date(2003, 9, 29)),
    "BWK": pnp.Vendor(u"Bitworks Inc.", "BWK", datetime.date(2003, 7, 10)),
    "BMD": pnp.Vendor(u"Blackmagic Design", "BMD", datetime.date(2012, 9, 13)),
    "BDR": pnp.Vendor(u"Blonder Tongue Labs, Inc.", "BDR", datetime.date(2008, 9, 16)),
    "BLP": pnp.Vendor(u"Bloomberg L.P.", "BLP", datetime.date(2008, 9, 16)),
    "ZZZ": pnp.Vendor(u"Boca Research Inc", "ZZZ", datetime.date(1997, 2, 13)),
    "BRI": pnp.Vendor(u"Boca Research Inc", "BRI", datetime.date(1996, 11, 29)),
    "BST": pnp.Vendor(u"BodySound Technologies, Inc.", "BST", datetime.date(2008, 3, 12)),
    "BII": pnp.Vendor(u"Boeckeler Instruments Inc", "BII", datetime.date(1996, 10, 17)),
    "BCS": pnp.Vendor(u"Booria CAD/CAM systems", "BCS", datetime.date(2005, 5, 11)),
    "BOS": pnp.Vendor(u"BOS", "BOS", datetime.date(1997, 7, 3)),
    "BSE": pnp.Vendor(u"Bose Corporation", "BSE", datetime.date(2006, 9, 5)),
    "BNS": pnp.Vendor(u"Boulder Nonlinear Systems", "BNS", datetime.date(2008, 3, 12)),
    "BRA": pnp.Vendor(u"Braemac Pty Ltd", "BRA", datetime.date(2010, 11, 18)),
    "BRM": pnp.Vendor(u"Braemar Inc", "BRM", datetime.date(1997, 10, 7)),
    "BDO": pnp.Vendor(u"Brahler ICS", "BDO", datetime.date(1998, 6, 4)),
    "BBL": pnp.Vendor(u"Brain Boxes Limited", "BBL", datetime.date(2001, 10, 2)),
    "BRG": pnp.Vendor(u"Bridge Information Co., Ltd", "BRG", datetime.date(1998, 8, 11)),
    "BSN": pnp.Vendor(u"BRIGHTSIGN, LLC", "BSN", datetime.date(2012, 2, 28)),
    "BTE": pnp.Vendor(u"Brilliant Technology", "BTE", datetime.date(1996, 11, 29)),
    "BCI": pnp.Vendor(u"Broadata Communications Inc.", "BCI", datetime.date(2013, 11, 19)),
    "BCM": pnp.Vendor(u"Broadcom", "BCM", datetime.date(2004, 4, 1)),
    "BRO": pnp.Vendor(u"BROTHER INDUSTRIES,LTD.", "BRO", datetime.date(2000, 2, 21)),
    "NFC": pnp.Vendor(u"BTC Korea Co., Ltd", "NFC", datetime.date(2002, 2, 25)),
    "BGT": pnp.Vendor(u"Budzetron Inc", "BGT", datetime.date(1996, 11, 29)),
    "BUL": pnp.Vendor(u"Bull", "BUL", datetime.date(1998, 2, 3)),
    "BNE": pnp.Vendor(u"Bull AB", "BNE", datetime.date(1998, 10, 6)),
    "BLI": pnp.Vendor(u"Busicom", "BLI", datetime.date(1998, 8, 11)),
    "BTI": pnp.Vendor(u"BusTech Inc", "BTI", datetime.date(1996, 11, 29)),
    "BUS": pnp.Vendor(u"BusTek", "BUS", datetime.date(1996, 11, 29)),
    "FLY": pnp.Vendor(u"Butterfly Communications", "FLY", datetime.date(1997, 5, 5)),
    "BXE": pnp.Vendor(u"Buxco Electronics", "BXE", datetime.date(1996, 11, 29)),
    "BYD": pnp.Vendor(u"byd:sign corporation", "BYD", datetime.date(2008, 4, 10)),
    "XMM": pnp.Vendor(u"C3PO S.L.", "XMM", datetime.date(1998, 3, 3)),
    "CAC": pnp.Vendor(u"CA & F Elettronica", "CAC", datetime.date(1999, 5, 16)),
    "CBT": pnp.Vendor(u"Cabletime Ltd", "CBT", datetime.date(2010, 5, 4)),
    "CSI": pnp.Vendor(u"Cabletron System Inc", "CSI", datetime.date(1996, 11, 29)),
    "CCI": pnp.Vendor(u"Cache", "CCI", datetime.date(1996, 11, 29)),
    "CAG": pnp.Vendor(u"CalComp", "CAG", datetime.date(1996, 11, 29)),
    "CDP": pnp.Vendor(u"CalComp", "CDP", datetime.date(1996, 11, 29)),
    "CUK": pnp.Vendor(u"Calibre UK Ltd", "CUK", datetime.date(2005, 9, 15)),
    "CSO": pnp.Vendor(u"California Institute of Technology", "CSO", datetime.date(1999, 3, 20)),
    "CAM": pnp.Vendor(u"Cambridge Audio", "CAM", datetime.date(2008, 8, 9)),
    "CED": pnp.Vendor(u"Cambridge Electronic Design Ltd", "CED", datetime.date(1996, 11, 29)),
    "CMR": pnp.Vendor(u"Cambridge Research Systems Ltd", "CMR", datetime.date(2002, 4, 25)),
    "CNN": pnp.Vendor(u"Canon Inc", "CNN", datetime.date(1996, 11, 29)),
    "CAI": pnp.Vendor(u"Canon Inc.", "CAI", datetime.date(2001, 11, 6)),
    "UBU": pnp.Vendor(u"Canonical Ltd.", "UBU", datetime.date(2013, 5, 24)),
    "CAN": pnp.Vendor(u"Canopus Company Ltd", "CAN", datetime.date(1996, 11, 29)),
    "CPM": pnp.Vendor(u"Capella Microsystems Inc.", "CPM", datetime.date(2012, 5, 9)),
    "CCP": pnp.Vendor(u"Capetronic USA Inc", "CCP", datetime.date(1996, 11, 29)),
    "DJE": pnp.Vendor(u"Capstone Visua lProduct Development", "DJE", datetime.date(2008, 10, 9)),
    "CAR": pnp.Vendor(u"Cardinal Company Ltd", "CAR", datetime.date(1996, 11, 29)),
    "CRD": pnp.Vendor(u"Cardinal Technical Inc", "CRD", datetime.date(1996, 11, 29)),
    "CLX": pnp.Vendor(u"CardLogix", "CLX", datetime.date(2001, 3, 15)),
    "CKJ": pnp.Vendor(u"Carina System Co., Ltd.", "CKJ", datetime.date(2010, 9, 3)),
    "CZE": pnp.Vendor(u"Carl Zeiss AG", "CZE", datetime.date(2009, 6, 3)),
    "CAS": pnp.Vendor(u"CASIO COMPUTER CO.,LTD", "CAS", datetime.date(1998, 10, 6)),
    "CAA": pnp.Vendor(u"Castles Automation Co., Ltd", "CAA", datetime.date(2000, 1, 13)),
    "CAV": pnp.Vendor(u"Cavium Networks, Inc", "CAV", datetime.date(2011, 2, 2)),
    "FVX": pnp.Vendor(u"C-C-C Group Plc", "FVX", datetime.date(1998, 5, 4)),
    "CCL": pnp.Vendor(u"CCL/ITRI", "CCL", datetime.date(1997, 3, 31)),
    "CCC": pnp.Vendor(u"C-Cube Microsystems", "CCC", datetime.date(1996, 11, 29)),
    "CEP": pnp.Vendor(u"C-DAC", "CEP", datetime.date(1996, 11, 29)),
    "CBR": pnp.Vendor(u"Cebra Tech A/S", "CBR", datetime.date(1996, 11, 29)),
    "CEF": pnp.Vendor(u"Cefar Digital Vision", "CEF", datetime.date(1997, 2, 19)),
    "CEN": pnp.Vendor(u"Centurion Technologies P/L", "CEN", datetime.date(2000, 10, 23)),
    "TCE": pnp.Vendor(u"Century Corporation", "TCE", datetime.date(1996, 11, 29)),
    "CRV": pnp.Vendor(u"Cerevo Inc.", "CRV", datetime.date(2010, 7, 13)),
    "CER": pnp.Vendor(u"Ceronix", "CER", datetime.date(2008, 9, 2)),
    "TOM": pnp.Vendor(u"Ceton Corporation", "TOM", datetime.date(2014, 5, 8)),
    "CHP": pnp.Vendor(u"CH Products", "CHP", datetime.date(1997, 4, 24)),
    "CHD": pnp.Vendor(u"ChangHong Electric Co.,Ltd", "CHD", datetime.date(2001, 11, 30)),
    "CHA": pnp.Vendor(u"Chase Research PLC", "CHA", datetime.date(1996, 11, 29)),
    "CHY": pnp.Vendor(u"Cherry GmbH", "CHY", datetime.date(1999, 5, 16)),
    "CMO": pnp.Vendor(u"Chi Mei Optoelectronics corp.", "CMO", datetime.date(2001, 3, 15)),
    "CHM": pnp.Vendor(u"CHIC TECHNOLOGY CORP.", "CHM", datetime.date(1999, 7, 16)),
    "CEC": pnp.Vendor(u"Chicony Electronics Company Ltd", "CEC", datetime.date(1996, 11, 29)),
    "CMN": pnp.Vendor(u"Chimei Innolux Corporation", "CMN", datetime.date(2010, 9, 2)),
    "HLG": pnp.Vendor(u"China Hualu Group Co., Ltd.", "HLG", datetime.date(2013, 5, 13)),
    "CHL": pnp.Vendor(u"Chloride-R&D", "CHL", datetime.date(1996, 11, 29)),
    "CDG": pnp.Vendor(u"Christie Digital Systems Inc", "CDG", datetime.date(2001, 4, 24)),
    "CVP": pnp.Vendor(u"Chromatec Video Products Ltd", "CVP", datetime.date(2013, 8, 9)),
    "CHI": pnp.Vendor(u"Chrontel Inc", "CHI", datetime.date(1996, 11, 29)),
    "CHT": pnp.Vendor(u"Chunghwa Picture Tubes,LTD.", "CHT", datetime.date(2001, 3, 15)),
    "CTE": pnp.Vendor(u"Chunghwa Telecom Co., Ltd.", "CTE", datetime.date(2002, 5, 16)),
    "KCD": pnp.Vendor(u"Chunichi Denshi Co.,LTD.", "KCD", datetime.date(2010, 12, 23)),
    "QQQ": pnp.Vendor(u"Chuomusen Co., Ltd.", "QQQ", datetime.date(2002, 8, 7)),
    "CGS": pnp.Vendor(u"Chyron Corp", "CGS", datetime.date(2008, 11, 13)),
    "CNE": pnp.Vendor(u"Cine-tal", "CNE", datetime.date(2007, 6, 13)),
    "PTG": pnp.Vendor(u"Cipher Systems Inc", "PTG", datetime.date(1996, 11, 29)),
    "CIP": pnp.Vendor(u"Ciprico Inc", "CIP", datetime.date(1996, 11, 29)),
    "CPC": pnp.Vendor(u"Ciprico Inc", "CPC", datetime.date(1996, 11, 29)),
    "FPX": pnp.Vendor(u"Cirel Systemes", "FPX", datetime.date(1996, 11, 29)),
    "CRQ": pnp.Vendor(u"Cirque Corporation", "CRQ", datetime.date(1996, 11, 29)),
    "CIR": pnp.Vendor(u"Cirrus Logic Inc", "CIR", datetime.date(1996, 11, 29)),
    "CLI": pnp.Vendor(u"Cirrus Logic Inc", "CLI", datetime.date(1996, 11, 29)),
    "SNS": pnp.Vendor(u"Cirtech (UK) Ltd", "SNS", datetime.date(1997, 8, 20)),
    "WSC": pnp.Vendor(u"CIS Technology Inc", "WSC", datetime.date(1996, 11, 29)),
    "CIS": pnp.Vendor(u"Cisco Systems Inc", "CIS", datetime.date(1996, 11, 29)),
    "CIL": pnp.Vendor(u"Citicom Infotech Private Limited", "CIL", datetime.date(2000, 8, 10)),
    "CIT": pnp.Vendor(u"Citifax Limited", "CIT", datetime.date(1997, 7, 16)),
    "CIN": pnp.Vendor(u"Citron GmbH", "CIN", datetime.date(2005, 7, 28)),
    "CLA": pnp.Vendor(u"Clarion Company Ltd", "CLA", datetime.date(1996, 11, 29)),
    "CVS": pnp.Vendor(u"Clarity Visual Systems", "CVS", datetime.date(2000, 1, 13)),
    "CLE": pnp.Vendor(u"Classe Audio", "CLE", datetime.date(2006, 2, 16)),
    "CLV": pnp.Vendor(u"Clevo Company", "CLV", datetime.date(1998, 1, 30)),
    "PPM": pnp.Vendor(u"Clinton Electronics Corp.", "PPM", datetime.date(2003, 10, 1)),
    "CLO": pnp.Vendor(u"Clone Computers", "CLO", datetime.date(1996, 11, 29)),
    "CSL": pnp.Vendor(u"Cloudium Systems Ltd.", "CSL", datetime.date(2013, 2, 14)),
    "CMC": pnp.Vendor(u"CMC Ltd", "CMC", datetime.date(1996, 11, 29)),
    "CMI": pnp.Vendor(u"C-Media Electronics", "CMI", datetime.date(1996, 11, 29)),
    "JQE": pnp.Vendor(u"CNet Technical Inc", "JQE", datetime.date(1996, 11, 29)),
    "COB": pnp.Vendor(u"COBY Electronics Co., Ltd", "COB", datetime.date(2007, 6, 13)),
    "COD": pnp.Vendor(u"CODAN Pty. Ltd.", "COD", datetime.date(2000, 10, 23)),
    "COI": pnp.Vendor(u"Codec Inc.", "COI", datetime.date(2001, 11, 30)),
    "CDN": pnp.Vendor(u"Codenoll Technical Corporation", "CDN", datetime.date(1996, 11, 29)),
    "CNT": pnp.Vendor(u"COINT Multimedia Systems", "CNT", datetime.date(1999, 3, 20)),
    "CDE": pnp.Vendor(u"Colin.de", "CDE", datetime.date(2005, 1, 18)),
    "CMD": pnp.Vendor(u"Colorado MicroDisplay, Inc.", "CMD", datetime.date(1999, 3, 20)),
    "CVI": pnp.Vendor(u"Colorado Video, Inc.", "CVI", datetime.date(2012, 8, 15)),
    "MVX": pnp.Vendor(u"COM 1", "MVX", datetime.date(1996, 11, 29)),
    "CMX": pnp.Vendor(u"Comex Electronics AB", "CMX", datetime.date(2004, 5, 28)),
    "CIC": pnp.Vendor(u"Comm. Intelligence Corporation", "CIC", datetime.date(1996, 11, 29)),
    "CLD": pnp.Vendor(u"COMMAT L.t.d.", "CLD", datetime.date(2000, 8, 10)),
    "SDH": pnp.Vendor(u"Communications Specialies, Inc.", "SDH", datetime.date(2005, 9, 6)),
    "INX": pnp.Vendor(u"Communications Supply Corporation (A division of WESCO)", "INX", datetime.date(2012, 11, 7)),
    "CPL": pnp.Vendor(u"Compal Electronics Inc", "CPL", datetime.date(1996, 11, 29)),
    "CPQ": pnp.Vendor(u"Compaq Computer Company", "CPQ", datetime.date(1996, 11, 29)),
    "CPP": pnp.Vendor(u"Compound Photonics", "CPP", datetime.date(2013, 10, 1)),
    "CPD": pnp.Vendor(u"CompuAdd", "CPD", datetime.date(1996, 11, 29)),
    "CMS": pnp.Vendor(u"CompuMaster Srl", "CMS", datetime.date(1999, 2, 22)),
    "CDS": pnp.Vendor(u"Computer Diagnostic Systems", "CDS", datetime.date(2001, 3, 15)),
    "CPI": pnp.Vendor(u"Computer Peripherals Inc", "CPI", datetime.date(1996, 11, 29)),
    "CTP": pnp.Vendor(u"Computer Technology Corporation", "CTP", datetime.date(1998, 3, 26)),
    "CBI": pnp.Vendor(u"ComputerBoards Inc", "CBI", datetime.date(1998, 2, 3)),
    "CTM": pnp.Vendor(u"Computerm Corporation", "CTM", datetime.date(1996, 11, 29)),
    "CTN": pnp.Vendor(u"Computone Products", "CTN", datetime.date(1996, 11, 29)),
    "COX": pnp.Vendor(u"Comrex", "COX", datetime.date(2011, 10, 18)),
    "CTS": pnp.Vendor(u"Comtec Systems Co., Ltd.", "CTS", datetime.date(2002, 4, 25)),
    "CMM": pnp.Vendor(u"Comtime GmbH", "CMM", datetime.date(2002, 9, 23)),
    "COM": pnp.Vendor(u"Comtrol Corporation", "COM", datetime.date(1996, 11, 29)),
    "CDI": pnp.Vendor(u"Concept Development Inc", "CDI", datetime.date(1996, 11, 29)),
    "CSE": pnp.Vendor(u"Concept Solutions & Engineering", "CSE", datetime.date(1996, 12, 11)),
    "DCI": pnp.Vendor(u"Concepts Inc", "DCI", datetime.date(1996, 11, 29)),
    "CXT": pnp.Vendor(u"Conexant Systems", "CXT", datetime.date(1999, 1, 20)),
    "CGT": pnp.Vendor(u"congatec AG", "CGT", datetime.date(2011, 6, 16)),
    "CNI": pnp.Vendor(u"Connect Int'l A/S", "CNI", datetime.date(1996, 11, 29)),
    "CWR": pnp.Vendor(u"Connectware Inc", "CWR", datetime.date(1996, 11, 29)),
    "CRC": pnp.Vendor(u"CONRAC GmbH", "CRC", datetime.date(2004, 4, 20)),
    "CAT": pnp.Vendor(u"Consultancy in Advanced Technology", "CAT", datetime.date(1997, 9, 19)),
    "CEA": pnp.Vendor(u"Consumer Electronics Association", "CEA", datetime.date(2006, 9, 5)),
    "CCJ": pnp.Vendor(u"CONTEC CO.,LTD.", "CCJ", datetime.date(2000, 8, 10)),
    "CON": pnp.Vendor(u"Contec Company Ltd", "CON", datetime.date(1996, 11, 29)),
    "CRH": pnp.Vendor(u"Contemporary Research Corp.", "CRH", datetime.date(2015, 2, 24)),
    "CTR": pnp.Vendor(u"Control4 Corporation", "CTR", datetime.date(2014, 5, 28)),
    "CDD": pnp.Vendor(u"Convergent Data Devices", "CDD", datetime.date(2004, 2, 27)),
    "CDV": pnp.Vendor(u"Convergent Design Inc.", "CDV", datetime.date(2006, 9, 5)),
    "CDC": pnp.Vendor(u"Core Dynamics Corporation", "CDC", datetime.date(1996, 11, 29)),
    "ART": pnp.Vendor(u"Corion Industrial Corporation", "ART", datetime.date(1996, 11, 29)),
    "COT": pnp.Vendor(u"Core Technology Inc", "COT", datetime.date(2000, 4, 19)),
    "CLG": pnp.Vendor(u"CoreLogic", "CLG", datetime.date(1998, 11, 27)),
    "CRN": pnp.Vendor(u"Cornerstone Imaging", "CRN", datetime.date(1996, 11, 29)),
    "COR": pnp.Vendor(u"Corollary Inc", "COR", datetime.date(1996, 12, 13)),
    "CSM": pnp.Vendor(u"Cosmic Engineering Inc.", "CSM", datetime.date(2012, 4, 18)),
    "COS": pnp.Vendor(u"CoStar Corporation", "COS", datetime.date(1996, 11, 29)),
    "CTA": pnp.Vendor(u"CoSystems Inc", "CTA", datetime.date(1998, 10, 24)),
    "CVA": pnp.Vendor(u"Covia Inc.", "CVA", datetime.date(2010, 5, 11)),
    "CPT": pnp.Vendor(u"cPATH", "CPT", datetime.date(1998, 3, 9)),
    "CRA": pnp.Vendor(u"CRALTECH ELECTRONICA, S.L.", "CRA", datetime.date(2015, 3, 24)),
    "CDK": pnp.Vendor(u"Cray Communications", "CDK", datetime.date(1996, 11, 29)),
    "IOA": pnp.Vendor(u"CRE Technology Corporation", "IOA", datetime.date(1997, 6, 30)),
    "CRE": pnp.Vendor(u"Creative Labs Inc", "CRE", datetime.date(1996, 11, 29)),
    "CRL": pnp.Vendor(u"Creative Logic", "CRL", datetime.date(1997, 10, 16)),
    "CTL": pnp.Vendor(u"Creative Technology Ltd", "CTL", datetime.date(1996, 11, 29)),
    "CTX": pnp.Vendor(u"Creatix Polymedia GmbH", "CTX", datetime.date(1996, 11, 29)),
    "CRS": pnp.Vendor(u"Crescendo Communication Inc", "CRS", datetime.date(1996, 11, 29)),
    "CSD": pnp.Vendor(u"Cresta Systems Inc", "CSD", datetime.date(1997, 8, 1)),
    "CEI": pnp.Vendor(u"Crestron Electronics, Inc.", "CEI", datetime.date(2006, 5, 8)),
    "CRI": pnp.Vendor(u"Crio Inc.", "CRI", datetime.date(1999, 9, 13)),
    "CII": pnp.Vendor(u"Cromack Industries Inc", "CII", datetime.date(1997, 1, 22)),
    "XTL": pnp.Vendor(u"Crystal Computer", "XTL", datetime.date(1996, 11, 29)),
    "CSC": pnp.Vendor(u"Crystal Semiconductor", "CSC", datetime.date(1996, 11, 29)),
    "CLM": pnp.Vendor(u"CrystaLake Multimedia", "CLM", datetime.date(1996, 11, 29)),
    "CSS": pnp.Vendor(u"CSS Laboratories", "CSS", datetime.date(1997, 1, 2)),
    "CST": pnp.Vendor(u"CSTI Inc", "CST", datetime.date(1996, 11, 29)),
    "CTC": pnp.Vendor(u"CTC Communication Development Company Ltd", "CTC", datetime.date(1997, 10, 21)),
    "CUB": pnp.Vendor(u"Cubix Corporation", "CUB", datetime.date(1996, 11, 29)),
    "CWC": pnp.Vendor(u"Curtiss-Wright Controls, Inc.", "CWC", datetime.date(2013, 4, 5)),
    "CYL": pnp.Vendor(u"Cyberlabs", "CYL", datetime.date(1998, 4, 14)),
    "CYB": pnp.Vendor(u"CyberVision", "CYB", datetime.date(1997, 5, 13)),
    "CYW": pnp.Vendor(u"Cyberware", "CYW", datetime.date(2000, 2, 21)),
    "CBX": pnp.Vendor(u"Cybex Computer Products Corporation", "CBX", datetime.date(1999, 11, 8)),
    "CYD": pnp.Vendor(u"Cyclades Corporation", "CYD", datetime.date(2001, 5, 7)),
    "CYC": pnp.Vendor(u"Cylink Corporation", "CYC", datetime.date(1996, 11, 29)),
    "CYX": pnp.Vendor(u"Cyrix Corporation", "CYX", datetime.date(1997, 10, 21)),
    "CRX": pnp.Vendor(u"Cyrix Corporation", "CRX", datetime.date(1997, 3, 21)),
    "CYT": pnp.Vendor(u"Cytechinfo Inc", "CYT", datetime.date(1998, 3, 13)),
    "CYV": pnp.Vendor(u"Cyviz AS", "CYV", datetime.date(2002, 4, 25)),
    "DMP": pnp.Vendor(u"D&M Holdings Inc, Professional Business Company", "DMP", datetime.date(2006, 9, 5)),
    "OPI": pnp.Vendor(u"D.N.S. Corporation", "OPI", datetime.date(1996, 11, 29)),
    "DDA": pnp.Vendor(u"DA2 Technologies Corporation", "DDA", datetime.date(2006, 3, 13)),
    "DAW": pnp.Vendor(u"DA2 Technologies Inc", "DAW", datetime.date(2005, 9, 6)),
    "DWE": pnp.Vendor(u"Daewoo Electronics Company Ltd", "DWE", datetime.date(1996, 11, 29)),
    "TLT": pnp.Vendor(u"Dai Telecom S.p.A.", "TLT", datetime.date(2003, 6, 4)),
    "DIN": pnp.Vendor(u"Daintelecom Co., Ltd", "DIN", datetime.date(1999, 11, 8)),
    "DAI": pnp.Vendor(u"DAIS SET Ltd.", "DAI", datetime.date(2000, 2, 21)),
    "DAK": pnp.Vendor(u"Daktronics", "DAK", datetime.date(2004, 6, 23)),
    "DCC": pnp.Vendor(u"Dale Computer Corporation", "DCC", datetime.date(1996, 11, 29)),
    "DCT": pnp.Vendor(u"Dancall Telecom A/S", "DCT", datetime.date(1997, 8, 12)),
    "DAN": pnp.Vendor(u"Danelec Marine A/S", "DAN", datetime.date(2009, 12, 24)),
    "DDD": pnp.Vendor(u"Danka Data Devices", "DDD", datetime.date(1996, 11, 29)),
    "DAU": pnp.Vendor(u"Daou Tech Inc", "DAU", datetime.date(1996, 11, 29)),
    "HCA": pnp.Vendor(u"DAT", "HCA", datetime.date(2001, 3, 15)),
    "DAX": pnp.Vendor(u"Data Apex Ltd", "DAX", datetime.date(1996, 11, 29)),
    "DDI": pnp.Vendor(u"Data Display AG", "DDI", datetime.date(2002, 7, 17)),
    "DXP": pnp.Vendor(u"Data Expert Corporation", "DXP", datetime.date(1996, 11, 29)),
    "EXP": pnp.Vendor(u"Data Export Corporation", "EXP", datetime.date(1996, 11, 29)),
    "DMO": pnp.Vendor(u"Data Modul AG", "DMO", datetime.date(2013, 12, 3)),
    "EBH": pnp.Vendor(u"Data Price Informatica", "EBH", datetime.date(2001, 5, 24)),
    "DRI": pnp.Vendor(u"Data Race Inc", "DRI", datetime.date(1997, 7, 30)),
    "DRC": pnp.Vendor(u"Data Ray Corp.", "DRC", datetime.date(2001, 11, 30)),
    "DTX": pnp.Vendor(u"Data Translation", "DTX", datetime.date(1996, 11, 29)),
    "DVT": pnp.Vendor(u"Data Video", "DVT", datetime.date(2007, 2, 13)),
    "DBK": pnp.Vendor(u"Databook Inc", "DBK", datetime.date(1996, 11, 29)),
    "DCD": pnp.Vendor(u"Datacast LLC", "DCD", datetime.date(1997, 12, 2)),
    "TRN": pnp.Vendor(u"Datacommunicatie Tron B.V.", "TRN", datetime.date(1996, 11, 29)),
    "DQB": pnp.Vendor(u"Datacube Inc", "DQB", datetime.date(1996, 11, 29)),
    "DDT": pnp.Vendor(u"Datadesk Technologies Inc", "DDT", datetime.date(1998, 11, 27)),
    "DKY": pnp.Vendor(u"Datakey Inc", "DKY", datetime.date(1998, 4, 6)),
    "LJX": pnp.Vendor(u"Datalogic Corporation", "LJX", datetime.date(1996, 11, 29)),
    "DTN": pnp.Vendor(u"Datang  Telephone Co", "DTN", datetime.date(1998, 9, 23)),
    "DII": pnp.Vendor(u"Dataq Instruments Inc", "DII", datetime.date(1996, 11, 29)),
    "DDE": pnp.Vendor(u"Datasat Digital Entertainment", "DDE", datetime.date(2011, 11, 18)),
    "DCV": pnp.Vendor(u"Datatronics Technology Inc", "DCV", datetime.date(1997, 1, 2)),
    "DAT": pnp.Vendor(u"Datel Inc", "DAT", datetime.date(1996, 11, 29)),
    "MSD": pnp.Vendor(u"Datenerfassungs- und Informationssysteme", "MSD", datetime.date(1998, 3, 16)),
    "DAV": pnp.Vendor(u"Davicom Semiconductor Inc", "DAV", datetime.date(1997, 1, 15)),
    "DAS": pnp.Vendor(u"DAVIS AS", "DAS", datetime.date(1998, 2, 3)),
    "DBN": pnp.Vendor(u"DB Networks Inc", "DBN", datetime.date(1997, 12, 1)),
    "HWC": pnp.Vendor(u"DBA Hans Wedemeyer", "HWC", datetime.date(1999, 3, 20)),
    "DCM": pnp.Vendor(u"DCM Data Products", "DCM", datetime.date(1996, 11, 29)),
    "DGT": pnp.Vendor(u"Dearborn Group Technology", "DGT", datetime.date(1997, 11, 11)),
    "DXD": pnp.Vendor(u"DECIMATOR DESIGN PTY LTD", "DXD", datetime.date(2012, 3, 6)),
    "DCR": pnp.Vendor(u"Decros Ltd", "DCR", datetime.date(1996, 11, 29)),
    "MLD": pnp.Vendor(u"Deep Video Imaging Ltd", "MLD", datetime.date(2003, 8, 14)),
    "DFT": pnp.Vendor(u"DEI Holdings dba Definitive Technology", "DFT", datetime.date(2011, 12, 9)),
    "DEI": pnp.Vendor(u"Deico Electronics", "DEI", datetime.date(1996, 11, 29)),
    "DLL": pnp.Vendor(u"Dell Inc", "DLL", datetime.date(2009, 3, 27)),
    "DEL": pnp.Vendor(u"Dell Inc.", "DEL", datetime.date(2009, 12, 9)),
    "DPH": pnp.Vendor(u"Delphi Automotive LLP", "DPH", datetime.date(2013, 10, 15)),
    "DPC": pnp.Vendor(u"Delta Electronics Inc", "DPC", datetime.date(1996, 11, 29)),
    "DDV": pnp.Vendor(u"Delta Information Systems, Inc", "DDV", datetime.date(2012, 1, 3)),
    "DTA": pnp.Vendor(u"DELTATEC", "DTA", datetime.date(2009, 3, 13)),
    "FPS": pnp.Vendor(u"Deltec Corporation", "FPS", datetime.date(1996, 11, 29)),
    "DON": pnp.Vendor(u"DENON, Ltd.", "DON", datetime.date(2004, 4, 1)),
    "DHD": pnp.Vendor(u"Dension Audio Systems", "DHD", datetime.date(2013, 3, 4)),
    "DEN": pnp.Vendor(u"Densitron Computers Ltd", "DEN", datetime.date(1999, 9, 13)),
    "DTT": pnp.Vendor(u"Design & Test Technology, Inc.", "DTT", datetime.date(2010, 9, 30)),
    "LPI": pnp.Vendor(u"Design Technology", "LPI", datetime.date(1996, 11, 29)),
    "DNI": pnp.Vendor(u"Deterministic Networks Inc.", "DNI", datetime.date(2000, 4, 19)),
    "BCQ": pnp.Vendor(u"Deutsche Telekom Berkom GmbH", "BCQ", datetime.date(1997, 8, 12)),
    "DTO": pnp.Vendor(u"Deutsche Thomson OHG", "DTO", datetime.date(2007, 6, 14)),
    "DVL": pnp.Vendor(u"Devolo AG", "DVL", datetime.date(2002, 5, 30)),
    "DXL": pnp.Vendor(u"Dextera Labs Inc", "DXL", datetime.date(2009, 12, 9)),
    "DFI": pnp.Vendor(u"DFI", "DFI", datetime.date(1996, 11, 29)),
    "DHP": pnp.Vendor(u"DH Print", "DHP", datetime.date(1996, 11, 29)),
    "DIA": pnp.Vendor(u"Diadem", "DIA", datetime.date(1996, 11, 29)),
    "DGS": pnp.Vendor(u"Diagsoft Inc", "DGS", datetime.date(1996, 11, 29)),
    "DCO": pnp.Vendor(u"Dialogue Technology Corporation", "DCO", datetime.date(2004, 6, 16)),
    "DCS": pnp.Vendor(u"Diamond Computer Systems Inc", "DCS", datetime.date(1996, 11, 29)),
    "DLC": pnp.Vendor(u"Diamond Lane Comm. Corporation", "DLC", datetime.date(1996, 11, 29)),
    "DNV": pnp.Vendor(u"DiCon", "DNV", datetime.date(2004, 12, 15)),
    "DVD": pnp.Vendor(u"Dictaphone Corporation", "DVD", datetime.date(1998, 4, 3)),
    "DBD": pnp.Vendor(u"Diebold Inc.", "DBD", datetime.date(2006, 9, 5)),
    "DAE": pnp.Vendor(u"Digatron Industrie Elektronik GmbH", "DAE", datetime.date(1997, 2, 24)),
    "DGI": pnp.Vendor(u"DIGI International", "DGI", datetime.date(1996, 11, 29)),
    "DBI": pnp.Vendor(u"DigiBoard Inc", "DBI", datetime.date(1996, 11, 29)),
    "DIG": pnp.Vendor(u"Digicom S.p.A.", "DIG", datetime.date(1996, 11, 29)),
    "DMB": pnp.Vendor(u"Digicom Systems Inc", "DMB", datetime.date(1998, 3, 13)),
    "DGP": pnp.Vendor(u"Digicorp European sales S.A.", "DGP", datetime.date(1997, 5, 22)),
    "DGA": pnp.Vendor(u"Digiital Arts Inc", "DGA", datetime.date(2007, 6, 14)),
    "DXC": pnp.Vendor(u"Digipronix Control Systems", "DXC", datetime.date(1999, 7, 16)),
    "DAC": pnp.Vendor(u"Digital Acoustics Corporation", "DAC", datetime.date(2000, 5, 24)),
    "DAL": pnp.Vendor(u"Digital Audio Labs Inc", "DAL", datetime.date(1996, 11, 29)),
    "DCA": pnp.Vendor(u"Digital Communications Association", "DCA", datetime.date(1996, 11, 29)),
    "SHR": pnp.Vendor(u"Digital Discovery", "SHR", datetime.date(1997, 9, 24)),
    "PRF": pnp.Vendor(u"Digital Electronics Corporation", "PRF", datetime.date(2003, 1, 2)),
    "DEC": pnp.Vendor(u"Digital Equipment Corporation", "DEC", datetime.date(1996, 11, 29)),
    "DPS": pnp.Vendor(u"Digital Processing Systems", "DPS", datetime.date(1996, 11, 29)),
    "DPL": pnp.Vendor(u"Digital Projection Limited", "DPL", datetime.date(2002, 7, 9)),
    "DRD": pnp.Vendor(u"DIGITAL REFLECTION INC.", "DRD", datetime.date(2000, 2, 21)),
    "DVS": pnp.Vendor(u"Digital Video System", "DVS", datetime.date(1996, 11, 29)),
    "DPA": pnp.Vendor(u"DigiTalk Pro AV", "DPA", datetime.date(2000, 10, 23)),
    "DLG": pnp.Vendor(u"Digital-Logic GmbH", "DLG", datetime.date(2003, 9, 2)),
    "DSI": pnp.Vendor(u"Digitan Systems Inc", "DSI", datetime.date(1996, 11, 29)),
    "DLT": pnp.Vendor(u"Digitelec Informatique Park Cadera", "DLT", datetime.date(1996, 11, 29)),
    "DTE": pnp.Vendor(u"Dimension Technologies, Inc.", "DTE", datetime.date(2010, 5, 3)),
    "DMM": pnp.Vendor(u"Dimond Multimedia Systems Inc", "DMM", datetime.date(1996, 11, 29)),
    "DIS": pnp.Vendor(u"Diseda S.A.", "DIS", datetime.date(1996, 11, 29)),
    "DMT": pnp.Vendor(u"Distributed Management Task Force, Inc. (DMTF)", "DMT", datetime.date(2009, 3, 31)),
    "DTI": pnp.Vendor(u"Diversified Technology, Inc.", "DTI", datetime.date(1996, 11, 29)),
    "ABO": pnp.Vendor(u"D-Link Systems Inc", "ABO", datetime.date(1996, 11, 29)),
    "DLK": pnp.Vendor(u"D-Link Systems Inc", "DLK", datetime.date(1996, 11, 29)),
    "DNA": pnp.Vendor(u"DNA Enterprises, Inc.", "DNA", datetime.date(1998, 9, 1)),
    "AUO": pnp.Vendor(u"DO NOT USE - AUO", "AUO", datetime.date(2008, 9, 16)),
    "LPL": pnp.Vendor(u"DO NOT USE - LPL", "LPL", datetime.date(2008, 9, 16)),
    "PHI": pnp.Vendor(u"DO NOT USE - PHI", "PHI", datetime.date(1996, 11, 29)),
    "PTW": pnp.Vendor(u"DO NOT USE - PTW", "PTW", datetime.date(2009, 9, 9)),
    "PVC": pnp.Vendor(u"DO NOT USE - PVC", "PVC", datetime.date(2009, 9, 9)),
    "RTK": pnp.Vendor(u"DO NOT USE - RTK", "RTK", datetime.date(2009, 9, 9)),
    "SEG": pnp.Vendor(u"DO NOT USE - SEG", "SEG", datetime.date(2009, 9, 9)),
    "TNJ": pnp.Vendor(u"DO NOT USE - TNJ", "TNJ", datetime.date(2009, 9, 9)),
    "UND": pnp.Vendor(u"DO NOT USE - UND", "UND", datetime.date(1996, 11, 29)),
    "UNE": pnp.Vendor(u"DO NOT USE - UNE", "UNE", datetime.date(1996, 11, 29)),
    "UNF": pnp.Vendor(u"DO NOT USE - UNF", "UNF", datetime.date(1996, 11, 29)),
    "WAN": pnp.Vendor(u"DO NOT USE - WAN", "WAN", datetime.date(2009, 9, 9)),
    "XER": pnp.Vendor(u"DO NOT USE - XER", "XER", datetime.date(2009, 9, 9)),
    "XOC": pnp.Vendor(u"DO NOT USE - XOC", "XOC", datetime.date(2009, 9, 9)),
    "DBL": pnp.Vendor(u"Doble Engineering Company", "DBL", datetime.date(1996, 11, 29)),
    "DPI": pnp.Vendor(u"DocuPoint", "DPI", datetime.date(1996, 11, 29)),
    "DLB": pnp.Vendor(u"Dolby Laboratories Inc.", "DLB", datetime.date(2010, 1, 27)),
    "DOL": pnp.Vendor(u"Dolman Technologies Group Inc", "DOL", datetime.date(1997, 11, 11)),
    "DSP": pnp.Vendor(u"Domain Technology Inc", "DSP", datetime.date(1996, 11, 29)),
    "DMS": pnp.Vendor(u"DOME imaging systems", "DMS", datetime.date(2000, 10, 23)),
    "DOM": pnp.Vendor(u"Dome Imaging Systems", "DOM", datetime.date(1996, 11, 29)),
    "AIK": pnp.Vendor(u"Dongguan Alllike Electronics Co., Ltd.", "AIK", datetime.date(2015, 4, 11)),
    "DUA": pnp.Vendor(u"Dosch & Amand GmbH & Company KG", "DUA", datetime.date(1997, 12, 2)),
    "DOT": pnp.Vendor(u"Dotronic Mikroelektronik GmbH", "DOT", datetime.date(2002, 6, 28)),
    "DIM": pnp.Vendor(u"dPict Imaging, Inc.", "DIM", datetime.date(2008, 2, 12)),
    "DPX": pnp.Vendor(u"DpiX, Inc.", "DPX", datetime.date(1998, 9, 23)),
    "DPT": pnp.Vendor(u"DPT", "DPT", datetime.date(1996, 11, 29)),
    "DRB": pnp.Vendor(u"Dr. Bott KG", "DRB", datetime.date(2002, 4, 25)),
    "DNT": pnp.Vendor(u"Dr. Neuhous Telekommunikation GmbH", "DNT", datetime.date(1996, 11, 29)),
    "DIT": pnp.Vendor(u"Dragon Information Technology", "DIT", datetime.date(1996, 11, 29)),
    "DRS": pnp.Vendor(u"DRS Defense Solutions, LLC", "DRS", datetime.date(2011, 10, 18)),
    "DSD": pnp.Vendor(u"DS Multimedia Pte Ltd", "DSD", datetime.date(2006, 2, 14)),
    "DSM": pnp.Vendor(u"DSM Digital Services GmbH", "DSM", datetime.date(1996, 11, 29)),
    "DCE": pnp.Vendor(u"dSPACE GmbH", "DCE", datetime.date(1996, 12, 16)),
    "DTC": pnp.Vendor(u"DTC Tech Corporation", "DTC", datetime.date(1996, 11, 29)),
    "DGK": pnp.Vendor(u"DugoTech Co., LTD", "DGK", datetime.date(2007, 6, 14)),
    "DMC": pnp.Vendor(u"Dune Microsystems Corporation", "DMC", datetime.date(1996, 11, 29)),
    "DYC": pnp.Vendor(u"Dycam Inc", "DYC", datetime.date(1998, 1, 8)),
    "DYM": pnp.Vendor(u"Dymo-CoStar Corporation", "DYM", datetime.date(1998, 12, 28)),
    "DCL": pnp.Vendor(u"Dynamic Controls Ltd", "DCL", datetime.date(2000, 5, 24)),
    "DTK": pnp.Vendor(u"Dynax Electronics (HK) Ltd", "DTK", datetime.date(1996, 11, 29)),
    "DYX": pnp.Vendor(u"Dynax Electronics (HK) Ltd", "DYX", datetime.date(1996, 11, 29)),
    "EDC": pnp.Vendor(u"e.Digital Corporation", "EDC", datetime.date(2000, 10, 23)),
    "EEP": pnp.Vendor(u"E.E.P.D. GmbH", "EEP", datetime.date(2007, 6, 14)),
    "EGL": pnp.Vendor(u"Eagle Technology", "EGL", datetime.date(1996, 11, 29)),
    "KOD": pnp.Vendor(u"Eastman Kodak Company", "KOD", datetime.date(2000, 5, 24)),
    "EKC": pnp.Vendor(u"Eastman Kodak Company", "EKC", datetime.date(1996, 11, 29)),
    "TWI": pnp.Vendor(u"Easytel oy", "TWI", datetime.date(1999, 7, 16)),
    "EBS": pnp.Vendor(u"EBS Euchner B\xfcro- und Schulsysteme GmbH", "EBS", datetime.date(2013, 2, 5)),
    "ECO": pnp.Vendor(u"Echo Speech Corporation", "ECO", datetime.date(1996, 11, 29)),
    "ETI": pnp.Vendor(u"Eclipse Tech Inc", "ETI", datetime.date(1996, 11, 29)),
    "ECM": pnp.Vendor(u"E-Cmos Tech Corporation", "ECM", datetime.date(1996, 11, 29)),
    "ESC": pnp.Vendor(u"Eden Sistemas de Computacao S/A", "ESC", datetime.date(1996, 11, 29)),
    "EDI": pnp.Vendor(u"Edimax Tech. Company Ltd", "EDI", datetime.date(1996, 11, 29)),
    "EDM": pnp.Vendor(u"EDMI", "EDM", datetime.date(1998, 7, 16)),
    "ELI": pnp.Vendor(u"Edsun Laboratories", "ELI", datetime.date(1996, 11, 29)),
    "EES": pnp.Vendor(u"EE Solutions, Inc.", "EES", datetime.date(2003, 4, 16)),
    "EEH": pnp.Vendor(u"EEH Datalink GmbH", "EEH", datetime.date(1997, 7, 3)),
    "ENI": pnp.Vendor(u"Efficient Networks", "ENI", datetime.date(1996, 11, 29)),
    "EGN": pnp.Vendor(u"Egenera, Inc.", "EGN", datetime.date(2002, 10, 8)),
    "EIC": pnp.Vendor(u"Eicon Technology Corporation", "EIC", datetime.date(1996, 11, 29)),
    "EGD": pnp.Vendor(u"EIZO GmbH Display Technologies", "EGD", datetime.date(2009, 2, 13)),
    "ENC": pnp.Vendor(u"Eizo Nanao Corporation", "ENC", datetime.date(1998, 12, 28)),
    "EKS": pnp.Vendor(u"EKSEN YAZILIM", "EKS", datetime.date(2002, 4, 25)),
    "ELA": pnp.Vendor(u"ELAD srl", "ELA", datetime.date(2002, 4, 25)),
    "ETD": pnp.Vendor(u"ELAN MICROELECTRONICS CORPORATION", "ETD", datetime.date(2009, 11, 3)),
    "TSH": pnp.Vendor(u"ELAN MICROELECTRONICS CORPORATION", "TSH", datetime.date(2014, 11, 14)),
    "ESA": pnp.Vendor(u"Elbit Systems of America", "ESA", datetime.date(2009, 6, 15)),
    "ESG": pnp.Vendor(u"ELCON Systemtechnik GmbH", "ESG", datetime.date(1999, 7, 16)),
    "LXS": pnp.Vendor(u"ELEA CardWare", "LXS", datetime.date(1998, 6, 25)),
    "ECP": pnp.Vendor(u"Elecom Company Ltd", "ECP", datetime.date(1996, 11, 29)),
    "ELE": pnp.Vendor(u"Elecom Company Ltd", "ELE", datetime.date(1996, 11, 29)),
    "ECA": pnp.Vendor(u"Electro Cam Corp.", "ECA", datetime.date(2000, 8, 10)),
    "ELC": pnp.Vendor(u"Electro Scientific Ind", "ELC", datetime.date(1996, 11, 29)),
    "MMM": pnp.Vendor(u"Electronic Measurements", "MMM", datetime.date(1996, 11, 29)),
    "ETS": pnp.Vendor(u"Electronic Trade Solutions Ltd", "ETS", datetime.date(2002, 8, 20)),
    "EDG": pnp.Vendor(u"Electronic-Design GmbH", "EDG", datetime.date(1997, 8, 12)),
    "ELL": pnp.Vendor(u"Electrosonic Ltd", "ELL", datetime.date(1999, 9, 13)),
    "ELT": pnp.Vendor(u"Element Labs, Inc.", "ELT", datetime.date(2007, 10, 11)),
    "EGA": pnp.Vendor(u"Elgato Systems LLC", "EGA", datetime.date(2011, 2, 8)),
    "ECS": pnp.Vendor(u"Elitegroup Computer Systems Company Ltd", "ECS", datetime.date(1996, 11, 29)),
    "UEG": pnp.Vendor(u"Elitegroup Computer Systems Company Ltd", "UEG", datetime.date(1996, 11, 29)),
    "ELG": pnp.Vendor(u"Elmeg GmbH Kommunikationstechnik", "ELG", datetime.date(1996, 11, 29)),
    "ELM": pnp.Vendor(u"Elmic Systems Inc", "ELM", datetime.date(1996, 11, 29)),
    "EMO": pnp.Vendor(u"ELMO COMPANY, LIMITED", "EMO", datetime.date(2012, 6, 26)),
    "ELO": pnp.Vendor(u"Elo TouchSystems Inc", "ELO", datetime.date(1996, 11, 29)),
    "ELX": pnp.Vendor(u"Elonex PLC", "ELX", datetime.date(1996, 11, 29)),
    "LPE": pnp.Vendor(u"El-PUSK Co., Ltd.", "LPE", datetime.date(2001, 8, 14)),
    "ELS": pnp.Vendor(u"ELSA GmbH", "ELS", datetime.date(1996, 11, 29)),
    "EAG": pnp.Vendor(u"ELTEC Elektronik AG", "EAG", datetime.date(2014, 11, 25)),
    "EMB": pnp.Vendor(u"Embedded computing inc ltd", "EMB", datetime.date(2002, 2, 25)),
    "EST": pnp.Vendor(u"Embedded Solution Technology", "EST", datetime.date(2000, 5, 24)),
    "EMD": pnp.Vendor(u"Embrionix Design Inc.", "EMD", datetime.date(2013, 7, 24)),
    "EMK": pnp.Vendor(u"Emcore Corporation", "EMK", datetime.date(2012, 5, 31)),
    "EDT": pnp.Vendor(u"Emerging Display Technologies Corp", "EDT", datetime.date(2009, 8, 18)),
    "EMG": pnp.Vendor(u"EMG Consultants Inc", "EMG", datetime.date(1996, 11, 29)),
    "EME": pnp.Vendor(u"EMiNE TECHNOLOGY COMPANY, LTD.", "EME", datetime.date(2005, 6, 16)),
    "EPC": pnp.Vendor(u"Empac", "EPC", datetime.date(1996, 12, 4)),
    "EMU": pnp.Vendor(u"Emulex Corporation", "EMU", datetime.date(1996, 11, 29)),
    "ECI": pnp.Vendor(u"Enciris Technologies", "ECI", datetime.date(2008, 11, 1)),
    "ECT": pnp.Vendor(u"Enciris Technologies", "ECT", datetime.date(2008, 11, 1)),
    "ENE": pnp.Vendor(u"ENE Technology Inc.", "ENE", datetime.date(2001, 3, 15)),
    "DTL": pnp.Vendor(u"e-Net Inc", "DTL", datetime.date(1997, 10, 16)),
    "EHN": pnp.Vendor(u"Enhansoft", "EHN", datetime.date(2010, 11, 16)),
    "END": pnp.Vendor(u"ENIDAN Technologies Ltd", "END", datetime.date(2000, 4, 19)),
    "ESD": pnp.Vendor(u"Ensemble Designs, Inc", "ESD", datetime.date(2009, 12, 9)),
    "ENS": pnp.Vendor(u"Ensoniq Corporation", "ENS", datetime.date(1996, 11, 29)),
    "ENT": pnp.Vendor(u"Enterprise Comm. & Computing Inc", "ENT", datetime.date(1996, 11, 29)),
    "EPI": pnp.Vendor(u"Envision Peripherals, Inc", "EPI", datetime.date(1999, 2, 22)),
    "EON": pnp.Vendor(u"Eon Instrumentation, Inc.", "EON", datetime.date(2015, 1, 15)),
    "EPN": pnp.Vendor(u"EPiCON Inc.", "EPN", datetime.date(1998, 9, 23)),
    "EPH": pnp.Vendor(u"Epiphan Systems Inc.", "EPH", datetime.date(2011, 3, 14)),
    "EHJ": pnp.Vendor(u"Epson Research", "EHJ", datetime.date(1996, 11, 29)),
    "EQX": pnp.Vendor(u"Equinox Systems Inc", "EQX", datetime.date(1996, 11, 29)),
    "EQP": pnp.Vendor(u"Equipe Electronics Ltd.", "EQP", datetime.date(2005, 7, 14)),
    "EGO": pnp.Vendor(u"Ergo Electronics", "EGO", datetime.date(1996, 11, 29)),
    "ERG": pnp.Vendor(u"Ergo System", "ERG", datetime.date(1996, 11, 29)),
    "ERI": pnp.Vendor(u"Ericsson Mobile Communications AB", "ERI", datetime.date(1997, 10, 22)),
    "EUT": pnp.Vendor(u"Ericsson Mobile Networks B.V.", "EUT", datetime.date(1998, 4, 14)),
    "ERN": pnp.Vendor(u"Ericsson, Inc.", "ERN", datetime.date(1998, 9, 23)),
    "ESK": pnp.Vendor(u"ES&S", "ESK", datetime.date(1999, 11, 8)),
    "ESN": pnp.Vendor(u"eSATURNUS", "ESN", datetime.date(2012, 2, 21)),
    "ERT": pnp.Vendor(u"Escort Insturments Corporation", "ERT", datetime.date(1997, 5, 2)),
    "ESS": pnp.Vendor(u"ESS Technology Inc", "ESS", datetime.date(1996, 11, 29)),
    "ECC": pnp.Vendor(u"ESSential Comm. Corporation", "ECC", datetime.date(1996, 11, 29)),
    "ESL": pnp.Vendor(u"Esterline Technologies", "ESL", datetime.date(2012, 1, 6)),
    "ESB": pnp.Vendor(u"Esterline Belgium BVBA", "ESB", datetime.date(2015, 1, 15)),
    "ESY": pnp.Vendor(u"E-Systems Inc", "ESY", datetime.date(1996, 11, 29)),
    "EEE": pnp.Vendor(u"ET&T Technology Company Ltd", "EEE", datetime.date(1998, 5, 4)),
    "ETT": pnp.Vendor(u"E-Tech Inc", "ETT", datetime.date(1996, 11, 29)),
    "ETK": pnp.Vendor(u"eTEK Labs Inc.", "ETK", datetime.date(1998, 7, 16)),
    "ETH": pnp.Vendor(u"Etherboot Project", "ETH", datetime.date(2010, 7, 9)),
    "ECK": pnp.Vendor(u"Eugene Chukhlomin Sole Proprietorship, d.b.a.", "ECK", datetime.date(2008, 5, 3)),
    "ERP": pnp.Vendor(u"Euraplan GmbH", "ERP", datetime.date(1996, 11, 29)),
    "EAS": pnp.Vendor(u"Evans and Sutherland Computer", "EAS", datetime.date(2003, 1, 28)),
    "EVX": pnp.Vendor(u"Everex", "EVX", datetime.date(1996, 11, 29)),
    "ETC": pnp.Vendor(u"Everton Technology Company Ltd", "ETC", datetime.date(1997, 4, 10)),
    "ETL": pnp.Vendor(u"Evertz Microsystems Ltd.", "ETL", datetime.date(2007, 6, 14)),
    "EVI": pnp.Vendor(u"eviateg GmbH", "EVI", datetime.date(2000, 2, 21)),
    "EMI": pnp.Vendor(u"Ex Machina Inc", "EMI", datetime.date(1996, 11, 29)),
    "YHW": pnp.Vendor(u"Exacom SA", "YHW", datetime.date(1996, 11, 29)),
    "EXT": pnp.Vendor(u"Exatech Computadores & Servicos Ltda", "EXT", datetime.date(1998, 9, 23)),
    "ECL": pnp.Vendor(u"Excel Company Ltd", "ECL", datetime.date(1997, 5, 27)),
    "EXC": pnp.Vendor(u"Excession Audio", "EXC", datetime.date(1998, 11, 6)),
    "XFO": pnp.Vendor(u"EXFO Electro Optical Engineering", "XFO", datetime.date(1998, 4, 29)),
    "EXI": pnp.Vendor(u"Exide Electronics", "EXI", datetime.date(1996, 11, 29)),
    "ESI": pnp.Vendor(u"Extended Systems, Inc.", "ESI", datetime.date(1999, 7, 16)),
    "EXY": pnp.Vendor(u"Exterity Ltd", "EXY", datetime.date(2009, 2, 12)),
    "CRO": pnp.Vendor(u"Extraordinary Technologies PTY Limited", "CRO", datetime.date(2005, 4, 11)),
    "EXX": pnp.Vendor(u"Exxact GmbH", "EXX", datetime.date(1996, 11, 29)),
    "EYF": pnp.Vendor(u"eyefactive Gmbh", "EYF", datetime.date(2015, 7, 7)),
    "EYE": pnp.Vendor(u"eyevis GmbH", "EYE", datetime.date(2011, 11, 18)),
    "EZE": pnp.Vendor(u"EzE Technologies", "EZE", datetime.date(2005, 2, 21)),
    "FJT": pnp.Vendor(u"F.J. Tieman BV", "FJT", datetime.date(1998, 6, 25)),
    "FFI": pnp.Vendor(u"Fairfield Industries", "FFI", datetime.date(1996, 11, 29)),
    "FAN": pnp.Vendor(u"Fantalooks Co., Ltd.", "FAN", datetime.date(2014, 3, 12)),
    "FNC": pnp.Vendor(u"Fanuc LTD", "FNC", datetime.date(1997, 1, 29)),
    "FAR": pnp.Vendor(u"Farallon Computing", "FAR", datetime.date(1996, 11, 29)),
    "FRO": pnp.Vendor(u"FARO Technologies", "FRO", datetime.date(2012, 9, 21)),
    "FLI": pnp.Vendor(u"Faroudja Laboratories", "FLI", datetime.date(2004, 6, 2)),
    "FMA": pnp.Vendor(u"Fast Multimedia AG", "FMA", datetime.date(1996, 11, 29)),
    "FTI": pnp.Vendor(u"FastPoint Technologies, Inc.", "FTI", datetime.date(2001, 6, 21)),
    "FIT": pnp.Vendor(u"Feature Integration Technology Inc.", "FIT", datetime.date(2009, 8, 11)),
    "FEL": pnp.Vendor(u"Fellowes & Questec", "FEL", datetime.date(1996, 11, 29)),
    "FMI": pnp.Vendor(u"Fellowes, Inc.", "FMI", datetime.date(2001, 7, 5)),
    "FEN": pnp.Vendor(u"Fen Systems Ltd.", "FEN", datetime.date(2010, 5, 4)),
    "FER": pnp.Vendor(u"Ferranti Int'L", "FER", datetime.date(1996, 11, 29)),
    "TLA": pnp.Vendor(u"Ferrari Electronic GmbH", "TLA", datetime.date(1996, 12, 4)),
    "FHL": pnp.Vendor(u"FHLP", "FHL", datetime.date(1996, 11, 29)),
    "FRI": pnp.Vendor(u"Fibernet Research Inc", "FRI", datetime.date(1996, 11, 29)),
    "FIN": pnp.Vendor(u"Finecom Co., Ltd.", "FIN", datetime.date(1998, 11, 27)),
    "FPC": pnp.Vendor(u"Fingerprint Cards AB", "FPC", datetime.date(2013, 6, 14)),
    "PCG": pnp.Vendor(u"First Industrial Computer Inc", "PCG", datetime.date(1996, 11, 29)),
    "LEO": pnp.Vendor(u"First International Computer Inc", "LEO", datetime.date(1997, 9, 19)),
    "FCG": pnp.Vendor(u"First International Computer Ltd", "FCG", datetime.date(1997, 4, 10)),
    "FVC": pnp.Vendor(u"First Virtual Corporation", "FVC", datetime.date(1996, 11, 29)),
    "FWR": pnp.Vendor(u"Flat Connections Inc", "FWR", datetime.date(1996, 11, 29)),
    "SSD": pnp.Vendor(u"FlightSafety International", "SSD", datetime.date(2000, 8, 10)),
    "FIS": pnp.Vendor(u"FLY-IT Simulators", "FIS", datetime.date(1997, 9, 8)),
    "FTS": pnp.Vendor(u"FocalTech Systems Co., Ltd.", "FTS", datetime.date(2013, 7, 23)),
    "FCS": pnp.Vendor(u"Focus Enhancements, Inc.", "FCS", datetime.date(2002, 12, 12)),
    "FOK": pnp.Vendor(u"Fokus Technologies GmbH", "FOK", datetime.date(2013, 10, 22)),
    "FOA": pnp.Vendor(u"FOR-A Company Limited", "FOA", datetime.date(2008, 12, 6)),
    "FRC": pnp.Vendor(u"Force Computers", "FRC", datetime.date(1996, 11, 29)),
    "FMC": pnp.Vendor(u"Ford Microelectronics Inc", "FMC", datetime.date(1997, 3, 11)),
    "FSI": pnp.Vendor(u"Fore Systems Inc", "FSI", datetime.date(1996, 11, 29)),
    "FIL": pnp.Vendor(u"Forefront Int'l Ltd", "FIL", datetime.date(1996, 11, 29)),
    "FIC": pnp.Vendor(u"Formosa Industrial Computing Inc", "FIC", datetime.date(1996, 11, 29)),
    "FMZ": pnp.Vendor(u"Formoza-Altair", "FMZ", datetime.date(2003, 4, 25)),
    "FDD": pnp.Vendor(u"Forth Dimension Displays Ltd", "FDD", datetime.date(2015, 7, 7)),
    "FRE": pnp.Vendor(u"Forvus Research Inc", "FRE", datetime.date(1997, 4, 24)),
    "FOS": pnp.Vendor(u"Foss Tecator", "FOS", datetime.date(1997, 10, 22)),
    "FZC": pnp.Vendor(u"Founder Group Shenzhen Co.", "FZC", datetime.date(1999, 11, 8)),
    "FTN": pnp.Vendor(u"Fountain Technologies Inc", "FTN", datetime.date(1996, 11, 29)),
    "HHI": pnp.Vendor(u"Fraunhofer Heinrich-Hertz-Institute", "HHI", datetime.date(2012, 7, 27)),
    "FRD": pnp.Vendor(u"Freedom Scientific BLV", "FRD", datetime.date(2007, 6, 15)),
    "TCX": pnp.Vendor(u"FREEMARS Heavy Industries", "TCX", datetime.date(2001, 3, 15)),
    "FTE": pnp.Vendor(u"Frontline Test Equipment Inc.", "FTE", datetime.date(1999, 1, 20)),
    "FTG": pnp.Vendor(u"FTG Data Systems", "FTG", datetime.date(1996, 11, 29)),
    "FXX": pnp.Vendor(u"Fuji Xerox", "FXX", datetime.date(1996, 11, 29)),
    "FFC": pnp.Vendor(u"FUJIFILM Corporation", "FFC", datetime.date(2011, 8, 22)),
    "FDT": pnp.Vendor(u"Fujitsu Display Technologies Corp.", "FDT", datetime.date(2002, 10, 23)),
    "FGL": pnp.Vendor(u"Fujitsu General Limited.", "FGL", datetime.date(2000, 2, 21)),
    "FUJ": pnp.Vendor(u"Fujitsu Ltd", "FUJ", datetime.date(1996, 11, 29)),
    "FML": pnp.Vendor(u"Fujitsu Microelect Ltd", "FML", datetime.date(1996, 11, 29)),
    "FPE": pnp.Vendor(u"Fujitsu Peripherals Ltd", "FPE", datetime.date(1997, 8, 19)),
    "FUS": pnp.Vendor(u"Fujitsu Siemens Computers GmbH", "FUS", datetime.date(2000, 1, 13)),
    "FJS": pnp.Vendor(u"Fujitsu Spain", "FJS", datetime.date(1996, 11, 29)),
    "FJC": pnp.Vendor(u"Fujitsu Takamisawa Component Limited", "FJC", datetime.date(1999, 5, 16)),
    "FTL": pnp.Vendor(u"FUJITSU TEN LIMITED", "FTL", datetime.date(2011, 12, 20)),
    "FNI": pnp.Vendor(u"Funai Electric Co., Ltd.", "FNI", datetime.date(2005, 1, 18)),
    "FCB": pnp.Vendor(u"Furukawa Electric Company Ltd", "FCB", datetime.date(1996, 11, 29)),
    "FEC": pnp.Vendor(u"FURUNO ELECTRIC CO., LTD.", "FEC", datetime.date(1996, 11, 29)),
    "FDI": pnp.Vendor(u"Future Designs, Inc.", "FDI", datetime.date(2014, 9, 29)),
    "FDC": pnp.Vendor(u"Future Domain", "FDC", datetime.date(1996, 11, 29)),
    "FSC": pnp.Vendor(u"Future Systems Consulting KK", "FSC", datetime.date(1996, 11, 29)),
    "FTC": pnp.Vendor(u"Futuretouch Corporation", "FTC", datetime.date(1996, 11, 29)),
    "FZI": pnp.Vendor(u"FZI Forschungszentrum Informatik", "FZI", datetime.date(1997, 8, 12)),
    "SPH": pnp.Vendor(u"G&W Instruments GmbH", "SPH", datetime.date(2002, 2, 25)),
    "GDI": pnp.Vendor(u"G. Diehl ISDN GmbH", "GDI", datetime.date(1996, 11, 29)),
    "GLS": pnp.Vendor(u"Gadget Labs LLC", "GLS", datetime.date(1996, 11, 29)),
    "GAG": pnp.Vendor(u"Gage Applied Sciences Inc", "GAG", datetime.date(1996, 11, 29)),
    "HUB": pnp.Vendor(u"GAI-Tronics, A Hubbell Company", "HUB", datetime.date(2009, 3, 26)),
    "GAL": pnp.Vendor(u"Galil Motion Control", "GAL", datetime.date(1996, 11, 29)),
    "GRM": pnp.Vendor(u"Garmin International", "GRM", datetime.date(2011, 12, 9)),
    "GTM": pnp.Vendor(u"Garnet System Company Ltd", "GTM", datetime.date(1996, 11, 29)),
    "GWY": pnp.Vendor(u"Gateway 2000", "GWY", datetime.date(1996, 11, 29)),
    "GCI": pnp.Vendor(u"Gateway Comm. Inc", "GCI", datetime.date(1996, 11, 29)),
    "GWK": pnp.Vendor(u"Gateworks Corporation", "GWK", datetime.date(2013, 7, 31)),
    "GAU": pnp.Vendor(u"Gaudi Co., Ltd.", "GAU", datetime.date(2003, 3, 31)),
    "GCC": pnp.Vendor(u"GCC Technologies Inc", "GCC", datetime.date(1997, 6, 5)),
    "GDS": pnp.Vendor(u"GDS", "GDS", datetime.date(2004, 6, 23)),
    "GEF": pnp.Vendor(u"GE Fanuc Embedded Systems", "GEF", datetime.date(2007, 6, 14)),
    "GEH": pnp.Vendor(u"Abaco Systems, Inc.", "GEH", datetime.date(2010, 9, 3)),
    "GFN": pnp.Vendor(u"Gefen Inc.", "GFN", datetime.date(2007, 10, 11)),
    "GEM": pnp.Vendor(u"Gem Plus", "GEM", datetime.date(1998, 2, 27)),
    "GMN": pnp.Vendor(u"GEMINI 2000 Ltd", "GMN", datetime.date(2000, 10, 23)),
    "GDC": pnp.Vendor(u"General Datacom", "GDC", datetime.date(1996, 11, 29)),
    "GED": pnp.Vendor(u"General Dynamics C4 Systems", "GED", datetime.date(2013, 1, 9)),
    "GML": pnp.Vendor(u"General Information Systems", "GML", datetime.date(2000, 1, 13)),
    "GIC": pnp.Vendor(u"General Inst. Corporation", "GIC", datetime.date(1996, 11, 29)),
    "GSC": pnp.Vendor(u"General Standards Corporation", "GSC", datetime.date(1998, 7, 16)),
    "GTT": pnp.Vendor(u"General Touch Technology Co., Ltd.", "GTT", datetime.date(2002, 11, 21)),
    "GEN": pnp.Vendor(u"Genesys ATE Inc", "GEN", datetime.date(1996, 11, 29)),
    "GLM": pnp.Vendor(u"Genesys Logic", "GLM", datetime.date(1999, 11, 8)),
    "GND": pnp.Vendor(u"Gennum Corporation", "GND", datetime.date(2006, 9, 5)),
    "GEO": pnp.Vendor(u"GEO Sense", "GEO", datetime.date(1996, 11, 29)),
    "GTS": pnp.Vendor(u"Geotest Marvin Test Systems Inc", "GTS", datetime.date(1998, 2, 24)),
    "GER": pnp.Vendor(u"GERMANEERS GmbH", "GER", datetime.date(2011, 12, 20)),
    "GES": pnp.Vendor(u"GES Singapore Pte Ltd", "GES", datetime.date(2001, 3, 15)),
    "GET": pnp.Vendor(u"Getac Technology Corporation", "GET", datetime.date(2010, 5, 11)),
    "GFM": pnp.Vendor(u"GFMesstechnik GmbH", "GFM", datetime.date(2001, 3, 15)),
    "GIP": pnp.Vendor(u"GI Provision Ltd", "GIP", datetime.date(2012, 2, 8)),
    "PST": pnp.Vendor(u"Global Data SA", "PST", datetime.date(1996, 11, 29)),
    "GVL": pnp.Vendor(u"Global Village Communication", "GVL", datetime.date(1996, 11, 29)),
    "GMK": pnp.Vendor(u"GMK Electronic Design GmbH", "GMK", datetime.date(2008, 1, 18)),
    "GMM": pnp.Vendor(u"GMM Research Inc", "GMM", datetime.date(1996, 11, 29)),
    "GMX": pnp.Vendor(u"GMX Inc", "GMX", datetime.date(1996, 11, 29)),
    "GNN": pnp.Vendor(u"GN Nettest Inc", "GNN", datetime.date(1997, 7, 30)),
    "GOE": pnp.Vendor(u"GOEPEL electronic GmbH", "GOE", datetime.date(2013, 6, 24)),
    "GLD": pnp.Vendor(u"Goldmund - Digital Audio SA", "GLD", datetime.date(2012, 2, 6)),
    "GRE": pnp.Vendor(u"GOLD RAIN ENTERPRISES CORP.", "GRE", datetime.date(2003, 6, 4)),
    "GSM": pnp.Vendor(u"Goldstar Company Ltd", "GSM", datetime.date(1996, 11, 29)),
    "GTI": pnp.Vendor(u"Goldtouch", "GTI", datetime.date(1997, 8, 6)),
    "GGL": pnp.Vendor(u"Google Inc.", "GGL", datetime.date(2010, 5, 26)),
    "GPR": pnp.Vendor(u"GoPro, Inc.", "GPR", datetime.date(2015, 1, 15)),
    "GRH": pnp.Vendor(u"Granch Ltd", "GRH", datetime.date(2002, 9, 23)),
    "GJN": pnp.Vendor(u"Grand Junction Networks", "GJN", datetime.date(1996, 11, 29)),
    "GSN": pnp.Vendor(u"Grandstream Networks, Inc.", "GSN", datetime.date(2014, 3, 3)),
    "GST": pnp.Vendor(u"Graphic SystemTechnology", "GST", datetime.date(1996, 11, 29)),
    "GRA": pnp.Vendor(u"Graphica Computer", "GRA", datetime.date(1996, 11, 29)),
    "GTC": pnp.Vendor(u"Graphtec Corporation", "GTC", datetime.date(1996, 11, 29)),
    "TGV": pnp.Vendor(u"Grass Valley Germany GmbH", "TGV", datetime.date(2007, 6, 14)),
    "GCS": pnp.Vendor(u"Grey Cell Systems Ltd", "GCS", datetime.date(1997, 4, 29)),
    "GSY": pnp.Vendor(u"Grossenbacher Systeme AG", "GSY", datetime.date(2000, 4, 19)),
    "GTK": pnp.Vendor(u"G-Tech Corporation", "GTK", datetime.date(1996, 11, 29)),
    "GIM": pnp.Vendor(u"Guillemont International", "GIM", datetime.date(1997, 10, 29)),
    "GZE": pnp.Vendor(u"GUNZE Limited", "GZE", datetime.date(2005, 5, 2)),
    "GNZ": pnp.Vendor(u"Gunze Ltd", "GNZ", datetime.date(1996, 11, 29)),
    "GUD": pnp.Vendor(u"Guntermann & Drunck GmbH", "GUD", datetime.date(2003, 3, 10)),
    "GUZ": pnp.Vendor(u"Guzik Technical Enterprises", "GUZ", datetime.date(1996, 11, 29)),
    "GVC": pnp.Vendor(u"GVC Corporation", "GVC", datetime.date(1996, 11, 29)),
    "HPR": pnp.Vendor(u"H.P.R. Electronics GmbH", "HPR", datetime.date(2007, 8, 29)),
    "HSC": pnp.Vendor(u"Hagiwara Sys-Com Company Ltd", "HSC", datetime.date(1996, 11, 29)),
    "GWI": pnp.Vendor(u"GW Instruments", "GWI", datetime.date(1996, 11, 29)),
    "HAE": pnp.Vendor(u"Haider electronics", "HAE", datetime.date(2001, 7, 5)),
    "HAI": pnp.Vendor(u"Haivision Systems Inc.", "HAI", datetime.date(2007, 11, 15)),
    "HAL": pnp.Vendor(u"Halberthal", "HAL", datetime.date(1998, 2, 10)),
    "HRI": pnp.Vendor(u"Hall Research", "HRI", datetime.date(2012, 5, 10)),
    "HPK": pnp.Vendor(u"HAMAMATSU PHOTONICS K.K.", "HPK", datetime.date(2006, 12, 20)),
    "HTI": pnp.Vendor(u"Hampshire Company, Inc.", "HTI", datetime.date(1999, 1, 20)),
    "HAN": pnp.Vendor(u"Hanchang System Corporation", "HAN", datetime.date(2003, 6, 21)),
    "HSD": pnp.Vendor(u"HannStar Display Corp", "HSD", datetime.date(2009, 8, 11)),
    "HSP": pnp.Vendor(u"HannStar Display Corp", "HSP", datetime.date(2009, 8, 11)),
    "HDC": pnp.Vendor(u"HardCom Elektronik & Datateknik", "HDC", datetime.date(1998, 4, 14)),
    "HII": pnp.Vendor(u"Harman International Industries, Inc", "HII", datetime.date(2015, 1, 9)),
    "HJI": pnp.Vendor(u"Harris & Jeffries Inc", "HJI", datetime.date(1996, 11, 29)),
    "HWA": pnp.Vendor(u"Harris Canada Inc", "HWA", datetime.date(1998, 3, 13)),
    "HAR": pnp.Vendor(u"Harris Corporation", "HAR", datetime.date(2011, 12, 20)),
    "HRS": pnp.Vendor(u"Harris Semiconductor", "HRS", datetime.date(1997, 1, 2)),
    "HCW": pnp.Vendor(u"Hauppauge Computer Works Inc", "HCW", datetime.date(1996, 11, 29)),
    "HAY": pnp.Vendor(u"Hayes Microcomputer Products Inc", "HAY", datetime.date(1996, 11, 29)),
    "HCL": pnp.Vendor(u"HCL America Inc", "HCL", datetime.date(1996, 11, 29)),
    "HCM": pnp.Vendor(u"HCL Peripherals", "HCM", datetime.date(2001, 10, 2)),
    "HDI": pnp.Vendor(u"HD-INFO d.o.o.", "HDI", datetime.date(2001, 10, 8)),
    "HPI": pnp.Vendor(u"Headplay, Inc.", "HPI", datetime.date(2007, 4, 30)),
    "HYT": pnp.Vendor(u"Heng Yu Technology (HK) Limited", "HYT", datetime.date(2000, 10, 23)),
    "HRC": pnp.Vendor(u"Hercules", "HRC", datetime.date(2001, 3, 15)),
    "HRT": pnp.Vendor(u"HERCULES", "HRT", datetime.date(2001, 3, 15)),
    "HET": pnp.Vendor(u"HETEC Datensysteme GmbH", "HET", datetime.date(2004, 2, 3)),
    "HWP": pnp.Vendor(u"Hewlett Packard", "HWP", datetime.date(2001, 3, 15)),
    "HPD": pnp.Vendor(u"Hewlett Packard", "HPD", datetime.date(1997, 5, 2)),
    "HPC": pnp.Vendor(u"Hewlett-Packard Co.", "HPC", datetime.date(2000, 8, 10)),
    "HPQ": pnp.Vendor(u"Hewlett-Packard Co.", "HPQ", datetime.date(2004, 7, 12)),
    "HXM": pnp.Vendor(u"Hexium Ltd.", "HXM", datetime.date(2008, 4, 15)),
    "HIB": pnp.Vendor(u"Hibino Corporation", "HIB", datetime.date(2003, 7, 9)),
    "HWD": pnp.Vendor(u"Highwater Designs Ltd", "HWD", datetime.date(1996, 11, 29)),
    "HIK": pnp.Vendor(u"Hikom Co., Ltd.", "HIK", datetime.date(2003, 10, 13)),
    "HIL": pnp.Vendor(u"Hilevel Technology", "HIL", datetime.date(1996, 11, 29)),
    "HHC": pnp.Vendor(u"HIRAKAWA HEWTECH CORP.", "HHC", datetime.date(2008, 5, 20)),
    "HIT": pnp.Vendor(u"Hitachi America Ltd", "HIT", datetime.date(1996, 11, 29)),
    "HCE": pnp.Vendor(u"Hitachi Consumer Electronics Co., Ltd", "HCE", datetime.date(2009, 5, 15)),
    "HIC": pnp.Vendor(u"Hitachi Information Technology Co., Ltd.", "HIC", datetime.date(2000, 4, 19)),
    "HTC": pnp.Vendor(u"Hitachi Ltd", "HTC", datetime.date(1996, 11, 29)),
    "MXL": pnp.Vendor(u"Hitachi Maxell, Ltd.", "MXL", datetime.date(2000, 1, 13)),
    "HEL": pnp.Vendor(u"Hitachi Micro Systems Europe Ltd", "HEL", datetime.date(1997, 7, 9)),
    "HTX": pnp.Vendor(u"Hitex Systementwicklung GmbH", "HTX", datetime.date(1998, 1, 30)),
    "HMK": pnp.Vendor(u"hmk Daten-System-Technik BmbH", "HMK", datetime.date(1997, 9, 30)),
    "HOB": pnp.Vendor(u"HOB Electronic GmbH", "HOB", datetime.date(1996, 11, 29)),
    "HOL": pnp.Vendor(u"Holoeye Photonics AG", "HOL", datetime.date(2005, 2, 2)),
    "HDV": pnp.Vendor(u"Holografika kft.", "HDV", datetime.date(2005, 3, 31)),
    "HTK": pnp.Vendor(u"Holtek Microelectronics Inc", "HTK", datetime.date(1996, 11, 29)),
    "INC": pnp.Vendor(u"Home Row Inc", "INC", datetime.date(1996, 11, 29)),
    "FOX": pnp.Vendor(u"HON HAI PRECISON IND.CO.,LTD.", "FOX", datetime.date(2010, 8, 2)),
    "HKA": pnp.Vendor(u"HONKO MFG. CO., LTD.", "HKA", datetime.date(2004, 12, 1)),
    "HIS": pnp.Vendor(u"Hope Industrial Systems, Inc.", "HIS", datetime.date(2014, 1, 13)),
    "APG": pnp.Vendor(u"Horner Electric Inc", "APG", datetime.date(1996, 11, 29)),
    "HST": pnp.Vendor(u"Horsent Technology Co., Ltd.", "HST", datetime.date(2015, 4, 11)),
    "HOE": pnp.Vendor(u"Hosiden Corporation", "HOE", datetime.date(1997, 8, 5)),
    "HTL": pnp.Vendor(u"HTBLuVA M\xf6dling", "HTL", datetime.date(2014, 2, 17)),
    "HMC": pnp.Vendor(u"Hualon Microelectric Corporation", "HMC", datetime.date(1996, 11, 29)),
    "EBT": pnp.Vendor(u"HUALONG TECHNOLOGY CO., LTD", "EBT", datetime.date(2007, 6, 15)),
    "HNS": pnp.Vendor(u"Hughes Network Systems", "HNS", datetime.date(1996, 11, 29)),
    "HMX": pnp.Vendor(u"HUMAX Co., Ltd.", "HMX", datetime.date(2006, 2, 14)),
    "HYO": pnp.Vendor(u"HYC CO., LTD.", "HYO", datetime.date(2006, 4, 12)),
    "HYD": pnp.Vendor(u"Hydis Technologies.Co.,LTD", "HYD", datetime.date(2010, 11, 22)),
    "HYV": pnp.Vendor(u"Hynix Semiconductor", "HYV", datetime.date(2008, 11, 29)),
    "HYC": pnp.Vendor(u"Hypercope Gmbh Aachen", "HYC", datetime.date(1997, 12, 1)),
    "HYR": pnp.Vendor(u"Hypertec Pty Ltd", "HYR", datetime.date(1996, 11, 29)),
    "HYP": pnp.Vendor(u"Hyphen Ltd", "HYP", datetime.date(1996, 11, 29)),
    "ITT": pnp.Vendor(u"I&T Telecom.", "ITT", datetime.date(1999, 11, 8)),
    "IOT": pnp.Vendor(u"I/OTech Inc", "IOT", datetime.date(1996, 11, 29)),
    "IAT": pnp.Vendor(u"IAT Germany GmbH", "IAT", datetime.date(1996, 11, 29)),
    "IBM": pnp.Vendor(u"IBM Brasil", "IBM", datetime.date(1996, 11, 29)),
    "CDT": pnp.Vendor(u"IBM Corporation", "CDT", datetime.date(1996, 11, 29)),
    "IBP": pnp.Vendor(u"IBP Instruments GmbH", "IBP", datetime.date(1998, 9, 23)),
    "IBR": pnp.Vendor(u"IBR GmbH", "IBR", datetime.date(1998, 1, 16)),
    "ICE": pnp.Vendor(u"IC Ensemble", "ICE", datetime.date(1997, 9, 19)),
    "ICA": pnp.Vendor(u"ICA Inc", "ICA", datetime.date(2002, 5, 20)),
    "ICX": pnp.Vendor(u"ICCC A/S", "ICX", datetime.date(1996, 11, 29)),
    "ICD": pnp.Vendor(u"ICD Inc", "ICD", datetime.date(1997, 6, 9)),
    "ARE": pnp.Vendor(u"ICET S.p.A.", "ARE", datetime.date(1999, 5, 16)),
    "ICP": pnp.Vendor(u"ICP Electronics, Inc./iEi Technology Corp.", "ICP", datetime.date(2012, 9, 7)),
    "IUC": pnp.Vendor(u"ICSL", "IUC", datetime.date(1997, 8, 14)),
    "XTD": pnp.Vendor(u"Icuiti Corporation", "XTD", datetime.date(2007, 6, 14)),
    "IWR": pnp.Vendor(u"Icuiti Corporation", "IWR", datetime.date(2007, 3, 6)),
    "ISC": pnp.Vendor(u"Id3 Semiconductors", "ISC", datetime.date(2001, 3, 15)),
    "IDE": pnp.Vendor(u"IDE Associates", "IDE", datetime.date(1996, 11, 29)),
    "IDO": pnp.Vendor(u"IDEO Product Development", "IDO", datetime.date(1997, 9, 30)),
    "DEX": pnp.Vendor(u"idex displays", "DEX", datetime.date(2002, 4, 25)),
    "IDX": pnp.Vendor(u"IDEXX Labs", "IDX", datetime.date(1996, 11, 29)),
    "IDK": pnp.Vendor(u"IDK Corporation", "IDK", datetime.date(2003, 4, 16)),
    "IDN": pnp.Vendor(u"Idneo Technologies", "IDN", datetime.date(2012, 7, 5)),
    "ITS": pnp.Vendor(u"IDTECH", "ITS", datetime.date(2002, 6, 17)),
    "IEE": pnp.Vendor(u"IEE", "IEE", datetime.date(2001, 6, 21)),
    "IGM": pnp.Vendor(u"IGM Communi", "IGM", datetime.date(1996, 11, 29)),
    "IIN": pnp.Vendor(u"IINFRA Co., Ltd", "IIN", datetime.date(2003, 5, 9)),
    "IVM": pnp.Vendor(u"Iiyama North America", "IVM", datetime.date(1996, 11, 29)),
    "IKE": pnp.Vendor(u"Ikegami Tsushinki Co. Ltd.", "IKE", datetime.date(2014, 11, 14)),
    "IKS": pnp.Vendor(u"Ikos Systems Inc", "IKS", datetime.date(1996, 11, 29)),
    "IND": pnp.Vendor(u"ILC", "IND", datetime.date(2004, 6, 16)),
    "ILC": pnp.Vendor(u"Image Logic Corporation", "ILC", datetime.date(1996, 11, 29)),
    "ISM": pnp.Vendor(u"Image Stream Medical", "ISM", datetime.date(2010, 5, 27)),
    "IMG": pnp.Vendor(u"IMAGENICS Co., Ltd.", "IMG", datetime.date(2006, 9, 5)),
    "IQT": pnp.Vendor(u"IMAGEQUEST Co., Ltd", "IQT", datetime.date(2002, 10, 8)),
    "IME": pnp.Vendor(u"Imagraph", "IME", datetime.date(1996, 12, 4)),
    "IMA": pnp.Vendor(u"Imagraph", "IMA", datetime.date(1996, 11, 29)),
    "IMD": pnp.Vendor(u"ImasDe Canarias S.A.", "IMD", datetime.date(1997, 7, 3)),
    "IMC": pnp.Vendor(u"IMC Networks", "IMC", datetime.date(1996, 11, 29)),
    "IMM": pnp.Vendor(u"Immersion Corporation", "IMM", datetime.date(1997, 7, 16)),
    "HUM": pnp.Vendor(u"IMP Electronics Ltd.", "HUM", datetime.date(2004, 6, 16)),
    "IMP": pnp.Vendor(u"Impinj", "IMP", datetime.date(2012, 8, 14)),
    "IMN": pnp.Vendor(u"Impossible Production", "IMN", datetime.date(2000, 8, 10)),
    "IFS": pnp.Vendor(u"In Focus Systems Inc", "IFS", datetime.date(1996, 11, 29)),
    "ALD": pnp.Vendor(u"In4S Inc", "ALD", datetime.date(1997, 12, 5)),
    "IBI": pnp.Vendor(u"INBINE.CO.LTD", "IBI", datetime.date(2001, 11, 6)),
    "INK": pnp.Vendor(u"Indtek Co., Ltd.", "INK", datetime.date(2007, 3, 26)),
    "IQI": pnp.Vendor(u"IneoQuest Technologies, Inc", "IQI", datetime.date(2011, 2, 18)),
    "IPD": pnp.Vendor(u"Industrial Products Design, Inc.", "IPD", datetime.date(1999, 7, 16)),
    "INS": pnp.Vendor(u"Ines GmbH", "INS", datetime.date(1996, 11, 29)),
    "IFX": pnp.Vendor(u"Infineon Technologies AG", "IFX", datetime.date(2000, 4, 19)),
    "IFZ": pnp.Vendor(u"Infinite Z", "IFZ", datetime.date(2012, 1, 4)),
    "IIT": pnp.Vendor(u"Informatik Information Technologies", "IIT", datetime.date(2013, 8, 14)),
    "IFT": pnp.Vendor(u"Informtech", "IFT", datetime.date(1996, 11, 29)),
    "ICI": pnp.Vendor(u"Infotek Communication Inc", "ICI", datetime.date(1996, 11, 29)),
    "ITR": pnp.Vendor(u"Infotronic America, Inc.", "ITR", datetime.date(2001, 6, 21)),
    "INF": pnp.Vendor(u"Inframetrics Inc", "INF", datetime.date(1996, 11, 29)),
    "VSN": pnp.Vendor(u"Ingram Macrotron", "VSN", datetime.date(2000, 8, 10)),
    "VID": pnp.Vendor(u"Ingram Macrotron Germany", "VID", datetime.date(2000, 5, 24)),
    "IHE": pnp.Vendor(u"InHand Electronics", "IHE", datetime.date(2010, 4, 20)),
    "INI": pnp.Vendor(u"Initio Corporation", "INI", datetime.date(1996, 11, 29)),
    "IMT": pnp.Vendor(u"Inmax Technology Corporation", "IMT", datetime.date(2003, 2, 12)),
    "INO": pnp.Vendor(u"Innolab Pte Ltd", "INO", datetime.date(1999, 1, 20)),
    "INL": pnp.Vendor(u"InnoLux Display Corporation", "INL", datetime.date(2004, 12, 15)),
    "INM": pnp.Vendor(u"InnoMedia Inc", "INM", datetime.date(1996, 11, 29)),
    "ILS": pnp.Vendor(u"Innotech Corporation", "ILS", datetime.date(2000, 10, 23)),
    "ATE": pnp.Vendor(u"Innovate Ltd", "ATE", datetime.date(1996, 11, 29)),
    "INN": pnp.Vendor(u"Innovent Systems, Inc.", "INN", datetime.date(2000, 4, 19)),
    "WII": pnp.Vendor(u"Innoware Inc", "WII", datetime.date(1998, 1, 30)),
    "inu": pnp.Vendor(u"Inovatec S.p.A.", "inu", datetime.date(2001, 3, 15)),
    "ICV": pnp.Vendor(u"Inside Contactless", "ICV", datetime.date(2010, 11, 4)),
    "ION": pnp.Vendor(u"Inside Out Networks", "ION", datetime.date(1998, 12, 28)),
    "ISG": pnp.Vendor(u"Insignia Solutions Inc", "ISG", datetime.date(1996, 11, 29)),
    "ISR": pnp.Vendor(u"INSIS Co., LTD.", "ISR", datetime.date(2003, 2, 12)),
    "IAF": pnp.Vendor(u"Institut f r angewandte Funksystemtechnik GmbH", "IAF", datetime.date(1999, 3, 20)),
    "ING": pnp.Vendor(u"Integraph Corporation", "ING", datetime.date(1996, 11, 29)),
    "IBC": pnp.Vendor(u"Integrated Business Systems", "IBC", datetime.date(1996, 11, 29)),
    "IDP": pnp.Vendor(u"Integrated Device Technology, Inc.", "IDP", datetime.date(2010, 1, 27)),
    "ITE": pnp.Vendor(u"Integrated Tech Express Inc", "ITE", datetime.date(1996, 11, 29)),
    "SRC": pnp.Vendor(u"Integrated Tech Express Inc", "SRC", datetime.date(1996, 11, 29)),
    "ITX": pnp.Vendor(u"integrated Technology Express Inc", "ITX", datetime.date(1997, 6, 25)),
    "IAI": pnp.Vendor(u"Integration Associates, Inc.", "IAI", datetime.date(2004, 3, 17)),
    "ICO": pnp.Vendor(u"Intel Corp", "ICO", datetime.date(2000, 8, 10)),
    "III": pnp.Vendor(u"Intelligent Instrumentation", "III", datetime.date(1996, 11, 29)),
    "IPI": pnp.Vendor(u"Intelligent Platform Management Interface (IPMI) forum (Intel, HP, NEC, Dell)", "IPI", datetime.date(2000, 5, 24)),
    "IWX": pnp.Vendor(u"Intelliworxx, Inc.", "IWX", datetime.date(1999, 5, 16)),
    "SVC": pnp.Vendor(u"Intellix Corp.", "SVC", datetime.date(2008, 1, 18)),
    "TCH": pnp.Vendor(u"Interaction Systems, Inc", "TCH", datetime.date(1999, 3, 20)),
    "PEN": pnp.Vendor(u"Interactive Computer Products Inc", "PEN", datetime.date(1997, 1, 15)),
    "ITC": pnp.Vendor(u"Intercom Inc", "ITC", datetime.date(1996, 11, 29)),
    "IDS": pnp.Vendor(u"Interdigital Sistemas de Informacao", "IDS", datetime.date(1997, 10, 28)),
    "FBI": pnp.Vendor(u"Interface Corporation", "FBI", datetime.date(1996, 11, 29)),
    "ISI": pnp.Vendor(u"Interface Solutions", "ISI", datetime.date(1996, 11, 29)),
    "IGC": pnp.Vendor(u"Intergate Pty Ltd", "IGC", datetime.date(1996, 11, 29)),
    "IEC": pnp.Vendor(u"Interlace Engineering Corporation", "IEC", datetime.date(1996, 11, 29)),
    "IEI": pnp.Vendor(u"Interlink Electronics", "IEI", datetime.date(1998, 10, 16)),
    "IDC": pnp.Vendor(u"International Datacasting Corporation", "IDC", datetime.date(1997, 2, 25)),
    "IDT": pnp.Vendor(u"International Display Technology", "IDT", datetime.date(2002, 5, 16)),
    "ISY": pnp.Vendor(u"International Integrated Systems,Inc.(IISI)", "ISY", datetime.date(2000, 8, 10)),
    "IMI": pnp.Vendor(u"International Microsystems Inc", "IMI", datetime.date(1996, 11, 29)),
    "IPT": pnp.Vendor(u"International Power Technologies", "IPT", datetime.date(1997, 4, 11)),
    "ITD": pnp.Vendor(u"Internet Technology Corporation", "ITD", datetime.date(1997, 12, 5)),
    "INP": pnp.Vendor(u"Interphase Corporation", "INP", datetime.date(1996, 11, 29)),
    "INT": pnp.Vendor(u"Interphase Corporation", "INT", datetime.date(1996, 11, 29)),
    "LSD": pnp.Vendor(u"Intersil Corporation", "LSD", datetime.date(2012, 3, 14)),
    "IST": pnp.Vendor(u"Intersolve Technologies", "IST", datetime.date(1999, 3, 20)),
    "ITL": pnp.Vendor(u"Inter-Tel", "ITL", datetime.date(1997, 3, 21)),
    "IXD": pnp.Vendor(u"Intertex Data AB", "IXD", datetime.date(1996, 11, 29)),
    "IVI": pnp.Vendor(u"Intervoice Inc", "IVI", datetime.date(1996, 11, 29)),
    "IVS": pnp.Vendor(u"Intevac Photonics Inc.", "IVS", datetime.date(2011, 2, 16)),
    "ICM": pnp.Vendor(u"Intracom SA", "ICM", datetime.date(1998, 8, 3)),
    "SDD": pnp.Vendor(u"Intrada-SDD Ltd", "SDD", datetime.date(2007, 11, 21)),
    "ISP": pnp.Vendor(u"IntreSource Systems Pte Ltd", "ISP", datetime.date(1997, 8, 27)),
    "SRG": pnp.Vendor(u"Intuitive Surgical, Inc.", "SRG", datetime.date(2006, 2, 16)),
    "INA": pnp.Vendor(u"Inventec Corporation", "INA", datetime.date(2013, 9, 13)),
    "INE": pnp.Vendor(u"Inventec Electronics (M) Sdn. Bhd.", "INE", datetime.date(1998, 7, 21)),
    "INV": pnp.Vendor(u"Inviso, Inc.", "INV", datetime.date(2000, 10, 23)),
    "IOD": pnp.Vendor(u"I-O Data Device Inc", "IOD", datetime.date(1996, 11, 29)),
    "IOS": pnp.Vendor(u"i-O Display System", "IOS", datetime.date(2001, 3, 15)),
    "IOM": pnp.Vendor(u"Iomega", "IOM", datetime.date(1996, 11, 29)),
    "IPP": pnp.Vendor(u"IP Power Technologies GmbH", "IPP", datetime.date(2010, 12, 6)),
    "IPQ": pnp.Vendor(u"IP3 Technology Ltd.", "IPQ", datetime.date(2013, 11, 11)),
    "IPC": pnp.Vendor(u"IPC Corporation", "IPC", datetime.date(1996, 11, 29)),
    "IPM": pnp.Vendor(u"IPM Industria Politecnica Meridionale SpA", "IPM", datetime.date(1998, 9, 23)),
    "IPS": pnp.Vendor(u"IPS, Inc. (Intellectual Property Solutions, Inc.)", "IPS", datetime.date(2001, 9, 5)),
    "IPW": pnp.Vendor(u"IPWireless, Inc", "IPW", datetime.date(2001, 3, 15)),
    "IIC": pnp.Vendor(u"ISIC Innoscan Industrial Computers A/S", "IIC", datetime.date(2003, 7, 23)),
    "ISL": pnp.Vendor(u"Isolation Systems", "ISL", datetime.date(1996, 11, 29)),
    "ISS": pnp.Vendor(u"ISS Inc", "ISS", datetime.date(1996, 11, 29)),
    "ITA": pnp.Vendor(u"Itausa Export North America", "ITA", datetime.date(1996, 11, 29)),
    "IPR": pnp.Vendor(u"Ithaca Peripherals", "IPR", datetime.date(1997, 7, 1)),
    "ITK": pnp.Vendor(u"ITK Telekommunikation AG", "ITK", datetime.date(1996, 11, 29)),
    "ITM": pnp.Vendor(u"ITM inc.", "ITM", datetime.date(2001, 4, 24)),
    "ITP": pnp.Vendor(u"IT-PRO Consulting und Systemhaus GmbH", "ITP", datetime.date(2000, 10, 23)),
    "JCE": pnp.Vendor(u"Jace Tech Inc", "JCE", datetime.date(1996, 11, 29)),
    "JIC": pnp.Vendor(u"Jaeik Information & Communication Co., Ltd.", "JIC", datetime.date(2000, 10, 23)),
    "XFG": pnp.Vendor(u"Jan Strapko - FOTO", "XFG", datetime.date(2001, 5, 7)),
    "JUK": pnp.Vendor(u"Janich & Klass Computertechnik GmbH", "JUK", datetime.date(2002, 10, 8)),
    "JAS": pnp.Vendor(u"Janz Automationssysteme AG", "JAS", datetime.date(2009, 11, 3)),
    "JAE": pnp.Vendor(u"Japan Aviation Electronics Industry, Limited", "JAE", datetime.date(2001, 3, 15)),
    "JDL": pnp.Vendor(u"Japan Digital Laboratory Co.,Ltd.", "JDL", datetime.date(2000, 4, 19)),
    "JDI": pnp.Vendor(u"Japan Display Inc.", "JDI", datetime.date(2013, 4, 18)),
    "JAT": pnp.Vendor(u"Jaton Corporation", "JAT", datetime.date(1997, 9, 24)),
    "JET": pnp.Vendor(u"JET POWER TECHNOLOGY CO., LTD.", "JET", datetime.date(2001, 3, 15)),
    "JWY": pnp.Vendor(u"Jetway Information Co., Ltd", "JWY", datetime.date(2003, 9, 22)),
    "JTY": pnp.Vendor(u"jetway security micro,inc", "JTY", datetime.date(2009, 11, 11)),
    "SHI": pnp.Vendor(u"Jiangsu Shinco Electronic Group Co., Ltd", "SHI", datetime.date(2004, 8, 10)),
    "JFX": pnp.Vendor(u"Jones Futurex Inc", "JFX", datetime.date(1996, 11, 29)),
    "LTI": pnp.Vendor(u"Jongshine Tech Inc", "LTI", datetime.date(1996, 11, 29)),
    "HKG": pnp.Vendor(u"Josef Heim KG", "HKG", datetime.date(1996, 11, 29)),
    "JPC": pnp.Vendor(u"JPC Technology Limited", "JPC", datetime.date(2000, 10, 23)),
    "JSD": pnp.Vendor(u"JS DigiTech, Inc", "JSD", datetime.date(2000, 10, 23)),
    "JTS": pnp.Vendor(u"JS Motorsports", "JTS", datetime.date(1997, 12, 5)),
    "TPJ": pnp.Vendor(u"Junnila", "TPJ", datetime.date(2001, 3, 15)),
    "JUP": pnp.Vendor(u"Jupiter Systems", "JUP", datetime.date(2006, 9, 5)),
    "JSI": pnp.Vendor(u"Jupiter Systems, Inc.", "JSI", datetime.date(2007, 6, 14)),
    "JVC": pnp.Vendor(u"JVC", "JVC", datetime.date(2000, 10, 23)),
    "JKC": pnp.Vendor(u"JVC KENWOOD Corporation", "JKC", datetime.date(2012, 3, 8)),
    "JWS": pnp.Vendor(u"JWSpencer & Co.", "JWS", datetime.date(1999, 7, 16)),
    "SGE": pnp.Vendor(u"Kansai Electric Company Ltd", "SGE", datetime.date(1996, 12, 4)),
    "HIQ": pnp.Vendor(u"Kaohsiung Opto Electronics Americas, Inc.", "HIQ", datetime.date(2012, 3, 14)),
    "KSL": pnp.Vendor(u"Karn Solutions Ltd.", "KSL", datetime.date(2006, 5, 8)),
    "KAR": pnp.Vendor(u"Karna", "KAR", datetime.date(2000, 2, 21)),
    "KTN": pnp.Vendor(u"Katron Tech Inc", "KTN", datetime.date(1996, 11, 29)),
    "KTG": pnp.Vendor(u"Kayser-Threde GmbH", "KTG", datetime.date(1996, 11, 29)),
    "KDT": pnp.Vendor(u"KDDI Technology Corporation", "KDT", datetime.date(2012, 5, 22)),
    "KDE": pnp.Vendor(u"KDE", "KDE", datetime.date(2001, 8, 14)),
    "KDS": pnp.Vendor(u"KDS USA", "KDS", datetime.date(1996, 11, 29)),
    "KGL": pnp.Vendor(u"KEISOKU GIKEN Co.,Ltd.", "KGL", datetime.date(2012, 4, 17)),
    "KML": pnp.Vendor(u"Kensington Microware Ltd", "KML", datetime.date(1996, 11, 29)),
    "KWD": pnp.Vendor(u"Kenwood Corporation", "KWD", datetime.date(2008, 2, 22)),
    "EPS": pnp.Vendor(u"KEPS", "EPS", datetime.date(1996, 11, 29)),
    "KES": pnp.Vendor(u"Kesa Corporation", "KES", datetime.date(1996, 11, 29)),
    "KEY": pnp.Vendor(u"Key Tech Inc", "KEY", datetime.date(1996, 11, 29)),
    "KTK": pnp.Vendor(u"Key Tronic Corporation", "KTK", datetime.date(1996, 11, 29)),
    "KCL": pnp.Vendor(u"Keycorp Ltd", "KCL", datetime.date(1997, 5, 20)),
    "KVX": pnp.Vendor(u"KeyView", "KVX", datetime.date(2012, 8, 13)),
    "KBI": pnp.Vendor(u"Kidboard Inc", "KBI", datetime.date(1997, 4, 24)),
    "KME": pnp.Vendor(u"KIMIN Electronics Co., Ltd.", "KME", datetime.date(2011, 2, 15)),
    "KSC": pnp.Vendor(u"Kinetic Systems Corporation", "KSC", datetime.date(1996, 11, 29)),
    "KPC": pnp.Vendor(u"King Phoenix Company", "KPC", datetime.date(1996, 11, 29)),
    "KSX": pnp.Vendor(u"King Tester Corporation", "KSX", datetime.date(1998, 7, 16)),
    "KTC": pnp.Vendor(u"Kingston Tech Corporation", "KTC", datetime.date(1996, 11, 29)),
    "KIO": pnp.Vendor(u"Kionix, Inc.", "KIO", datetime.date(2013, 12, 23)),
    "KIS": pnp.Vendor(u"KiSS Technology A/S", "KIS", datetime.date(2005, 6, 16)),
    "PVP": pnp.Vendor(u"Klos Technologies, Inc.", "PVP", datetime.date(2000, 8, 10)),
    "KBL": pnp.Vendor(u"Kobil Systems GmbH", "KBL", datetime.date(2001, 3, 15)),
    "KOB": pnp.Vendor(u"Kobil Systems GmbH", "KOB", datetime.date(2001, 3, 15)),
    "KDK": pnp.Vendor(u"Kodiak Tech", "KDK", datetime.date(1996, 11, 29)),
    "KFX": pnp.Vendor(u"Kofax Image Products", "KFX", datetime.date(1996, 11, 29)),
    "KOL": pnp.Vendor(u"Kollmorgen Motion Technologies Group", "KOL", datetime.date(1996, 11, 29)),
    "KOE": pnp.Vendor(u"KOLTER ELECTRONIC", "KOE", datetime.date(2001, 3, 15)),
    "KFE": pnp.Vendor(u"Komatsu Forest", "KFE", datetime.date(2010, 4, 20)),
    "KNC": pnp.Vendor(u"Konica corporation", "KNC", datetime.date(1997, 8, 5)),
    "KTI": pnp.Vendor(u"Konica Technical Inc", "KTI", datetime.date(1996, 11, 29)),
    "TWE": pnp.Vendor(u"Kontron Electronik", "TWE", datetime.date(1996, 11, 29)),
    "KEM": pnp.Vendor(u"Kontron Embedded Modules GmbH", "KEM", datetime.date(2007, 8, 29)),
    "KEU": pnp.Vendor(u"Kontron Europe GmbH", "KEU", datetime.date(2014, 2, 20)),
    "KDM": pnp.Vendor(u"Korea Data Systems Co., Ltd.", "KDM", datetime.date(2003, 12, 18)),
    "KOU": pnp.Vendor(u"KOUZIRO Co.,Ltd.", "KOU", datetime.date(2012, 7, 27)),
    "KOW": pnp.Vendor(u"KOWA Company,LTD.", "KOW", datetime.date(2008, 3, 12)),
    "KMR": pnp.Vendor(u"Kramer Electronics Ltd. International", "KMR", datetime.date(2013, 7, 10)),
    "KRL": pnp.Vendor(u"Krell Industries Inc.", "KRL", datetime.date(2004, 8, 3)),
    "KRM": pnp.Vendor(u"Kroma Telecom", "KRM", datetime.date(2010, 5, 5)),
    "KRY": pnp.Vendor(u"Kroy LLC", "KRY", datetime.date(1998, 7, 16)),
    "KTE": pnp.Vendor(u"K-Tech", "KTE", datetime.date(2003, 3, 31)),
    "KSG": pnp.Vendor(u"KUPA China Shenzhen Micro Technology Co., Ltd. Gold Institute", "KSG", datetime.date(2014, 4, 22)),
    "KUR": pnp.Vendor(u"Kurta Corporation", "KUR", datetime.date(1996, 11, 29)),
    "KVA": pnp.Vendor(u"Kvaser AB", "KVA", datetime.date(1997, 1, 24)),
    "KYE": pnp.Vendor(u"KYE Syst Corporation", "KYE", datetime.date(1996, 11, 29)),
    "KYC": pnp.Vendor(u"Kyocera Corporation", "KYC", datetime.date(1996, 11, 29)),
    "KEC": pnp.Vendor(u"Kyushu Electronics Systems Inc", "KEC", datetime.date(1998, 1, 12)),
    "KZN": pnp.Vendor(u"K-Zone International", "KZN", datetime.date(2001, 6, 21)),
    "KZI": pnp.Vendor(u"K-Zone International co. Ltd.", "KZI", datetime.date(2000, 8, 10)),
    "LLL": pnp.Vendor(u"L-3 Communications", "LLL", datetime.date(2010, 5, 11)),
    "LCE": pnp.Vendor(u"La Commande Electronique", "LCE", datetime.date(1996, 11, 29)),
    "LCT": pnp.Vendor(u"Labcal Technologies", "LCT", datetime.date(1999, 11, 8)),
    "LTC": pnp.Vendor(u"Labtec Inc", "LTC", datetime.date(1997, 12, 8)),
    "LWC": pnp.Vendor(u"Labway Corporation", "LWC", datetime.date(1996, 12, 4)),
    "LAC": pnp.Vendor(u"LaCie", "LAC", datetime.date(1998, 12, 28)),
    "LAG": pnp.Vendor(u"Laguna Systems", "LAG", datetime.date(1996, 11, 29)),
    "LND": pnp.Vendor(u"Land Computer Company Ltd", "LND", datetime.date(1996, 11, 29)),
    "LNT": pnp.Vendor(u"LANETCO International", "LNT", datetime.date(2003, 5, 2)),
    "LWW": pnp.Vendor(u"Lanier Worldwide", "LWW", datetime.date(1996, 11, 29)),
    "LHA": pnp.Vendor(u"Lars Haagh ApS", "LHA", datetime.date(1997, 1, 9)),
    "LAS": pnp.Vendor(u"LASAT Comm. A/S", "LAS", datetime.date(1996, 11, 29)),
    "LMT": pnp.Vendor(u"Laser Master", "LMT", datetime.date(1996, 11, 29)),
    "LDN": pnp.Vendor(u"Laserdyne Technologies", "LDN", datetime.date(2013, 10, 16)),
    "LGX": pnp.Vendor(u"Lasergraphics, Inc.", "LGX", datetime.date(2000, 2, 21)),
    "LCM": pnp.Vendor(u"Latitude Comm.", "LCM", datetime.date(1996, 11, 29)),
    "LAV": pnp.Vendor(u"Lava Computer MFG Inc", "LAV", datetime.date(1997, 4, 14)),
    "LCC": pnp.Vendor(u"LCI", "LCC", datetime.date(2000, 8, 10)),
    "LEC": pnp.Vendor(u"Lectron Company Ltd", "LEC", datetime.date(1997, 3, 27)),
    "LMP": pnp.Vendor(u"Leda Media Products", "LMP", datetime.date(1998, 5, 11)),
    "LEG": pnp.Vendor(u"Legerity, Inc", "LEG", datetime.date(2005, 1, 18)),
    "LTV": pnp.Vendor(u"Leitch Technology International Inc.", "LTV", datetime.date(2003, 12, 9)),
    "LNV": pnp.Vendor(u"Lenovo", "LNV", datetime.date(2005, 7, 14)),
    "LIN": pnp.Vendor(u"Lenovo Beijing Co. Ltd.", "LIN", datetime.date(2012, 5, 22)),
    "LEN": pnp.Vendor(u"Lenovo Group Limited", "LEN", datetime.date(2005, 6, 3)),
    "LEX": pnp.Vendor(u"Lexical Ltd", "LEX", datetime.date(1996, 11, 29)),
    "LCN": pnp.Vendor(u"LEXICON", "LCN", datetime.date(2005, 3, 1)),
    "PRS": pnp.Vendor(u"Leutron Vision", "PRS", datetime.date(1996, 11, 29)),
    "LMI": pnp.Vendor(u"Lexmark Int'l Inc", "LMI", datetime.date(1996, 11, 29)),
    "LGS": pnp.Vendor(u"LG Semicom Company Ltd", "LGS", datetime.date(1996, 11, 29)),
    "MAN": pnp.Vendor(u"LGIC", "MAN", datetime.date(2000, 2, 21)),
    "LSC": pnp.Vendor(u"LifeSize Communications", "LSC", datetime.date(2006, 2, 14)),
    "LHT": pnp.Vendor(u"Lighthouse Technologies Limited", "LHT", datetime.date(2010, 5, 4)),
    "LWR": pnp.Vendor(u"Lightware Visual Engineering", "LWR", datetime.date(2009, 2, 4)),
    "LTW": pnp.Vendor(u"Lightware, Inc", "LTW", datetime.date(1998, 10, 16)),
    "LZX": pnp.Vendor(u"Lightwell Company Ltd", "LZX", datetime.date(1997, 12, 2)),
    "LKM": pnp.Vendor(u"Likom Technology Sdn. Bhd.", "LKM", datetime.date(1998, 4, 23)),
    "LNR": pnp.Vendor(u"Linear Systems Ltd.", "LNR", datetime.date(2007, 10, 11)),
    "LNK": pnp.Vendor(u"Link Tech Inc", "LNK", datetime.date(1996, 11, 29)),
    "LIP": pnp.Vendor(u"Linked IP GmbH", "LIP", datetime.date(2010, 7, 19)),
    "FGD": pnp.Vendor(u"Lisa Draexlmaier GmbH", "FGD", datetime.date(1999, 2, 22)),
    "LOL": pnp.Vendor(u"Litelogic Operations Ltd", "LOL", datetime.date(2011, 12, 9)),
    "LCI": pnp.Vendor(u"Lite-On Communication Inc", "LCI", datetime.date(1996, 11, 29)),
    "LIT": pnp.Vendor(u"Lithics Silicon Technology", "LIT", datetime.date(2001, 3, 15)),
    "LTN": pnp.Vendor(u"Litronic Inc", "LTN", datetime.date(1998, 2, 3)),
    "LOC": pnp.Vendor(u"Locamation B.V.", "LOC", datetime.date(2004, 1, 9)),
    "LOE": pnp.Vendor(u"Loewe Opta GmbH", "LOE", datetime.date(2005, 5, 2)),
    "LGC": pnp.Vendor(u"Logic Ltd", "LGC", datetime.date(1994, 4, 2)),
    "LSL": pnp.Vendor(u"Logical Solutions", "LSL", datetime.date(1996, 11, 29)),
    "LOG": pnp.Vendor(u"Logicode Technology Inc", "LOG", datetime.date(1996, 11, 29)),
    "LGI": pnp.Vendor(u"Logitech Inc", "LGI", datetime.date(1996, 11, 29)),
    "LDT": pnp.Vendor(u"LogiDataTech Electronic GmbH", "LDT", datetime.date(2001, 3, 15)),
    "SGO": pnp.Vendor(u"Logos Design A/S", "SGO", datetime.date(2001, 4, 24)),
    "LED": pnp.Vendor(u"Long Engineering Design Inc", "LED", datetime.date(1996, 11, 29)),
    "LCS": pnp.Vendor(u"Longshine Electronics Company", "LCS", datetime.date(1996, 11, 29)),
    "LSI": pnp.Vendor(u"Loughborough Sound Images", "LSI", datetime.date(1996, 11, 29)),
    "LSJ": pnp.Vendor(u"LSI Japan Company Ltd", "LSJ", datetime.date(1996, 11, 29)),
    "LSY": pnp.Vendor(u"LSI Systems Inc", "LSY", datetime.date(1996, 11, 29)),
    "LTS": pnp.Vendor(u"LTS Scale LLC", "LTS", datetime.date(2007, 11, 15)),
    "LBO": pnp.Vendor(u"Lubosoft", "LBO", datetime.date(2001, 4, 24)),
    "LUC": pnp.Vendor(u"Lucent Technologies", "LUC", datetime.date(2000, 4, 19)),
    "LMG": pnp.Vendor(u"Lucent Technologies", "LMG", datetime.date(1997, 1, 13)),
    "LTK": pnp.Vendor(u"Lucidity Technology Company Ltd", "LTK", datetime.date(1998, 5, 18)),
    "LUM": pnp.Vendor(u"Lumagen, Inc.", "LUM", datetime.date(2004, 8, 12)),
    "LHE": pnp.Vendor(u"Lung Hwa Electronics Company Ltd", "LHE", datetime.date(1998, 6, 12)),
    "LXN": pnp.Vendor(u"Luxeon", "LXN", datetime.date(2001, 3, 15)),
    "LUX": pnp.Vendor(u"Luxxell Research Inc", "LUX", datetime.date(1997, 6, 9)),
    "LVI": pnp.Vendor(u"LVI Low Vision International AB", "LVI", datetime.date(2011, 1, 21)),
    "LXC": pnp.Vendor(u"LXCO Technologies AG", "LXC", datetime.date(2012, 1, 11)),
    "MAC": pnp.Vendor(u"MAC System Company Ltd", "MAC", datetime.date(1997, 9, 26)),
    "MEJ": pnp.Vendor(u"Mac-Eight Co., LTD.", "MEJ", datetime.date(2011, 1, 19)),
    "OCD": pnp.Vendor(u"Macraigor Systems Inc", "OCD", datetime.date(1998, 3, 23)),
    "VHI": pnp.Vendor(u"Macrocad Development Inc.", "VHI", datetime.date(2000, 4, 19)),
    "MXI": pnp.Vendor(u"Macronix Inc", "MXI", datetime.date(1996, 11, 29)),
    "MDG": pnp.Vendor(u"Madge Networks", "MDG", datetime.date(1996, 11, 29)),
    "MAE": pnp.Vendor(u"Maestro Pty Ltd", "MAE", datetime.date(1996, 12, 4)),
    "MAG": pnp.Vendor(u"MAG InnoVision", "MAG", datetime.date(1996, 11, 29)),
    "MLP": pnp.Vendor(u"Magic Leap", "MLP", datetime.date(2014, 11, 14)),
    "MCP": pnp.Vendor(u"Magni Systems Inc", "MCP", datetime.date(1996, 11, 29)),
    "EKA": pnp.Vendor(u"MagTek Inc.", "EKA", datetime.date(2006, 2, 14)),
    "MDT": pnp.Vendor(u"Magus Data Tech", "MDT", datetime.date(1996, 11, 29)),
    "MPN": pnp.Vendor(u"Mainpine Limited", "MPN", datetime.date(2007, 6, 30)),
    "MUK": pnp.Vendor(u"Mainpine Limited", "MUK", datetime.date(1999, 9, 13)),
    "PAK": pnp.Vendor(u"Many CNC System Co., Ltd.", "PAK", datetime.date(2004, 3, 12)),
    "MPL": pnp.Vendor(u"Maple Research Inst. Company Ltd", "MPL", datetime.date(1996, 11, 29)),
    "MJI": pnp.Vendor(u"MARANTZ JAPAN, INC.", "MJI", datetime.date(2000, 10, 23)),
    "MIL": pnp.Vendor(u"Marconi Instruments Ltd", "MIL", datetime.date(1996, 11, 29)),
    "MRC": pnp.Vendor(u"Marconi Simulation & Ty-Coch Way Training", "MRC", datetime.date(1996, 11, 29)),
    "MCR": pnp.Vendor(u"Marina Communicaitons", "MCR", datetime.date(1996, 11, 29)),
    "MLN": pnp.Vendor(u"Mark Levinson", "MLN", datetime.date(2005, 2, 28)),
    "MTU": pnp.Vendor(u"Mark of the Unicorn Inc", "MTU", datetime.date(1997, 3, 21)),
    "MNI": pnp.Vendor(u"Marseille, Inc.", "MNI", datetime.date(2013, 2, 27)),
    "MBM": pnp.Vendor(u"Marshall Electronics", "MBM", datetime.date(2006, 3, 13)),
    "MTC": pnp.Vendor(u"Mars-Tech Corporation", "MTC", datetime.date(1996, 11, 29)),
    "MRK": pnp.Vendor(u"Maruko & Company Ltd", "MRK", datetime.date(1996, 11, 29)),
    "MSR": pnp.Vendor(u"MASPRO DENKOH Corp.", "MSR", datetime.date(2012, 10, 25)),
    "MAS": pnp.Vendor(u"Mass Inc.", "MAS", datetime.date(2002, 2, 25)),
    "MEQ": pnp.Vendor(u"Matelect Ltd.", "MEQ", datetime.date(2002, 5, 30)),
    "MTX": pnp.Vendor(u"Matrox", "MTX", datetime.date(1996, 11, 29)),
    "MCQ": pnp.Vendor(u"Mat's Computers", "MCQ", datetime.date(2004, 7, 22)),
    "WPA": pnp.Vendor(u"Matsushita Communication Industrial Co., Ltd.", "WPA", datetime.date(2001, 3, 15)),
    "MAT": pnp.Vendor(u"Matsushita Electric Ind. Company Ltd", "MAT", datetime.date(1996, 11, 29)),
    "MTI": pnp.Vendor(u"MaxCom Technical Inc", "MTI", datetime.date(1996, 11, 29)),
    "VOB": pnp.Vendor(u"MaxData Computer AG", "VOB", datetime.date(2000, 2, 21)),
    "MXD": pnp.Vendor(u"MaxData Computer GmbH & Co.KG", "MXD", datetime.date(2000, 4, 19)),
    "MXP": pnp.Vendor(u"Maxpeed Corporation", "MXP", datetime.date(1997, 2, 19)),
    "MXT": pnp.Vendor(u"Maxtech Corporation", "MXT", datetime.date(1996, 11, 29)),
    "MXV": pnp.Vendor(u"MaxVision Corporation", "MXV", datetime.date(1999, 7, 16)),
    "DJP": pnp.Vendor(u"Maygay Machines, Ltd", "DJP", datetime.date(2000, 8, 10)),
    "MAY": pnp.Vendor(u"Maynard Electronics", "MAY", datetime.date(1996, 11, 29)),
    "MAZ": pnp.Vendor(u"MAZeT GmbH", "MAZ", datetime.date(1998, 8, 11)),
    "MBC": pnp.Vendor(u"MBC", "MBC", datetime.date(1996, 11, 29)),
    "MCD": pnp.Vendor(u"McDATA Corporation", "MCD", datetime.date(1996, 11, 29)),
    "MLI": pnp.Vendor(u"McIntosh Laboratory Inc.", "MLI", datetime.date(2008, 1, 18)),
    "MIT": pnp.Vendor(u"MCM Industrial Technology GmbH", "MIT", datetime.date(2004, 10, 29)),
    "CEM": pnp.Vendor(u"MEC Electronics GmbH", "CEM", datetime.date(2000, 4, 19)),
    "MDR": pnp.Vendor(u"Medar Inc", "MDR", datetime.date(1996, 12, 11)),
    "MTB": pnp.Vendor(u"Media Technologies Ltd.", "MTB", datetime.date(2009, 1, 5)),
    "MKC": pnp.Vendor(u"Media Tek Inc.", "MKC", datetime.date(2007, 6, 14)),
    "MVI": pnp.Vendor(u"Media Vision Inc", "MVI", datetime.date(1996, 11, 29)),
    "MDA": pnp.Vendor(u"Media4 Inc", "MDA", datetime.date(1997, 3, 20)),
    "OWL": pnp.Vendor(u"Mediacom Technologies Pte Ltd", "OWL", datetime.date(1996, 11, 29)),
    "MEK": pnp.Vendor(u"Mediaedge Corporation", "MEK", datetime.date(2013, 11, 19)),
    "MFR": pnp.Vendor(u"MediaFire Corp.", "MFR", datetime.date(1998, 12, 28)),
    "FTR": pnp.Vendor(u"Mediasonic", "FTR", datetime.date(1996, 11, 29)),
    "MTE": pnp.Vendor(u"MediaTec GmbH", "MTE", datetime.date(1996, 12, 13)),
    "MDK": pnp.Vendor(u"Mediatek Corporation", "MDK", datetime.date(1997, 3, 13)),
    "MPI": pnp.Vendor(u"Mediatrix Peripherals Inc", "MPI", datetime.date(1997, 4, 24)),
    "MRO": pnp.Vendor(u"Medikro Oy", "MRO", datetime.date(1997, 9, 19)),
    "MEC": pnp.Vendor(u"Mega System Technologies Inc", "MEC", datetime.date(1997, 12, 29)),
    "MGA": pnp.Vendor(u"Mega System Technologies, Inc.", "MGA", datetime.date(1998, 12, 28)),
    "MSK": pnp.Vendor(u"Megasoft Inc", "MSK", datetime.date(1996, 11, 29)),
    "MGT": pnp.Vendor(u"Megatech R & D Company", "MGT", datetime.date(1996, 11, 29)),
    "MEP": pnp.Vendor(u"Meld Technology", "MEP", datetime.date(2012, 8, 16)),
    "MEN": pnp.Vendor(u"MEN Mikroelectronik Nueruberg GmbH", "MEN", datetime.date(1997, 5, 23)),
    "MGC": pnp.Vendor(u"Mentor Graphics Corporation", "MGC", datetime.date(2009, 7, 30)),
    "RLD": pnp.Vendor(u"MEPCO", "RLD", datetime.date(2001, 3, 15)),
    "PPD": pnp.Vendor(u"MEPhI", "PPD", datetime.date(1998, 11, 27)),
    "MRT": pnp.Vendor(u"Merging Technologies", "MRT", datetime.date(1996, 11, 29)),
    "MAL": pnp.Vendor(u"Meridian Audio Ltd", "MAL", datetime.date(2009, 2, 4)),
    "MED": pnp.Vendor(u"Messeltronik Dresden GmbH", "MED", datetime.date(1996, 11, 29)),
    "MDV": pnp.Vendor(u"MET Development Inc", "MDV", datetime.date(1996, 11, 29)),
    "MTA": pnp.Vendor(u"Meta Watch Ltd", "MTA", datetime.date(2013, 8, 29)),
    "MET": pnp.Vendor(u"Metheus Corporation", "MET", datetime.date(1996, 11, 29)),
    "MCM": pnp.Vendor(u"Metricom Inc", "MCM", datetime.date(1996, 11, 29)),
    "QCH": pnp.Vendor(u"Metronics Inc", "QCH", datetime.date(1996, 11, 29)),
    "NET": pnp.Vendor(u"Mettler Toledo", "NET", datetime.date(1996, 11, 29)),
    "MCE": pnp.Vendor(u"Metz-Werke GmbH & Co KG", "MCE", datetime.date(2005, 6, 30)),
    "MGL": pnp.Vendor(u"M-G Technology Ltd", "MGL", datetime.date(1997, 10, 29)),
    "MIC": pnp.Vendor(u"Micom Communications Inc", "MIC", datetime.date(1997, 5, 5)),
    "MSX": pnp.Vendor(u"Micomsoft Co., Ltd.", "MSX", datetime.date(2008, 4, 10)),
    "MCS": pnp.Vendor(u"Micro Computer Systems", "MCS", datetime.date(1996, 11, 29)),
    "MDI": pnp.Vendor(u"Micro Design Inc", "MDI", datetime.date(1998, 1, 20)),
    "MDS": pnp.Vendor(u"Micro Display Systems Inc", "MDS", datetime.date(1996, 11, 29)),
    "MFI": pnp.Vendor(u"Micro Firmware", "MFI", datetime.date(1997, 12, 30)),
    "MCC": pnp.Vendor(u"Micro Industries", "MCC", datetime.date(2003, 4, 21)),
    "BPD": pnp.Vendor(u"Micro Solutions, Inc.", "BPD", datetime.date(2000, 4, 19)),
    "MSA": pnp.Vendor(u"Micro Systemation AB", "MSA", datetime.date(1999, 11, 8)),
    "JMT": pnp.Vendor(u"Micro Technical Company Ltd", "JMT", datetime.date(1996, 11, 29)),
    "MBD": pnp.Vendor(u"Microbus PLC", "MBD", datetime.date(2002, 8, 13)),
    "MNP": pnp.Vendor(u"Microcom", "MNP", datetime.date(1996, 11, 29)),
    "MDX": pnp.Vendor(u"MicroDatec GmbH", "MDX", datetime.date(1999, 9, 13)),
    "MRD": pnp.Vendor(u"MicroDisplay Corporation", "MRD", datetime.date(2007, 6, 14)),
    "MDY": pnp.Vendor(u"Microdyne Inc", "MDY", datetime.date(1996, 12, 18)),
    "MFG": pnp.Vendor(u"MicroField Graphics Inc", "MFG", datetime.date(1996, 11, 29)),
    "MPJ": pnp.Vendor(u"Microlab", "MPJ", datetime.date(1997, 5, 23)),
    "LAF": pnp.Vendor(u"Microline", "LAF", datetime.date(1999, 9, 13)),
    "MLG": pnp.Vendor(u"Micrologica AG", "MLG", datetime.date(1998, 10, 6)),
    "MMD": pnp.Vendor(u"Micromed Biotecnologia Ltd", "MMD", datetime.date(1996, 12, 11)),
    "MMA": pnp.Vendor(u"Micromedia AG", "MMA", datetime.date(1997, 4, 24)),
    "MCN": pnp.Vendor(u"Micron Electronics Inc", "MCN", datetime.date(1997, 2, 20)),
    "MCI": pnp.Vendor(u"Micronics Computers", "MCI", datetime.date(1996, 11, 29)),
    "MIP": pnp.Vendor(u"micronpc.com", "MIP", datetime.date(2000, 8, 10)),
    "MYX": pnp.Vendor(u"Micronyx Inc", "MYX", datetime.date(1996, 11, 29)),
    "MPX": pnp.Vendor(u"Micropix Technologies, Ltd.", "MPX", datetime.date(2001, 10, 8)),
    "MSL": pnp.Vendor(u"MicroSlate Inc.", "MSL", datetime.date(1999, 5, 16)),
    "PNP": pnp.Vendor(u"Microsoft", "PNP", datetime.date(2004, 3, 5)),
    "MSH": pnp.Vendor(u"Microsoft", "MSH", datetime.date(1996, 11, 29)),
    "PNG": pnp.Vendor(u"Microsoft", "PNG", datetime.date(1996, 11, 29)),
    "WBN": pnp.Vendor(u"MicroSoftWare", "WBN", datetime.date(1998, 1, 14)),
    "MSI": pnp.Vendor(u"Microstep", "MSI", datetime.date(1996, 11, 29)),
    "MCT": pnp.Vendor(u"Microtec", "MCT", datetime.date(1996, 11, 29)),
    "MTH": pnp.Vendor(u"Micro-Tech Hearing Instruments", "MTH", datetime.date(1997, 12, 15)),
    "MKT": pnp.Vendor(u"MICROTEK Inc.", "MKT", datetime.date(2005, 7, 14)),
    "MTK": pnp.Vendor(u"Microtek International Inc.", "MTK", datetime.date(2002, 2, 25)),
    "MSY": pnp.Vendor(u"MicroTouch Systems Inc", "MSY", datetime.date(2000, 8, 10)),
    "MVS": pnp.Vendor(u"Microvision", "MVS", datetime.date(2009, 2, 13)),
    "MVD": pnp.Vendor(u"Microvitec PLC", "MVD", datetime.date(1996, 11, 29)),
    "MWY": pnp.Vendor(u"Microway Inc", "MWY", datetime.date(1996, 11, 29)),
    "MDC": pnp.Vendor(u"Midori Electronics", "MDC", datetime.date(1996, 11, 29)),
    "SFT": pnp.Vendor(u"Mikroforum Ring 3", "SFT", datetime.date(2004, 11, 2)),
    "MLS": pnp.Vendor(u"Milestone EPE", "MLS", datetime.date(1998, 8, 11)),
    "MLM": pnp.Vendor(u"Millennium Engineering Inc", "MLM", datetime.date(1996, 11, 29)),
    "MLL": pnp.Vendor(u"Millogic Ltd.", "MLL", datetime.date(2014, 1, 9)),
    "MCX": pnp.Vendor(u"Millson Custom Solutions Inc.", "MCX", datetime.date(2013, 10, 17)),
    "VTM": pnp.Vendor(u"Miltope Corporation", "VTM", datetime.date(2009, 9, 23)),
    "MIM": pnp.Vendor(u"Mimio \u2013 A Newell Rubbermaid Company", "MIM", datetime.date(2012, 7, 31)),
    "MTD": pnp.Vendor(u"MindTech Display Co. Ltd", "MTD", datetime.date(2007, 6, 14)),
    "FTW": pnp.Vendor(u"MindTribe Product Engineering, Inc.", "FTW", datetime.date(2011, 2, 14)),
    "MNC": pnp.Vendor(u"Mini Micro Methods Ltd", "MNC", datetime.date(1996, 11, 29)),
    "MIN": pnp.Vendor(u"Minicom Digital Signage", "MIN", datetime.date(2010, 8, 13)),
    "MMN": pnp.Vendor(u"MiniMan Inc", "MMN", datetime.date(1996, 11, 29)),
    "MMF": pnp.Vendor(u"Minnesota Mining and Manufacturing", "MMF", datetime.date(2001, 3, 15)),
    "MRA": pnp.Vendor(u"Miranda Technologies Inc", "MRA", datetime.date(1996, 11, 29)),
    "MRL": pnp.Vendor(u"Miratel", "MRL", datetime.date(1998, 10, 16)),
    "MIR": pnp.Vendor(u"Miro Computer Prod.", "MIR", datetime.date(1996, 11, 29)),
    "MID": pnp.Vendor(u"miro Displays", "MID", datetime.date(1999, 3, 20)),
    "MSP": pnp.Vendor(u"Mistral Solutions [P] Ltd.", "MSP", datetime.date(1998, 9, 23)),
    "MII": pnp.Vendor(u"Mitec Inc", "MII", datetime.date(1996, 11, 29)),
    "MTL": pnp.Vendor(u"Mitel Corporation", "MTL", datetime.date(1997, 8, 1)),
    "MTR": pnp.Vendor(u"Mitron computer Inc", "MTR", datetime.date(1996, 11, 29)),
    "MEL": pnp.Vendor(u"Mitsubishi Electric Corporation", "MEL", datetime.date(1996, 11, 29)),
    "MEE": pnp.Vendor(u"Mitsubishi Electric Engineering Co., Ltd.", "MEE", datetime.date(2005, 10, 3)),
    "KMC": pnp.Vendor(u"Mitsumi Company Ltd", "KMC", datetime.date(1996, 11, 29)),
    "MJS": pnp.Vendor(u"MJS Designs", "MJS", datetime.date(1996, 11, 29)),
    "MKS": pnp.Vendor(u"MK Seiko Co., Ltd.", "MKS", datetime.date(2013, 6, 18)),
    "OHW": pnp.Vendor(u"M-Labs Limited", "OHW", datetime.date(2013, 11, 27)),
    "MMS": pnp.Vendor(u"MMS Electronics", "MMS", datetime.date(1998, 2, 24)),
    "FST": pnp.Vendor(u"Modesto PC Inc", "FST", datetime.date(1997, 2, 27)),
    "MDD": pnp.Vendor(u"MODIS", "MDD", datetime.date(1999, 11, 8)),
    "MIS": pnp.Vendor(u"Modular Industrial Solutions Inc", "MIS", datetime.date(1996, 11, 29)),
    "MOD": pnp.Vendor(u"Modular Technology", "MOD", datetime.date(1997, 6, 9)),
    "MOM": pnp.Vendor(u"Momentum Data Systems", "MOM", datetime.date(2008, 1, 18)),
    "MNL": pnp.Vendor(u"Monorail Inc", "MNL", datetime.date(1997, 2, 18)),
    "MYA": pnp.Vendor(u"Monydata", "MYA", datetime.date(1996, 11, 29)),
    "MBV": pnp.Vendor(u"Moreton Bay", "MBV", datetime.date(2000, 1, 13)),
    "MOS": pnp.Vendor(u"Moses Corporation", "MOS", datetime.date(1996, 11, 29)),
    "MSV": pnp.Vendor(u"Mosgi Corporation", "MSV", datetime.date(1996, 11, 29)),
    "MCO": pnp.Vendor(u"Motion Computing Inc.", "MCO", datetime.date(2002, 5, 30)),
    "MTM": pnp.Vendor(u"Motium", "MTM", datetime.date(2012, 6, 19)),
    "MSU": pnp.Vendor(u"motorola", "MSU", datetime.date(2001, 3, 15)),
    "MCL": pnp.Vendor(u"Motorola Communications Israel", "MCL", datetime.date(2002, 7, 2)),
    "MCG": pnp.Vendor(u"Motorola Computer Group", "MCG", datetime.date(1997, 8, 14)),
    "MOT": pnp.Vendor(u"Motorola UDS", "MOT", datetime.date(1996, 11, 29)),
    "MSC": pnp.Vendor(u"Mouse Systems Corporation", "MSC", datetime.date(1996, 11, 29)),
    "MPC": pnp.Vendor(u"M-Pact Inc", "MPC", datetime.date(1996, 11, 29)),
    "MPS": pnp.Vendor(u"mps Software GmbH", "MPS", datetime.date(1996, 11, 29)),
    "MST": pnp.Vendor(u"MS Telematica", "MST", datetime.date(1997, 4, 28)),
    "MEX": pnp.Vendor(u"MSC Vertriebs GmbH", "MEX", datetime.date(2012, 6, 4)),
    "MSG": pnp.Vendor(u"MSI GmbH", "MSG", datetime.date(1999, 9, 13)),
    "MSF": pnp.Vendor(u"M-Systems Flash Disk Pioneers", "MSF", datetime.date(1997, 12, 17)),
    "MTN": pnp.Vendor(u"Mtron Storage Technology Co., Ltd.", "MTN", datetime.date(2008, 6, 17)),
    "MUD": pnp.Vendor(u"Multi-Dimension Institute", "MUD", datetime.date(2000, 10, 23)),
    "MMI": pnp.Vendor(u"Multimax", "MMI", datetime.date(1996, 11, 29)),
    "MTS": pnp.Vendor(u"Multi-Tech Systems", "MTS", datetime.date(1996, 11, 29)),
    "MWI": pnp.Vendor(u"Multiwave Innovation Pte Ltd", "MWI", datetime.date(1996, 11, 29)),
    "MAI": pnp.Vendor(u"Mutoh America Inc", "MAI", datetime.date(1999, 9, 13)),
    "MWR": pnp.Vendor(u"mware", "MWR", datetime.date(2001, 4, 24)),
    "MLX": pnp.Vendor(u"Mylex Corporation", "MLX", datetime.date(1996, 11, 29)),
    "MYR": pnp.Vendor(u"Myriad Solutions Ltd", "MYR", datetime.date(1996, 11, 29)),
    "WYS": pnp.Vendor(u"Myse Technology", "WYS", datetime.date(1996, 11, 29)),
    "NBL": pnp.Vendor(u"N*Able Technologies Inc", "NBL", datetime.date(1998, 4, 28)),
    "NAD": pnp.Vendor(u"NAD Electronics", "NAD", datetime.date(2007, 6, 14)),
    "NDK": pnp.Vendor(u"Naitoh Densei CO., LTD.", "NDK", datetime.date(2006, 4, 12)),
    "NCP": pnp.Vendor(u"Najing CEC Panda FPD Technology CO. ltd", "NCP", datetime.date(2015, 2, 24)),
    "NAK": pnp.Vendor(u"Nakano Engineering Co.,Ltd.", "NAK", datetime.date(2009, 7, 22)),
    "NYC": pnp.Vendor(u"Nakayo Relecommunications, Inc.", "NYC", datetime.date(2000, 8, 10)),
    "SCS": pnp.Vendor(u"Nanomach Anstalt", "SCS", datetime.date(1996, 11, 29)),
    "ADR": pnp.Vendor(u"Nasa Ames Research Center", "ADR", datetime.date(1996, 11, 29)),
    "NDC": pnp.Vendor(u"National DataComm Corporaiton", "NDC", datetime.date(1996, 11, 29)),
    "NDI": pnp.Vendor(u"National Display Systems", "NDI", datetime.date(2003, 8, 8)),
    "NIC": pnp.Vendor(u"National Instruments Corporation", "NIC", datetime.date(1996, 11, 29)),
    "NBS": pnp.Vendor(u"National Key Lab. on ISN", "NBS", datetime.date(1998, 7, 16)),
    "NSC": pnp.Vendor(u"National Semiconductor Corporation", "NSC", datetime.date(1996, 11, 29)),
    "TTB": pnp.Vendor(u"National Semiconductor Japan Ltd", "TTB", datetime.date(1997, 4, 14)),
    "NTL": pnp.Vendor(u"National Transcomm. Ltd", "NTL", datetime.date(1996, 11, 29)),
    "ZIC": pnp.Vendor(u"Nationz Technologies Inc.", "ZIC", datetime.date(2009, 3, 12)),
    "NMS": pnp.Vendor(u"Natural Micro System", "NMS", datetime.date(1996, 11, 29)),
    "NAT": pnp.Vendor(u"NaturalPoint Inc.", "NAT", datetime.date(2010, 9, 3)),
    "NVT": pnp.Vendor(u"Navatek Engineering Corporation", "NVT", datetime.date(1998, 3, 2)),
    "NME": pnp.Vendor(u"Navico, Inc.", "NME", datetime.date(2012, 11, 28)),
    "NAV": pnp.Vendor(u"Navigation Corporation", "NAV", datetime.date(1999, 2, 22)),
    "NAX": pnp.Vendor(u"Naxos Tecnologia", "NAX", datetime.date(1997, 12, 12)),
    "DUN": pnp.Vendor(u"NCR Corporation", "DUN", datetime.date(2002, 4, 25)),
    "NCC": pnp.Vendor(u"NCR Corporation", "NCC", datetime.date(1996, 11, 29)),
    "NCR": pnp.Vendor(u"NCR Electronics", "NCR", datetime.date(1996, 11, 29)),
    "NDF": pnp.Vendor(u"NDF Special Light Products B.V.", "NDF", datetime.date(2014, 9, 18)),
    "DMV": pnp.Vendor(u"NDS Ltd", "DMV", datetime.date(1997, 6, 25)),
    "NEC": pnp.Vendor(u"NEC Corporation", "NEC", datetime.date(2000, 5, 24)),
    "NCT": pnp.Vendor(u"NEC CustomTechnica, Ltd.", "NCT", datetime.date(2002, 10, 23)),
    "NMV": pnp.Vendor(u"NEC-Mitsubishi Electric Visual Systems Corporation", "NMV", datetime.date(2002, 2, 25)),
    "NEO": pnp.Vendor(u"NEO TELECOM CO.,LTD.", "NEO", datetime.date(1999, 11, 8)),
    "NMX": pnp.Vendor(u"Neomagic", "NMX", datetime.date(1996, 11, 29)),
    "NTC": pnp.Vendor(u"NeoTech S.R.L", "NTC", datetime.date(1997, 11, 11)),
    "NTX": pnp.Vendor(u"Netaccess Inc", "NTX", datetime.date(1997, 2, 7)),
    "NCL": pnp.Vendor(u"NetComm Ltd", "NCL", datetime.date(1996, 11, 29)),
    "NVC": pnp.Vendor(u"NetVision Corporation", "NVC", datetime.date(1996, 11, 29)),
    "NAL": pnp.Vendor(u"Network Alchemy", "NAL", datetime.date(1997, 9, 30)),
    "NDL": pnp.Vendor(u"Network Designers", "NDL", datetime.date(1996, 11, 29)),
    "NGC": pnp.Vendor(u"Network General", "NGC", datetime.date(1997, 8, 26)),
    "NIT": pnp.Vendor(u"Network Info Technology", "NIT", datetime.date(1996, 11, 29)),
    "NPI": pnp.Vendor(u"Network Peripherals Inc", "NPI", datetime.date(1996, 11, 29)),
    "NST": pnp.Vendor(u"Network Security Technology Co", "NST", datetime.date(1999, 2, 22)),
    "NTW": pnp.Vendor(u"Networth Inc", "NTW", datetime.date(1996, 11, 29)),
    "NSA": pnp.Vendor(u"NeuroSky, Inc.", "NSA", datetime.date(2013, 8, 28)),
    "NEU": pnp.Vendor(u"NEUROTEC - EMPRESA DE PESQUISA E DESENVOLVIMENTO EM BIOMEDICINA", "NEU", datetime.date(2001, 3, 15)),
    "NTI": pnp.Vendor(u"New Tech Int'l Company", "NTI", datetime.date(1996, 11, 29)),
    "NCI": pnp.Vendor(u"NewCom Inc", "NCI", datetime.date(1997, 1, 9)),
    "NWS": pnp.Vendor(u"Newisys, Inc.", "NWS", datetime.date(2002, 10, 8)),
    "NSS": pnp.Vendor(u"Newport Systems Solutions", "NSS", datetime.date(1996, 11, 29)),
    "NXG": pnp.Vendor(u"Nexgen", "NXG", datetime.date(1996, 11, 29)),
    "NEX": pnp.Vendor(u"Nexgen Mediatech Inc.,", "NEX", datetime.date(2003, 11, 11)),
    "NXQ": pnp.Vendor(u"Nexiq Technologies, Inc.", "NXQ", datetime.date(2001, 10, 8)),
    "NLC": pnp.Vendor(u"Next Level Communications", "NLC", datetime.date(1996, 11, 29)),
    "NXC": pnp.Vendor(u"NextCom K.K.", "NXC", datetime.date(1996, 11, 29)),
    "NBT": pnp.Vendor(u"NingBo Bestwinning Technology CO., Ltd", "NBT", datetime.date(2006, 9, 5)),
    "BOI": pnp.Vendor(u"NINGBO BOIGLE DIGITAL TECHNOLOGY CO.,LTD", "BOI", datetime.date(2009, 11, 25)),
    "AVI": pnp.Vendor(u"Nippon Avionics Co.,Ltd", "AVI", datetime.date(2000, 10, 23)),
    "GSB": pnp.Vendor(u"NIPPONDENCHI CO,.LTD", "GSB", datetime.date(2000, 5, 24)),
    "NSI": pnp.Vendor(u"NISSEI ELECTRIC CO.,LTD", "NSI", datetime.date(2000, 1, 13)),
    "NIS": pnp.Vendor(u"Nissei Electric Company", "NIS", datetime.date(1996, 11, 29)),
    "NTS": pnp.Vendor(u"Nits Technology Inc.", "NTS", datetime.date(2006, 12, 19)),
    "NCA": pnp.Vendor(u"Nixdorf Company", "NCA", datetime.date(1996, 11, 29)),
    "NNC": pnp.Vendor(u"NNC", "NNC", datetime.date(1996, 11, 29)),
    "NDS": pnp.Vendor(u"Nokia Data", "NDS", datetime.date(1996, 11, 29)),
    "NOK": pnp.Vendor(u"Nokia Display Products", "NOK", datetime.date(1996, 11, 29)),
    "NMP": pnp.Vendor(u"Nokia Mobile Phones", "NMP", datetime.date(1996, 11, 29)),
    "NOR": pnp.Vendor(u"Norand Corporation", "NOR", datetime.date(1997, 3, 19)),
    "NCE": pnp.Vendor(u"Norcent Technology, Inc.", "NCE", datetime.date(2007, 6, 20)),
    "NOE": pnp.Vendor(u"NordicEye AB", "NOE", datetime.date(2009, 9, 23)),
    "NOI": pnp.Vendor(u"North Invent A/S", "NOI", datetime.date(2010, 5, 4)),
    "NCS": pnp.Vendor(u"Northgate Computer Systems", "NCS", datetime.date(1996, 11, 29)),
    "NOT": pnp.Vendor(u"Not Limited Inc", "NOT", datetime.date(1998, 1, 30)),
    "NWP": pnp.Vendor(u"NovaWeb Technologies Inc", "NWP", datetime.date(1998, 6, 12)),
    "NVL": pnp.Vendor(u"Novell Inc", "NVL", datetime.date(1996, 11, 29)),
    "NSP": pnp.Vendor(u"Nspire System Inc.", "NSP", datetime.date(2007, 2, 13)),
    "NTR": pnp.Vendor(u"N-trig Innovative Technologies, Inc.", "NTR", datetime.date(2005, 10, 3)),
    "NTT": pnp.Vendor(u"NTT Advanced Technology Corporation", "NTT", datetime.date(2004, 8, 19)),
    "NUI": pnp.Vendor(u"NU Inc.", "NUI", datetime.date(2007, 8, 29)),
    "NUG": pnp.Vendor(u"NU Technology, Inc.", "NUG", datetime.date(2004, 4, 16)),
    "NFS": pnp.Vendor(u"Number Five Software", "NFS", datetime.date(1999, 2, 22)),
    "KNX": pnp.Vendor(u"Nutech Marketing PTL", "KNX", datetime.date(1996, 11, 29)),
    "NVI": pnp.Vendor(u"NuVision US, Inc.", "NVI", datetime.date(2006, 9, 5)),
    "NTN": pnp.Vendor(u"Nuvoton Technology Corporation", "NTN", datetime.date(2008, 10, 9)),
    "NVD": pnp.Vendor(u"Nvidia", "NVD", datetime.date(1996, 11, 29)),
    "JEN": pnp.Vendor(u"N-Vision", "JEN", datetime.date(2000, 10, 23)),
    "NXP": pnp.Vendor(u"NXP Semiconductors bv.", "NXP", datetime.date(2007, 6, 14)),
    "NWC": pnp.Vendor(u"NW Computer Engineering", "NWC", datetime.date(1997, 2, 3)),
    "OAK": pnp.Vendor(u"Oak Tech Inc", "OAK", datetime.date(1996, 11, 29)),
    "OAS": pnp.Vendor(u"Oasys Technology Company", "OAS", datetime.date(1996, 11, 29)),
    "OMC": pnp.Vendor(u"OBJIX Multimedia Corporation", "OMC", datetime.date(1996, 11, 29)),
    "PCB": pnp.Vendor(u"OCTAL S.A.", "PCB", datetime.date(1998, 2, 24)),
    "OVR": pnp.Vendor(u"Oculus VR, Inc.", "OVR", datetime.date(2012, 10, 19)),
    "ODR": pnp.Vendor(u"Odrac", "ODR", datetime.date(2001, 6, 21)),
    "ATV": pnp.Vendor(u"Office Depot, Inc.", "ATV", datetime.date(2007, 6, 13)),
    "OKI": pnp.Vendor(u"OKI Electric Industrial Company Ltd", "OKI", datetime.date(1996, 11, 29)),
    "OQI": pnp.Vendor(u"Oksori Company Ltd", "OQI", datetime.date(1996, 11, 29)),
    "OSR": pnp.Vendor(u"Oksori Company Ltd", "OSR", datetime.date(1996, 11, 29)),
    "OCN": pnp.Vendor(u"Olfan", "OCN", datetime.date(1996, 11, 29)),
    "OLC": pnp.Vendor(u"Olicom A/S", "OLC", datetime.date(1996, 11, 29)),
    "OLD": pnp.Vendor(u"Olidata S.p.A.", "OLD", datetime.date(2006, 3, 13)),
    "OLT": pnp.Vendor(u"Olitec S.A.", "OLT", datetime.date(1996, 11, 29)),
    "OLV": pnp.Vendor(u"Olitec S.A.", "OLV", datetime.date(1996, 11, 29)),
    "OLI": pnp.Vendor(u"Olivetti", "OLI", datetime.date(1996, 11, 29)),
    "OLY": pnp.Vendor(u"OLYMPUS CORPORATION", "OLY", datetime.date(2005, 5, 2)),
    "OTK": pnp.Vendor(u"OmniTek", "OTK", datetime.date(2013, 9, 19)),
    "OMN": pnp.Vendor(u"Omnitel", "OMN", datetime.date(1998, 4, 28)),
    "OMR": pnp.Vendor(u"Omron Corporation", "OMR", datetime.date(1996, 11, 29)),
    "ONS": pnp.Vendor(u"On Systems Inc", "ONS", datetime.date(1996, 11, 29)),
    "ONE": pnp.Vendor(u"Oneac Corporation", "ONE", datetime.date(1998, 4, 14)),
    "ONK": pnp.Vendor(u"ONKYO Corporation", "ONK", datetime.date(2005, 6, 16)),
    "ONL": pnp.Vendor(u"OnLive, Inc", "ONL", datetime.date(2010, 9, 3)),
    "TIV": pnp.Vendor(u"OOO Technoinvest", "TIV", datetime.date(1997, 8, 5)),
    "OPC": pnp.Vendor(u"Opcode Inc", "OPC", datetime.date(1996, 11, 29)),
    "OCS": pnp.Vendor(u"Open Connect Solutions", "OCS", datetime.date(1999, 9, 13)),
    "ONW": pnp.Vendor(u"OPEN Networks Ltd", "ONW", datetime.date(2003, 4, 25)),
    "OSI": pnp.Vendor(u"Open Stack, Inc.", "OSI", datetime.date(2013, 7, 22)),
    "OPP": pnp.Vendor(u"OPPO Digital, Inc.", "OPP", datetime.date(2012, 6, 19)),
    "OPT": pnp.Vendor(u"OPTi Inc", "OPT", datetime.date(1996, 11, 29)),
    "OBS": pnp.Vendor(u"Optibase Technologies", "OBS", datetime.date(2010, 11, 1)),
    "OSD": pnp.Vendor(u"Optical Systems Design Pty Ltd", "OSD", datetime.date(2013, 6, 3)),
    "OIC": pnp.Vendor(u"Option Industrial Computers", "OIC", datetime.date(2001, 5, 7)),
    "OIN": pnp.Vendor(u"Option International", "OIN", datetime.date(2000, 10, 23)),
    "OIM": pnp.Vendor(u"Option International", "OIM", datetime.date(1997, 1, 30)),
    "OSP": pnp.Vendor(u"OPTI-UPS Corporation", "OSP", datetime.date(1997, 7, 1)),
    "OPV": pnp.Vendor(u"Optivision Inc", "OPV", datetime.date(1996, 11, 29)),
    "OTT": pnp.Vendor(u"OPTO22, Inc.", "OTT", datetime.date(1998, 10, 6)),
    "OTM": pnp.Vendor(u"Optoma Corporation", "OTM", datetime.date(2010, 4, 20)),
    "OEI": pnp.Vendor(u"Optum Engineering Inc.", "OEI", datetime.date(2010, 8, 2)),
    "OTI": pnp.Vendor(u"Orchid Technology", "OTI", datetime.date(1996, 11, 29)),
    "ORG": pnp.Vendor(u"ORGA Kartensysteme GmbH", "ORG", datetime.date(1998, 10, 24)),
    "TOP": pnp.Vendor(u"Orion Communications Co., Ltd.", "TOP", datetime.date(2007, 4, 30)),
    "ORN": pnp.Vendor(u"ORION ELECTRIC CO., LTD.", "ORN", datetime.date(2005, 1, 19)),
    "OEC": pnp.Vendor(u"ORION ELECTRIC CO.,LTD", "OEC", datetime.date(2000, 1, 13)),
    "OSA": pnp.Vendor(u"OSAKA Micro Computer, Inc.", "OSA", datetime.date(2003, 9, 5)),
    "ORI": pnp.Vendor(u"OSR Open Systems Resources, Inc.", "ORI", datetime.date(1999, 1, 20)),
    "OOS": pnp.Vendor(u"OSRAM", "OOS", datetime.date(2002, 4, 25)),
    "OUK": pnp.Vendor(u"OUK Company Ltd", "OUK", datetime.date(1996, 11, 29)),
    "OTB": pnp.Vendor(u"outsidetheboxstuff.com", "OTB", datetime.date(2010, 9, 3)),
    "OXU": pnp.Vendor(u"Oxus Research S.A.", "OXU", datetime.date(1996, 11, 29)),
    "OZC": pnp.Vendor(u"OZ Corporation", "OZC", datetime.date(2012, 8, 7)),
    "PAC": pnp.Vendor(u"Pacific Avionics Corporation", "PAC", datetime.date(1996, 11, 29)),
    "PCW": pnp.Vendor(u"Pacific CommWare Inc", "PCW", datetime.date(1996, 11, 29)),
    "PIE": pnp.Vendor(u"Pacific Image Electronics Company Ltd", "PIE", datetime.date(1997, 10, 21)),
    "PBL": pnp.Vendor(u"Packard Bell Electronics", "PBL", datetime.date(1996, 11, 29)),
    "PBN": pnp.Vendor(u"Packard Bell NEC", "PBN", datetime.date(1996, 11, 29)),
    "PGI": pnp.Vendor(u"PACSGEAR, Inc.", "PGI", datetime.date(2012, 8, 13)),
    "QFF": pnp.Vendor(u"Padix Co., Inc.", "QFF", datetime.date(1999, 9, 13)),
    "PJT": pnp.Vendor(u"Pan Jit International Inc.", "PJT", datetime.date(2004, 8, 3)),
    "MDO": pnp.Vendor(u"Panasonic", "MDO", datetime.date(1996, 11, 29)),
    "PLF": pnp.Vendor(u"Panasonic Avionics Corporation", "PLF", datetime.date(2010, 8, 13)),
    "MEI": pnp.Vendor(u"Panasonic Industry Company", "MEI", datetime.date(1996, 11, 29)),
    "PNL": pnp.Vendor(u"Panelview, Inc.", "PNL", datetime.date(2003, 8, 4)),
    "PTL": pnp.Vendor(u"Pantel Inc", "PTL", datetime.date(1996, 11, 29)),
    "PTA": pnp.Vendor(u"PAR Tech Inc.", "PTA", datetime.date(2011, 1, 26)),
    "PRT": pnp.Vendor(u"Parade Technologies, Ltd.", "PRT", datetime.date(2012, 4, 6)),
    "PGM": pnp.Vendor(u"Paradigm Advanced Research Centre", "PGM", datetime.date(2005, 6, 16)),
    "PAR": pnp.Vendor(u"Parallan Comp Inc", "PAR", datetime.date(1996, 11, 29)),
    "PLX": pnp.Vendor(u"Parallax Graphics", "PLX", datetime.date(1996, 11, 29)),
    "RCE": pnp.Vendor(u"Parc d'Activite des Bellevues", "RCE", datetime.date(1996, 11, 29)),
    "POT": pnp.Vendor(u"Parrot", "POT", datetime.date(2014, 11, 25)),
    "PTH": pnp.Vendor(u"Pathlight Technology Inc", "PTH", datetime.date(1996, 11, 29)),
    "PCX": pnp.Vendor(u"PC Xperten", "PCX", datetime.date(1998, 2, 24)),
    "PCK": pnp.Vendor(u"PCBANK21", "PCK", datetime.date(2007, 2, 13)),
    "PCM": pnp.Vendor(u"PCM Systems Corporation", "PCM", datetime.date(1997, 3, 25)),
    "PCT": pnp.Vendor(u"PC-Tel Inc", "PCT", datetime.date(1997, 5, 2)),
    "PDS": pnp.Vendor(u"PD Systems International Ltd", "PDS", datetime.date(1999, 3, 20)),
    "PDT": pnp.Vendor(u"PDTS - Prozessdatentechnik und Systeme", "PDT", datetime.date(1998, 2, 10)),
    "PEG": pnp.Vendor(u"Pegatron Corporation", "PEG", datetime.date(2013, 8, 27)),
    "PEI": pnp.Vendor(u"PEI Electronics Inc", "PEI", datetime.date(1998, 4, 6)),
    "PVM": pnp.Vendor(u"Penta Studiotechnik GmbH", "PVM", datetime.date(2010, 5, 5)),
    "PCL": pnp.Vendor(u"pentel.co.,ltd", "PCL", datetime.date(2002, 2, 25)),
    "PEP": pnp.Vendor(u"Peppercon AG", "PEP", datetime.date(2006, 4, 12)),
    "PPX": pnp.Vendor(u"Perceptive Pixel Inc.", "PPX", datetime.date(2010, 5, 4)),
    "PER": pnp.Vendor(u"Perceptive Signal Technologies", "PER", datetime.date(1997, 5, 13)),
    "PRC": pnp.Vendor(u"PerComm", "PRC", datetime.date(2001, 4, 24)),
    "PCO": pnp.Vendor(u"Performance Concepts Inc.,", "PCO", datetime.date(2002, 9, 24)),
    "IPN": pnp.Vendor(u"Performance Technologies", "IPN", datetime.date(2004, 2, 24)),
    "PSL": pnp.Vendor(u"Perle Systems Limited", "PSL", datetime.date(1999, 2, 22)),
    "PON": pnp.Vendor(u"Perpetual Technologies, LLC", "PON", datetime.date(2000, 1, 13)),
    "PAM": pnp.Vendor(u"Peter Antesberger Messtechnik", "PAM", datetime.date(1998, 4, 28)),
    "PSD": pnp.Vendor(u"Peus-Systems GmbH", "PSD", datetime.date(1996, 11, 29)),
    "PCA": pnp.Vendor(u"Philips BU Add On Card", "PCA", datetime.date(1996, 11, 29)),
    "PHS": pnp.Vendor(u"Philips Communication Systems", "PHS", datetime.date(1996, 11, 29)),
    "PHL": pnp.Vendor(u"Philips Consumer Electronics Company", "PHL", datetime.date(1996, 11, 29)),
    "PHE": pnp.Vendor(u"Philips Medical Systems Boeblingen GmbH", "PHE", datetime.date(2010, 4, 20)),
    "PSC": pnp.Vendor(u"Philips Semiconductors", "PSC", datetime.date(1996, 11, 29)),
    "PXC": pnp.Vendor(u"Phoenix Contact", "PXC", datetime.date(2008, 2, 27)),
    "PNX": pnp.Vendor(u"Phoenix Technologies, Ltd.", "PNX", datetime.date(1999, 11, 8)),
    "PPC": pnp.Vendor(u"Phoenixtec Power Company Ltd", "PPC", datetime.date(1999, 5, 16)),
    "PHO": pnp.Vendor(u"Photonics Systems Inc.", "PHO", datetime.date(2002, 6, 3)),
    "RSC": pnp.Vendor(u"PhotoTelesis", "RSC", datetime.date(1998, 3, 16)),
    "PHY": pnp.Vendor(u"Phylon Communications", "PHY", datetime.date(1996, 11, 29)),
    "PPR": pnp.Vendor(u"PicPro", "PPR", datetime.date(2004, 10, 18)),
    "PHC": pnp.Vendor(u"Pijnenburg Beheer N.V.", "PHC", datetime.date(2001, 4, 24)),
    "PCI": pnp.Vendor(u"Pioneer Computer Inc", "PCI", datetime.date(1996, 11, 29)),
    "PIO": pnp.Vendor(u"Pioneer Electronic Corporation", "PIO", datetime.date(1997, 7, 16)),
    "PBV": pnp.Vendor(u"Pitney Bowes", "PBV", datetime.date(1999, 9, 13)),
    "PBI": pnp.Vendor(u"Pitney Bowes", "PBI", datetime.date(1996, 11, 29)),
    "PQI": pnp.Vendor(u"Pixel Qi", "PQI", datetime.date(2009, 6, 24)),
    "PVN": pnp.Vendor(u"Pixel Vision", "PVN", datetime.date(1996, 11, 29)),
    "PXE": pnp.Vendor(u"PIXELA CORPORATION", "PXE", datetime.date(2007, 11, 21)),
    "PIX": pnp.Vendor(u"Pixie Tech Inc", "PIX", datetime.date(1996, 11, 29)),
    "PTS": pnp.Vendor(u"Plain Tree Systems Inc", "PTS", datetime.date(1996, 11, 29)),
    "PNR": pnp.Vendor(u"Planar Systems, Inc.", "PNR", datetime.date(2003, 8, 11)),
    "PLV": pnp.Vendor(u"PLUS Vision Corp.", "PLV", datetime.date(2001, 7, 5)),
    "PMC": pnp.Vendor(u"PMC Consumer Electronics Ltd", "PMC", datetime.date(1996, 12, 11)),
    "SPR": pnp.Vendor(u"pmns GmbH", "SPR", datetime.date(2002, 10, 8)),
    "PMM": pnp.Vendor(u"Point Multimedia System", "PMM", datetime.date(1997, 6, 9)),
    "PLY": pnp.Vendor(u"Polycom Inc.", "PLY", datetime.date(2002, 6, 19)),
    "POL": pnp.Vendor(u"PolyComp (PTY) Ltd.", "POL", datetime.date(2006, 2, 14)),
    "COW": pnp.Vendor(u"Polycow Productions", "COW", datetime.date(2001, 3, 15)),
    "POR": pnp.Vendor(u"Portalis LC", "POR", datetime.date(2008, 11, 1)),
    "ARO": pnp.Vendor(u"Poso International B.V.", "ARO", datetime.date(1997, 8, 1)),
    "PEC": pnp.Vendor(u"POTRANS Electrical Corp.", "PEC", datetime.date(1999, 7, 16)),
    "PCC": pnp.Vendor(u"PowerCom Technology Company Ltd", "PCC", datetime.date(1997, 9, 2)),
    "CPX": pnp.Vendor(u"Powermatic Data Systems", "CPX", datetime.date(1996, 11, 29)),
    "PET": pnp.Vendor(u"Practical Electronic Tools", "PET", datetime.date(1999, 2, 22)),
    "PPI": pnp.Vendor(u"Practical Peripherals", "PPI", datetime.date(1996, 11, 29)),
    "PSE": pnp.Vendor(u"Practical Solutions Pte., Ltd.", "PSE", datetime.date(1998, 10, 6)),
    "PRD": pnp.Vendor(u"Praim S.R.L.", "PRD", datetime.date(1996, 11, 29)),
    "PEL": pnp.Vendor(u"Primax Electric Ltd", "PEL", datetime.date(1996, 11, 29)),
    "SYX": pnp.Vendor(u"Prime Systems, Inc.", "SYX", datetime.date(2003, 10, 21)),
    "PVI": pnp.Vendor(u"Prime view international Co., Ltd", "PVI", datetime.date(2009, 7, 6)),
    "PGS": pnp.Vendor(u"Princeton Graphic Systems", "PGS", datetime.date(1996, 11, 29)),
    "PIM": pnp.Vendor(u"Prism, LLC", "PIM", datetime.date(2007, 7, 24)),
    "PRI": pnp.Vendor(u"Priva Hortimation BV", "PRI", datetime.date(1997, 10, 22)),
    "PRA": pnp.Vendor(u"PRO/AUTOMATION", "PRA", datetime.date(1999, 7, 16)),
    "PCP": pnp.Vendor(u"Procomp USA Inc", "PCP", datetime.date(1996, 11, 29)),
    "PSY": pnp.Vendor(u"Prodea Systems Inc.", "PSY", datetime.date(2013, 2, 4)),
    "PDV": pnp.Vendor(u"Prodrive B.V.", "PDV", datetime.date(2005, 1, 18)),
    "PJA": pnp.Vendor(u"Projecta", "PJA", datetime.date(1997, 1, 29)),
    "DHT": pnp.Vendor(u"Projectavision Inc", "DHT", datetime.date(1998, 1, 14)),
    "PJD": pnp.Vendor(u"Projectiondesign AS", "PJD", datetime.date(2002, 9, 23)),
    "PLM": pnp.Vendor(u"PROLINK Microsystems Corp.", "PLM", datetime.date(2002, 2, 25)),
    "PLC": pnp.Vendor(u"Pro-Log Corporation", "PLC", datetime.date(1996, 11, 29)),
    "PMT": pnp.Vendor(u"Promate Electronic Co., Ltd.", "PMT", datetime.date(2003, 1, 13)),
    "PRM": pnp.Vendor(u"Prometheus", "PRM", datetime.date(1996, 11, 29)),
    "PTI": pnp.Vendor(u"Promise Technology Inc", "PTI", datetime.date(1997, 1, 2)),
    "PAD": pnp.Vendor(u"Promotion and Display Technology Ltd.", "PAD", datetime.date(2001, 4, 24)),
    "TEL": pnp.Vendor(u"Promotion and Display Technology Ltd.", "TEL", datetime.date(2001, 4, 24)),
    "PGP": pnp.Vendor(u"propagamma kommunikation", "PGP", datetime.date(2000, 4, 19)),
    "PSM": pnp.Vendor(u"Prosum", "PSM", datetime.date(1996, 11, 29)),
    "PRO": pnp.Vendor(u"Proteon", "PRO", datetime.date(1996, 11, 29)),
    "PVG": pnp.Vendor(u"Proview Global Co., Ltd", "PVG", datetime.date(2002, 10, 8)),
    "PXM": pnp.Vendor(u"Proxim Inc", "PXM", datetime.date(1997, 9, 19)),
    "PRX": pnp.Vendor(u"Proxima Corporation", "PRX", datetime.date(1996, 11, 29)),
    "PTC": pnp.Vendor(u"PS Technology Corporation", "PTC", datetime.date(1997, 1, 29)),
    "PDM": pnp.Vendor(u"Psion Dacom Plc.", "PDM", datetime.date(1999, 11, 8)),
    "PSI": pnp.Vendor(u"PSI-Perceptive Solutions Inc", "PSI", datetime.date(1996, 11, 29)),
    "PLT": pnp.Vendor(u"PT Hartono Istana Teknologi", "PLT", datetime.date(2010, 5, 5)),
    "PUL": pnp.Vendor(u"Pulse-Eight Ltd", "PUL", datetime.date(2012, 9, 12)),
    "PDR": pnp.Vendor(u"Pure Data Inc", "PDR", datetime.date(1996, 11, 29)),
    "PPP": pnp.Vendor(u"Purup Prepress AS", "PPP", datetime.date(1996, 11, 29)),
    "HRE": pnp.Vendor(u"Qingdao Haier Electronics Co., Ltd.", "HRE", datetime.date(2006, 4, 12)),
    "QLC": pnp.Vendor(u"Q-Logic", "QLC", datetime.date(1996, 11, 29)),
    "QTR": pnp.Vendor(u"Qtronix Corporation", "QTR", datetime.date(1996, 11, 29)),
    "DHQ": pnp.Vendor(u"Quadram", "DHQ", datetime.date(1996, 11, 29)),
    "QDM": pnp.Vendor(u"Quadram", "QDM", datetime.date(1996, 11, 29)),
    "QCL": pnp.Vendor(u"Quadrant Components Inc", "QCL", datetime.date(1997, 4, 3)),
    "QCC": pnp.Vendor(u"QuakeCom Company Ltd", "QCC", datetime.date(1998, 3, 23)),
    "QCP": pnp.Vendor(u"Qualcomm Inc", "QCP", datetime.date(1999, 5, 16)),
    "QCI": pnp.Vendor(u"Quanta Computer Inc", "QCI", datetime.date(1996, 11, 29)),
    "QDS": pnp.Vendor(u"Quanta Display Inc.", "QDS", datetime.date(2002, 4, 25)),
    "QTM": pnp.Vendor(u"Quantum", "QTM", datetime.date(1996, 11, 29)),
    "QTD": pnp.Vendor(u"Quantum 3D Inc", "QTD", datetime.date(1997, 5, 23)),
    "QDI": pnp.Vendor(u"Quantum Data Incorporated", "QDI", datetime.date(2001, 3, 15)),
    "QVU": pnp.Vendor(u"Quartics", "QVU", datetime.date(2010, 11, 4)),
    "QUA": pnp.Vendor(u"Quatographic AG", "QUA", datetime.date(2000, 1, 13)),
    "QTH": pnp.Vendor(u"Questech Ltd", "QTH", datetime.date(2000, 1, 13)),
    "QUE": pnp.Vendor(u"Questra Consulting", "QUE", datetime.date(1998, 1, 30)),
    "QCK": pnp.Vendor(u"Quick Corporation", "QCK", datetime.date(1996, 11, 29)),
    "QFI": pnp.Vendor(u"Quickflex, Inc", "QFI", datetime.date(1998, 8, 4)),
    "QTI": pnp.Vendor(u"Quicknet Technologies Inc", "QTI", datetime.date(1996, 11, 29)),
    "RSQ": pnp.Vendor(u"R Squared", "RSQ", datetime.date(1999, 11, 8)),
    "RPT": pnp.Vendor(u"R.P.T.Intergroups", "RPT", datetime.date(1996, 11, 29)),
    "RII": pnp.Vendor(u"Racal Interlan Inc", "RII", datetime.date(1996, 11, 29)),
    "TSF": pnp.Vendor(u"Racal-Airtech Software Forge Ltd", "TSF", datetime.date(1996, 11, 29)),
    "RAC": pnp.Vendor(u"Racore Computer Products Inc", "RAC", datetime.date(1996, 11, 29)),
    "RRI": pnp.Vendor(u"Radicom Research Inc", "RRI", datetime.date(1997, 12, 2)),
    "RCN": pnp.Vendor(u"Radio Consult SRL", "RCN", datetime.date(2002, 9, 24)),
    "RDN": pnp.Vendor(u"RADIODATA GmbH", "RDN", datetime.date(2012, 7, 25)),
    "RLN": pnp.Vendor(u"RadioLAN Inc", "RLN", datetime.date(1996, 11, 29)),
    "RSN": pnp.Vendor(u"Radiospire Networks, Inc.", "RSN", datetime.date(2007, 6, 14)),
    "RAD": pnp.Vendor(u"Radisys Corporation", "RAD", datetime.date(1996, 11, 29)),
    "RDS": pnp.Vendor(u"Radius Inc", "RDS", datetime.date(1997, 3, 7)),
    "RFI": pnp.Vendor(u"RAFI GmbH & Co. KG", "RFI", datetime.date(2015, 8, 24)),
    "RDI": pnp.Vendor(u"Rainbow Displays, Inc.", "RDI", datetime.date(1998, 9, 23)),
    "RNB": pnp.Vendor(u"Rainbow Technologies", "RNB", datetime.date(1996, 11, 29)),
    "RTS": pnp.Vendor(u"Raintree Systems", "RTS", datetime.date(2001, 10, 2)),
    "BOB": pnp.Vendor(u"Rainy Orchard", "BOB", datetime.date(2000, 2, 21)),
    "RSI": pnp.Vendor(u"Rampage Systems Inc", "RSI", datetime.date(1996, 11, 29)),
    "RAN": pnp.Vendor(u"Rancho Tech Inc", "RAN", datetime.date(1996, 11, 29)),
    "RTI": pnp.Vendor(u"Rancho Tech Inc", "RTI", datetime.date(1996, 11, 29)),
    "RSX": pnp.Vendor(u"Rapid Tech Corporation", "RSX", datetime.date(1996, 11, 29)),
    "RMC": pnp.Vendor(u"Raritan Computer, Inc", "RMC", datetime.date(1998, 11, 27)),
    "RAR": pnp.Vendor(u"Raritan, Inc.", "RAR", datetime.date(2007, 6, 14)),
    "RAS": pnp.Vendor(u"RAScom Inc", "RAS", datetime.date(1996, 11, 29)),
    "REX": pnp.Vendor(u"RATOC Systems, Inc.", "REX", datetime.date(2012, 1, 6)),
    "RAY": pnp.Vendor(u"Raylar Design, Inc.", "RAY", datetime.date(2000, 1, 13)),
    "RCI": pnp.Vendor(u"RC International", "RCI", datetime.date(1996, 11, 29)),
    "RCH": pnp.Vendor(u"Reach Technology Inc", "RCH", datetime.date(1998, 2, 9)),
    "RKC": pnp.Vendor(u"Reakin Technolohy Corporation", "RKC", datetime.date(2001, 3, 15)),
    "REA": pnp.Vendor(u"Real D", "REA", datetime.date(2007, 11, 15)),
    "RTL": pnp.Vendor(u"Realtek Semiconductor Company Ltd", "RTL", datetime.date(1996, 11, 29)),
    "ALG": pnp.Vendor(u"Realtek Semiconductor Corp.", "ALG", datetime.date(2002, 10, 25)),
    "RVI": pnp.Vendor(u"Realvision Inc", "RVI", datetime.date(1996, 11, 29)),
    "REC": pnp.Vendor(u"ReCom", "REC", datetime.date(1999, 5, 16)),
    "RWC": pnp.Vendor(u"Red Wing Corporation", "RWC", datetime.date(1998, 1, 8)),
    "RFX": pnp.Vendor(u"Redfox Technologies Inc.", "RFX", datetime.date(2014, 1, 14)),
    "REF": pnp.Vendor(u"Reflectivity, Inc.", "REF", datetime.date(2000, 4, 19)),
    "REH": pnp.Vendor(u"Rehan Electronics Ltd.", "REH", datetime.date(2012, 2, 15)),
    "RTC": pnp.Vendor(u"Relia Technologies", "RTC", datetime.date(1996, 11, 29)),
    "REL": pnp.Vendor(u"Reliance Electric Ind Corporation", "REL", datetime.date(1996, 11, 29)),
    "REN": pnp.Vendor(u"Renesas Technology Corp.", "REN", datetime.date(2007, 6, 14)),
    "RAT": pnp.Vendor(u"Rent-A-Tech", "RAT", datetime.date(1999, 2, 22)),
    "RED": pnp.Vendor(u"Research Electronics Development Inc", "RED", datetime.date(1997, 12, 2)),
    "RMP": pnp.Vendor(u"Research Machines", "RMP", datetime.date(1996, 11, 29)),
    "RES": pnp.Vendor(u"ResMed Pty Ltd", "RES", datetime.date(2000, 2, 21)),
    "RET": pnp.Vendor(u"Resonance Technology, Inc.", "RET", datetime.date(2011, 2, 9)),
    "WTS": pnp.Vendor(u"Restek Electric Company Ltd", "WTS", datetime.date(1996, 11, 29)),
    "RVL": pnp.Vendor(u"Reveal Computer Prod", "RVL", datetime.date(1996, 11, 29)),
    "REV": pnp.Vendor(u"Revolution Display, Inc.", "REV", datetime.date(2014, 3, 19)),
    "RGB": pnp.Vendor(u"RGB Spectrum", "RGB", datetime.date(2012, 11, 14)),
    "EXN": pnp.Vendor(u"RGB Systems, Inc. dba Extron Electronics", "EXN", datetime.date(2008, 7, 6)),
    "RIC": pnp.Vendor(u"RICOH COMPANY, LTD.", "RIC", datetime.date(2010, 5, 13)),
    "RHD": pnp.Vendor(u"RightHand Technologies", "RHD", datetime.date(2012, 5, 1)),
    "RIO": pnp.Vendor(u"Rios Systems Company Ltd", "RIO", datetime.date(1996, 11, 29)),
    "RIT": pnp.Vendor(u"Ritech Inc", "RIT", datetime.date(1998, 4, 14)),
    "RIV": pnp.Vendor(u"Rivulet Communications", "RIV", datetime.date(2007, 7, 19)),
    "BSG": pnp.Vendor(u"Robert Bosch GmbH", "BSG", datetime.date(2014, 5, 15)),
    "GRY": pnp.Vendor(u"Robert Gray Company", "GRY", datetime.date(1998, 3, 31)),
    "RGL": pnp.Vendor(u"Robertson Geologging Ltd", "RGL", datetime.date(2000, 8, 10)),
    "ROB": pnp.Vendor(u"Robust Electronics GmbH", "ROB", datetime.date(2008, 1, 18)),
    "RAI": pnp.Vendor(u"Rockwell Automation/Intecolor", "RAI", datetime.date(1998, 3, 13)),
    "RCO": pnp.Vendor(u"Rockwell Collins", "RCO", datetime.date(2010, 9, 10)),
    "ASY": pnp.Vendor(u"Rockwell Collins / Airshow Systems", "ASY", datetime.date(2004, 12, 2)),
    "COL": pnp.Vendor(u"Rockwell Collins, Inc.", "COL", datetime.date(2007, 6, 14)),
    "ROK": pnp.Vendor(u"Rockwell International", "ROK", datetime.date(1996, 11, 29)),
    "RSS": pnp.Vendor(u"Rockwell Semiconductor Systems", "RSS", datetime.date(1996, 11, 29)),
    "MAX": pnp.Vendor(u"Rogen Tech Distribution Inc", "MAX", datetime.date(1996, 11, 29)),
    "ROS": pnp.Vendor(u"Rohde & Schwarz", "ROS", datetime.date(2012, 1, 20)),
    "ROH": pnp.Vendor(u"Rohm Co., Ltd.", "ROH", datetime.date(2004, 6, 16)),
    "RHM": pnp.Vendor(u"Rohm Company Ltd", "RHM", datetime.date(1997, 5, 13)),
    "RJA": pnp.Vendor(u"Roland Corporation", "RJA", datetime.date(1996, 11, 29)),
    "RPI": pnp.Vendor(u"RoomPro Technologies", "RPI", datetime.date(2010, 7, 9)),
    "ROP": pnp.Vendor(u"Roper International Ltd", "ROP", datetime.date(1999, 5, 16)),
    "RMT": pnp.Vendor(u"Roper Mobile", "RMT", datetime.date(2010, 7, 2)),
    "RSV": pnp.Vendor(u"Ross Video Ltd", "RSV", datetime.date(2012, 6, 11)),
    "TRL": pnp.Vendor(u"Royal Information", "TRL", datetime.date(1996, 11, 29)),
    "RZS": pnp.Vendor(u"Rozsny\xf3, s.r.o.", "RZS", datetime.date(2014, 3, 24)),
    "RVC": pnp.Vendor(u"RSI Systems Inc", "RVC", datetime.date(1998, 4, 28)),
    "RUN": pnp.Vendor(u"RUNCO International", "RUN", datetime.date(2004, 4, 1)),
    "SNK": pnp.Vendor(u"S&K Electronics", "SNK", datetime.date(2000, 2, 21)),
    "TLV": pnp.Vendor(u"S3 Inc", "TLV", datetime.date(1997, 1, 7)),
    "SIM": pnp.Vendor(u"S3 Inc", "SIM", datetime.date(1996, 11, 29)),
    "SSS": pnp.Vendor(u"S3 Inc", "SSS", datetime.date(1996, 11, 29)),
    "SAE": pnp.Vendor(u"Saab Aerotech", "SAE", datetime.date(2007, 6, 14)),
    "SAI": pnp.Vendor(u"Sage Inc", "SAI", datetime.date(1997, 7, 16)),
    "SGM": pnp.Vendor(u"SAGEM", "SGM", datetime.date(2003, 9, 5)),
    "SDK": pnp.Vendor(u"SAIT-Devlonics", "SDK", datetime.date(1996, 11, 29)),
    "SAK": pnp.Vendor(u"Saitek Ltd", "SAK", datetime.date(1999, 5, 16)),
    "SLT": pnp.Vendor(u"Salt Internatioinal Corp.", "SLT", datetime.date(2006, 9, 5)),
    "SAM": pnp.Vendor(u"Samsung Electric Company", "SAM", datetime.date(1996, 11, 29)),
    "SKT": pnp.Vendor(u"Samsung Electro-Mechanics Company Ltd", "SKT", datetime.date(1996, 11, 29)),
    "STN": pnp.Vendor(u"Samsung Electronics America", "STN", datetime.date(2000, 8, 10)),
    "KYK": pnp.Vendor(u"Samsung Electronics America Inc", "KYK", datetime.date(1998, 2, 24)),
    "SSE": pnp.Vendor(u"Samsung Electronic Co.", "SSE", datetime.date(2000, 8, 10)),
    "SEM": pnp.Vendor(u"Samsung Electronics Company Ltd", "SEM", datetime.date(1996, 11, 29)),
    "SDI": pnp.Vendor(u"Samtron Displays Inc", "SDI", datetime.date(1996, 11, 29)),
    "JSK": pnp.Vendor(u"SANKEN ELECTRIC CO., LTD", "JSK", datetime.date(1999, 9, 13)),
    "SSJ": pnp.Vendor(u"Sankyo Seiki Mfg.co., Ltd", "SSJ", datetime.date(2003, 1, 28)),
    "SAA": pnp.Vendor(u"Sanritz Automation Co.,Ltd.", "SAA", datetime.date(2002, 2, 25)),
    "STK": pnp.Vendor(u"SANTAK CORP.", "STK", datetime.date(1998, 11, 27)),
    "SOC": pnp.Vendor(u"Santec Corporation", "SOC", datetime.date(2015, 1, 12)),
    "SAN": pnp.Vendor(u"Sanyo Electric Co.,Ltd.", "SAN", datetime.date(1999, 11, 8)),
    "SCD": pnp.Vendor(u"Sanyo Electric Company Ltd", "SCD", datetime.date(1996, 11, 29)),
    "SIB": pnp.Vendor(u"Sanyo Electric Company Ltd", "SIB", datetime.date(1996, 11, 29)),
    "TSC": pnp.Vendor(u"Sanyo Electric Company Ltd", "TSC", datetime.date(1996, 11, 29)),
    "ICN": pnp.Vendor(u"Sanyo Icon", "ICN", datetime.date(1996, 11, 29)),
    "SPN": pnp.Vendor(u"Sapience Corporation", "SPN", datetime.date(1996, 11, 29)),
    "SDA": pnp.Vendor(u"SAT (Societe Anonyme)", "SDA", datetime.date(1996, 11, 29)),
    "AVV": pnp.Vendor(u"SBS Technologies (Canada), Inc. (was Avvida Systems, Inc.)", "AVV", datetime.date(2002, 12, 17)),
    "SBS": pnp.Vendor(u"SBS-or Industrial Computers GmbH", "SBS", datetime.date(1998, 12, 28)),
    "SGI": pnp.Vendor(u"Scan Group Ltd", "SGI", datetime.date(1996, 11, 29)),
    "SCN": pnp.Vendor(u"Scanport, Inc.", "SCN", datetime.date(2002, 8, 5)),
    "KFC": pnp.Vendor(u"SCD Tech", "KFC", datetime.date(2002, 10, 23)),
    "SPT": pnp.Vendor(u"Sceptre Tech Inc", "SPT", datetime.date(1996, 11, 29)),
    "SMB": pnp.Vendor(u"Schlumberger", "SMB", datetime.date(1999, 7, 16)),
    "SCH": pnp.Vendor(u"Schlumberger Cards", "SCH", datetime.date(1998, 4, 28)),
    "SLR": pnp.Vendor(u"Schlumberger Technology Corporate", "SLR", datetime.date(2000, 8, 10)),
    "SKD": pnp.Vendor(u"Schneider & Koch", "SKD", datetime.date(1996, 11, 29)),
    "MGE": pnp.Vendor(u"Schneider Electric S.A.", "MGE", datetime.date(1996, 11, 29)),
    "SLS": pnp.Vendor(u"Schnick-Schnack-Systems GmbH", "SLS", datetime.date(2009, 5, 6)),
    "REM": pnp.Vendor(u"SCI Systems Inc.", "REM", datetime.date(2000, 8, 10)),
    "SCM": pnp.Vendor(u"SCM Microsystems Inc", "SCM", datetime.date(1996, 11, 29)),
    "SCP": pnp.Vendor(u"Scriptel Corporation", "SCP", datetime.date(2007, 6, 14)),
    "SDR": pnp.Vendor(u"SDR Systems", "SDR", datetime.date(2001, 3, 15)),
    "STY": pnp.Vendor(u"SDS Technologies", "STY", datetime.date(1999, 11, 8)),
    "SDX": pnp.Vendor(u"SDX Business Systems Ltd", "SDX", datetime.date(1996, 11, 29)),
    "NIX": pnp.Vendor(u"Seanix Technology Inc", "NIX", datetime.date(2007, 4, 9)),
    "SEA": pnp.Vendor(u"Seanix Technology Inc.", "SEA", datetime.date(1998, 2, 24)),
    "SAG": pnp.Vendor(u"Sedlbauer", "SAG", datetime.date(1996, 11, 29)),
    "SEE": pnp.Vendor(u"SeeColor Corporation", "SEE", datetime.date(1996, 11, 29)),
    "SCB": pnp.Vendor(u"SeeCubic B.V.", "SCB", datetime.date(2012, 11, 2)),
    "SRT": pnp.Vendor(u"SeeReal Technologies GmbH", "SRT", datetime.date(2005, 6, 27)),
    "SEC": pnp.Vendor(u"Seiko Epson Corporation", "SEC", datetime.date(1996, 11, 29)),
    "SID": pnp.Vendor(u"Seiko Instruments Information Devices Inc", "SID", datetime.date(1996, 12, 16)),
    "SIU": pnp.Vendor(u"Seiko Instruments USA Inc", "SIU", datetime.date(1996, 11, 29)),
    "SEI": pnp.Vendor(u"Seitz & Associates Inc", "SEI", datetime.date(1998, 1, 30)),
    "SJE": pnp.Vendor(u"Sejin Electron Inc", "SJE", datetime.date(1997, 8, 20)),
    "SXG": pnp.Vendor(u"SELEX GALILEO", "SXG", datetime.date(2012, 10, 1)),
    "STH": pnp.Vendor(u"Semtech Corporation", "STH", datetime.date(2001, 11, 30)),
    "SET": pnp.Vendor(u"SendTek Corporation", "SET", datetime.date(1999, 11, 8)),
    "SBT": pnp.Vendor(u"Senseboard Technologies AB", "SBT", datetime.date(2002, 9, 3)),
    "SEN": pnp.Vendor(u"Sencore", "SEN", datetime.date(1997, 5, 23)),
    "STU": pnp.Vendor(u"Sentelic Corporation", "STU", datetime.date(2012, 7, 27)),
    "SEO": pnp.Vendor(u"SEOS Ltd", "SEO", datetime.date(2003, 2, 20)),
    "SNC": pnp.Vendor(u"Sentronic International Corp.", "SNC", datetime.date(2000, 10, 23)),
    "SEP": pnp.Vendor(u"SEP Eletronica Ltda.", "SEP", datetime.date(2001, 5, 7)),
    "SQT": pnp.Vendor(u"Sequent Computer Systems Inc", "SQT", datetime.date(1996, 11, 29)),
    "SES": pnp.Vendor(u"Session Control LLC", "SES", datetime.date(2010, 9, 3)),
    "SRD": pnp.Vendor(u"Setred", "SRD", datetime.date(2006, 9, 5)),
    "SVT": pnp.Vendor(u"SEVIT Co., Ltd.", "SVT", datetime.date(2002, 6, 25)),
    "SVA": pnp.Vendor(u"SGEG", "SVA", datetime.date(2000, 2, 21)),
    "SYT": pnp.Vendor(u"Seyeon Tech Company Ltd", "SYT", datetime.date(1997, 12, 2)),
    "STM": pnp.Vendor(u"SGS Thomson Microelectronics", "STM", datetime.date(1997, 11, 11)),
    "OYO": pnp.Vendor(u"Shadow Systems", "OYO", datetime.date(1996, 11, 29)),
    "SBC": pnp.Vendor(u"Shanghai Bell Telephone Equip Mfg Co", "SBC", datetime.date(1998, 4, 30)),
    "SGW": pnp.Vendor(u"Shanghai Guowei Science and Technology Co., Ltd.", "SGW", datetime.date(2011, 1, 28)),
    "XQU": pnp.Vendor(u"SHANGHAI SVA-DAV ELECTRONICS CO., LTD", "XQU", datetime.date(2003, 7, 24)),
    "SWL": pnp.Vendor(u"Sharedware Ltd", "SWL", datetime.date(1998, 8, 11)),
    "SMM": pnp.Vendor(u"Shark Multimedia Inc", "SMM", datetime.date(1996, 11, 29)),
    "DFK": pnp.Vendor(u"SharkTec A/S", "DFK", datetime.date(2006, 2, 14)),
    "SHP": pnp.Vendor(u"Sharp Corporation", "SHP", datetime.date(1996, 11, 29)),
    "SXT": pnp.Vendor(u"SHARP TAKAYA ELECTRONIC INDUSTRY CO.,LTD.", "SXT", datetime.date(2010, 6, 24)),
    "CZC": pnp.Vendor(u"Shenzhen ChuangZhiCheng Technology Co., Ltd.", "CZC", datetime.date(2013, 10, 23)),
    "IXN": pnp.Vendor(u"Shenzhen Inet Mobile Internet Technology Co., LTD", "IXN", datetime.date(2014, 11, 4)),
    "SZM": pnp.Vendor(u"Shenzhen MTC Co., Ltd", "SZM", datetime.date(2013, 8, 9)),
    "RMS": pnp.Vendor(u"Shenzhen Ramos Digital Technology Co., Ltd", "RMS", datetime.date(2014, 10, 29)),
    "SSL": pnp.Vendor(u"Shenzhen South-Top Computer Co., Ltd.", "SSL", datetime.date(2013, 12, 6)),
    "AZH": pnp.Vendor(u"Shenzhen three Connaught Information Technology Co., Ltd. (3nod Group)", "AZH", datetime.date(2013, 9, 17)),
    "XYE": pnp.Vendor(u"Shenzhen Zhuona Technology Co., Ltd.", "XYE", datetime.date(2013, 10, 1)),
    "HTR": pnp.Vendor(u"Shenzhen ZhuoYi HengTong Computer Technology Limited", "HTR", datetime.date(2013, 12, 13)),
    "ZWE": pnp.Vendor(u"Shenzhen Zowee Technology Co., LTD", "ZWE", datetime.date(2015, 5, 26)),
    "SDE": pnp.Vendor(u"Sherwood Digital Electronics Corporation", "SDE", datetime.date(1996, 11, 29)),
    "SHC": pnp.Vendor(u"ShibaSoku Co., Ltd.", "SHC", datetime.date(2005, 5, 26)),
    "SHT": pnp.Vendor(u"Shin Ho Tech", "SHT", datetime.date(1996, 11, 29)),
    "SLB": pnp.Vendor(u"Shlumberger Ltd", "SLB", datetime.date(1996, 11, 29)),
    "SAT": pnp.Vendor(u"Shuttle Tech", "SAT", datetime.date(1996, 11, 29)),
    "CHG": pnp.Vendor(u"Sichuan Changhong Electric CO, LTD.", "CHG", datetime.date(2003, 2, 26)),
    "CHO": pnp.Vendor(u"Sichuang Changhong Corporation", "CHO", datetime.date(2001, 11, 30)),
    "SIE": pnp.Vendor(u"Siemens", "SIE", datetime.date(1996, 11, 29)),
    "SDT": pnp.Vendor(u"Siemens AG", "SDT", datetime.date(2006, 2, 14)),
    "SIA": pnp.Vendor(u"SIEMENS AG", "SIA", datetime.date(2001, 3, 15)),
    "SNI": pnp.Vendor(u"Siemens Microdesign GmbH", "SNI", datetime.date(1996, 11, 29)),
    "SNP": pnp.Vendor(u"Siemens Nixdorf Info Systems", "SNP", datetime.date(1996, 11, 29)),
    "SSC": pnp.Vendor(u"Sierra Semiconductor Inc", "SSC", datetime.date(1996, 11, 29)),
    "SWI": pnp.Vendor(u"Sierra Wireless Inc.", "SWI", datetime.date(2003, 7, 10)),
    "SIG": pnp.Vendor(u"Sigma Designs Inc", "SIG", datetime.date(1996, 11, 29)),
    "SGD": pnp.Vendor(u"Sigma Designs, Inc.", "SGD", datetime.date(2006, 2, 14)),
    "SCL": pnp.Vendor(u"Sigmacom Co., Ltd.", "SCL", datetime.date(2002, 4, 25)),
    "STL": pnp.Vendor(u"SigmaTel Inc", "STL", datetime.date(1997, 3, 3)),
    "DXS": pnp.Vendor(u"Signet", "DXS", datetime.date(2000, 10, 23)),
    "STE": pnp.Vendor(u"SII Ido-Tsushin Inc", "STE", datetime.date(1997, 4, 3)),
    "SMT": pnp.Vendor(u"Silcom Manufacturing Tech Inc", "SMT", datetime.date(1996, 11, 29)),
    "SXD": pnp.Vendor(u"Silex technology, Inc.", "SXD", datetime.date(2009, 3, 12)),
    "SMS": pnp.Vendor(u"Silicom Multimedia Systems Inc", "SMS", datetime.date(1996, 12, 4)),
    "SGX": pnp.Vendor(u"Silicon Graphics Inc", "SGX", datetime.date(1996, 11, 29)),
    "SII": pnp.Vendor(u"Silicon Image, Inc.", "SII", datetime.date(2000, 1, 13)),
    "SIS": pnp.Vendor(u"Silicon Integrated Systems Corporation", "SIS", datetime.date(1996, 11, 29)),
    "SIL": pnp.Vendor(u"Silicon Laboratories, Inc", "SIL", datetime.date(1998, 7, 16)),
    "SLH": pnp.Vendor(u"Silicon Library Inc.", "SLH", datetime.date(2008, 11, 1)),
    "SOI": pnp.Vendor(u"Silicon Optix Corporation", "SOI", datetime.date(2005, 7, 28)),
    "SLK": pnp.Vendor(u"Silitek Corporation", "SLK", datetime.date(1997, 7, 16)),
    "SPU": pnp.Vendor(u"SIM2 Multimedia S.P.A.", "SPU", datetime.date(2002, 9, 5)),
    "SMP": pnp.Vendor(u"Simple Computing", "SMP", datetime.date(1996, 11, 29)),
    "SPX": pnp.Vendor(u"Simplex Time Recorder Co.", "SPX", datetime.date(2001, 3, 15)),
    "SIN": pnp.Vendor(u"Singular Technology Co., Ltd.", "SIN", datetime.date(1999, 11, 8)),
    "SNO": pnp.Vendor(u"SINOSUN TECHNOLOGY CO., LTD", "SNO", datetime.date(2005, 6, 27)),
    "SIR": pnp.Vendor(u"Sirius Technologies Pty Ltd", "SIR", datetime.date(1998, 3, 13)),
    "FUN": pnp.Vendor(u"sisel muhendislik", "FUN", datetime.date(2002, 4, 25)),
    "STS": pnp.Vendor(u"SITECSYSTEM CO., LTD.", "STS", datetime.date(2005, 3, 16)),
    "SIT": pnp.Vendor(u"Sitintel", "SIT", datetime.date(1996, 11, 29)),
    "SKY": pnp.Vendor(u"SKYDATA S.P.A.", "SKY", datetime.date(1997, 9, 19)),
    "SCT": pnp.Vendor(u"Smart Card Technology", "SCT", datetime.date(2000, 8, 10)),
    "SMA": pnp.Vendor(u"SMART Modular Technologies", "SMA", datetime.date(1997, 4, 4)),
    "SPL": pnp.Vendor(u"Smart Silicon Systems Pty Ltd", "SPL", datetime.date(2000, 8, 10)),
    "STI": pnp.Vendor(u"Smart Tech Inc", "STI", datetime.date(1996, 11, 29)),
    "SBI": pnp.Vendor(u"SMART Technologies Inc.", "SBI", datetime.date(2007, 6, 14)),
    "SMK": pnp.Vendor(u"SMK CORPORATION", "SMK", datetime.date(2000, 2, 21)),
    "SNW": pnp.Vendor(u"Snell & Wilcox", "SNW", datetime.date(2002, 4, 25)),
    "MVM": pnp.Vendor(u"SOBO VISION", "MVM", datetime.date(2007, 6, 14)),
    "SCX": pnp.Vendor(u"Socionext Inc.", "SCX", datetime.date(2015, 5, 14)),
    "LAN": pnp.Vendor(u"Sodeman Lancom Inc", "LAN", datetime.date(1996, 11, 29)),
    "SDF": pnp.Vendor(u"SODIFF E&T CO., Ltd.", "SDF", datetime.date(2007, 6, 1)),
    "SHG": pnp.Vendor(u"Soft & Hardware development Goldammer GmbH", "SHG", datetime.date(1996, 11, 29)),
    "SBD": pnp.Vendor(u"Softbed - Consulting & Development Ltd", "SBD", datetime.date(1997, 12, 23)),
    "SWC": pnp.Vendor(u"Software Caf\xe9", "SWC", datetime.date(1996, 11, 29)),
    "SWT": pnp.Vendor(u"Software Technologies Group,Inc.", "SWT", datetime.date(2008, 11, 29)),
    "SOL": pnp.Vendor(u"Solitron Technologies Inc", "SOL", datetime.date(1996, 11, 29)),
    "SLM": pnp.Vendor(u"Solomon Technology Corporation", "SLM", datetime.date(1998, 1, 16)),
    "SXL": pnp.Vendor(u"SolutionInside", "SXL", datetime.date(2001, 5, 8)),
    "ONX": pnp.Vendor(u"SOMELEC Z.I. Du Vert Galanta", "ONX", datetime.date(1996, 11, 29)),
    "HON": pnp.Vendor(u"Sonitronix", "HON", datetime.date(2011, 2, 3)),
    "SNX": pnp.Vendor(u"Sonix Comm. Ltd", "SNX", datetime.date(1996, 11, 29)),
    "SNY": pnp.Vendor(u"Sony", "SNY", datetime.date(1996, 11, 29)),
    "SON": pnp.Vendor(u"Sony", "SON", datetime.date(1996, 11, 29)),
    "SER": pnp.Vendor(u"Sony Ericsson Mobile Communications Inc.", "SER", datetime.date(2004, 4, 16)),
    "SCO": pnp.Vendor(u"SORCUS Computer GmbH", "SCO", datetime.date(2000, 1, 13)),
    "SOR": pnp.Vendor(u"Sorcus Computer GmbH", "SOR", datetime.date(1996, 11, 29)),
    "SCC": pnp.Vendor(u"SORD Computer Corporation", "SCC", datetime.date(1996, 11, 29)),
    "SOT": pnp.Vendor(u"Sotec Company Ltd", "SOT", datetime.date(1997, 5, 21)),
    "FRS": pnp.Vendor(u"South Mountain Technologies, LTD", "FRS", datetime.date(2006, 2, 14)),
    "SOY": pnp.Vendor(u"SOYO Group, Inc", "SOY", datetime.date(2006, 12, 18)),
    "SPI": pnp.Vendor(u"SPACE-I Co., Ltd.", "SPI", datetime.date(2005, 5, 11)),
    "SMI": pnp.Vendor(u"SpaceLabs Medical Inc", "SMI", datetime.date(1996, 11, 29)),
    "SPE": pnp.Vendor(u"SPEA Software AG", "SPE", datetime.date(1996, 11, 29)),
    "SPK": pnp.Vendor(u"SpeakerCraft", "SPK", datetime.date(2010, 4, 20)),
    "SLX": pnp.Vendor(u"Specialix", "SLX", datetime.date(1996, 11, 29)),
    "SGC": pnp.Vendor(u"Spectragraphics Corporation", "SGC", datetime.date(1996, 11, 29)),
    "SSP": pnp.Vendor(u"Spectrum Signal Proecessing Inc", "SSP", datetime.date(1996, 11, 29)),
    "SRS": pnp.Vendor(u"SR-Systems e.K.", "SRS", datetime.date(2012, 11, 19)),
    "SSI": pnp.Vendor(u"S-S Technology Inc", "SSI", datetime.date(1996, 11, 29)),
    "STA": pnp.Vendor(u"ST Electronics Systems Assembly Pte Ltd", "STA", datetime.date(1998, 12, 28)),
    "STC": pnp.Vendor(u"STAC Electronics", "STC", datetime.date(1996, 11, 29)),
    "SMC": pnp.Vendor(u"Standard Microsystems Corporation", "SMC", datetime.date(1996, 11, 29)),
    "STT": pnp.Vendor(u"Star Paging Telecom Tech (Shenzhen) Co. Ltd.", "STT", datetime.date(1998, 9, 23)),
    "STF": pnp.Vendor(u"Starflight Electronics", "STF", datetime.date(1997, 5, 23)),
    "SGT": pnp.Vendor(u"Stargate Technology", "SGT", datetime.date(1996, 11, 29)),
    "SLF": pnp.Vendor(u"StarLeaf", "SLF", datetime.date(2010, 11, 1)),
    "STR": pnp.Vendor(u"Starlight Networks Inc", "STR", datetime.date(1996, 11, 29)),
    "STW": pnp.Vendor(u"Starwin Inc.", "STW", datetime.date(2001, 4, 24)),
    "SWS": pnp.Vendor(u"Static", "SWS", datetime.date(1999, 5, 16)),
    "STB": pnp.Vendor(u"STB Systems Inc", "STB", datetime.date(1996, 11, 29)),
    "STD": pnp.Vendor(u"STD Computer Inc", "STD", datetime.date(1996, 11, 29)),
    "STG": pnp.Vendor(u"StereoGraphics Corp.", "STG", datetime.date(2001, 10, 2)),
    "STX": pnp.Vendor(u"ST-Ericsson", "STX", datetime.date(2011, 12, 9)),
    "SMO": pnp.Vendor(u"STMicroelectronics", "SMO", datetime.date(2007, 6, 14)),
    "STO": pnp.Vendor(u"Stollmann E+V GmbH", "STO", datetime.date(1997, 3, 27)),
    "SAS": pnp.Vendor(u"Stores Automated Systems Inc", "SAS", datetime.date(1997, 3, 19)),
    "EZP": pnp.Vendor(u"Storm Technology", "EZP", datetime.date(1996, 10, 17)),
    "STP": pnp.Vendor(u"StreamPlay Ltd", "STP", datetime.date(2009, 2, 4)),
    "SYK": pnp.Vendor(u"Stryker Communications", "SYK", datetime.date(2005, 10, 10)),
    "SUB": pnp.Vendor(u"Subspace Comm. Inc", "SUB", datetime.date(1996, 11, 29)),
    "SML": pnp.Vendor(u"Sumitomo Metal Industries, Ltd.", "SML", datetime.date(1999, 9, 13)),
    "SUM": pnp.Vendor(u"Summagraphics Corporation", "SUM", datetime.date(1996, 11, 29)),
    "SCE": pnp.Vendor(u"Sun Corporation", "SCE", datetime.date(1996, 11, 29)),
    "SUN": pnp.Vendor(u"Sun Electronics Corporation", "SUN", datetime.date(1996, 11, 29)),
    "SVI": pnp.Vendor(u"Sun Microsystems", "SVI", datetime.date(2003, 1, 13)),
    "SNN": pnp.Vendor(u"SUNNY ELEKTRONIK", "SNN", datetime.date(2014, 11, 14)),
    "SDS": pnp.Vendor(u"SunRiver Data System", "SDS", datetime.date(1996, 11, 29)),
    "SGL": pnp.Vendor(u"Super Gate Technology Company Ltd", "SGL", datetime.date(1997, 12, 30)),
    "SNT": pnp.Vendor(u"SuperNet Inc", "SNT", datetime.date(1998, 4, 23)),
    "SUP": pnp.Vendor(u"Supra Corporation", "SUP", datetime.date(1996, 11, 29)),
    "SUR": pnp.Vendor(u"Surenam Computer Corporation", "SUR", datetime.date(1996, 11, 29)),
    "SRF": pnp.Vendor(u"Surf Communication Solutions Ltd", "SRF", datetime.date(1998, 3, 23)),
    "SVD": pnp.Vendor(u"SVD Computer", "SVD", datetime.date(1998, 4, 14)),
    "SVS": pnp.Vendor(u"SVSI", "SVS", datetime.date(2008, 8, 9)),
    "SYE": pnp.Vendor(u"SY Electronics Ltd", "SYE", datetime.date(2010, 9, 20)),
    "SYL": pnp.Vendor(u"Sylvania Computer Products", "SYL", datetime.date(1998, 6, 12)),
    "SLI": pnp.Vendor(u"Symbios Logic Inc", "SLI", datetime.date(1996, 11, 29)),
    "ISA": pnp.Vendor(u"Symbol Technologies", "ISA", datetime.date(1997, 6, 2)),
    "SYM": pnp.Vendor(u"Symicron Computer Communications Ltd.", "SYM", datetime.date(1996, 11, 29)),
    "SYN": pnp.Vendor(u"Synaptics Inc", "SYN", datetime.date(1996, 11, 29)),
    "SPS": pnp.Vendor(u"Synopsys Inc", "SPS", datetime.date(1996, 11, 29)),
    "SXB": pnp.Vendor(u"Syntax-Brillian", "SXB", datetime.date(2006, 5, 8)),
    "SYP": pnp.Vendor(u"SYPRO Co Ltd", "SYP", datetime.date(1998, 11, 27)),
    "SYS": pnp.Vendor(u"Sysgration Ltd", "SYS", datetime.date(1997, 4, 28)),
    "SLC": pnp.Vendor(u"Syslogic Datentechnik AG", "SLC", datetime.date(1999, 1, 20)),
    "SME": pnp.Vendor(u"Sysmate Company", "SME", datetime.date(1997, 9, 2)),
    "SIC": pnp.Vendor(u"Sysmate Corporation", "SIC", datetime.date(1997, 5, 5)),
    "SYC": pnp.Vendor(u"Sysmic", "SYC", datetime.date(1996, 11, 29)),
    "SGZ": pnp.Vendor(u"Systec Computer GmbH", "SGZ", datetime.date(1997, 10, 2)),
    "SCI": pnp.Vendor(u"System Craft", "SCI", datetime.date(1996, 11, 29)),
    "SEB": pnp.Vendor(u"system elektronik GmbH", "SEB", datetime.date(2000, 4, 19)),
    "SLA": pnp.Vendor(u"Systeme Lauer GmbH&Co KG", "SLA", datetime.date(1999, 3, 20)),
    "UPS": pnp.Vendor(u"Systems Enhancement", "UPS", datetime.date(1996, 11, 29)),
    "SST": pnp.Vendor(u"SystemSoft Corporation", "SST", datetime.date(1996, 11, 29)),
    "SCR": pnp.Vendor(u"Systran Corporation", "SCR", datetime.date(1996, 11, 29)),
    "SYV": pnp.Vendor(u"SYVAX Inc", "SYV", datetime.date(1996, 11, 29)),
    "TUA": pnp.Vendor(u"T+A elektroakustik GmbH", "TUA", datetime.date(2011, 1, 5)),
    "TCD": pnp.Vendor(u"Taicom Data Systems Co., Ltd.", "TCD", datetime.date(2001, 10, 8)),
    "TMR": pnp.Vendor(u"Taicom International Inc", "TMR", datetime.date(1996, 11, 29)),
    "TKC": pnp.Vendor(u"Taiko Electric Works.LTD", "TKC", datetime.date(2001, 3, 15)),
    "TVM": pnp.Vendor(u"Taiwan Video & Monitor Corporation", "TVM", datetime.date(1996, 11, 29)),
    "KTD": pnp.Vendor(u"Takahata Electronics Co.,Ltd.", "KTD", datetime.date(2009, 7, 22)),
    "TAM": pnp.Vendor(u"Tamura Seisakusyo Ltd", "TAM", datetime.date(1997, 7, 17)),
    "TAA": pnp.Vendor(u"Tandberg", "TAA", datetime.date(2003, 10, 21)),
    "TDD": pnp.Vendor(u"Tandberg Data Display AS", "TDD", datetime.date(1996, 11, 29)),
    "TDM": pnp.Vendor(u"Tandem Computer Europe Inc", "TDM", datetime.date(1996, 11, 29)),
    "TCC": pnp.Vendor(u"Tandon Corporation", "TCC", datetime.date(1996, 11, 29)),
    "TDY": pnp.Vendor(u"Tandy Electronics", "TDY", datetime.date(1996, 11, 29)),
    "TAS": pnp.Vendor(u"Taskit Rechnertechnik GmbH", "TAS", datetime.date(1997, 12, 15)),
    "TCS": pnp.Vendor(u"Tatung Company of America Inc", "TCS", datetime.date(1996, 11, 29)),
    "VIB": pnp.Vendor(u"Tatung UK Ltd", "VIB", datetime.date(1999, 7, 16)),
    "NRV": pnp.Vendor(u"Taugagreining hf", "NRV", datetime.date(1996, 11, 29)),
    "TAX": pnp.Vendor(u"Taxan (Europe) Ltd", "TAX", datetime.date(1997, 3, 13)),
    "PMD": pnp.Vendor(u"TDK USA Corporation", "PMD", datetime.date(1996, 11, 29)),
    "TDT": pnp.Vendor(u"TDT", "TDT", datetime.date(1996, 11, 29)),
    "TDV": pnp.Vendor(u"TDVision Systems, Inc.", "TDV", datetime.date(2008, 1, 18)),
    "TEA": pnp.Vendor(u"TEAC System Corporation", "TEA", datetime.date(1996, 11, 29)),
    "CET": pnp.Vendor(u"TEC CORPORATION", "CET", datetime.date(1998, 7, 16)),
    "TCJ": pnp.Vendor(u"TEAC America Inc", "TCJ", datetime.date(1996, 11, 29)),
    "TEZ": pnp.Vendor(u"Tech Source Inc.", "TEZ", datetime.date(2013, 8, 14)),
    "TMC": pnp.Vendor(u"Techmedia Computer Systems Corporation", "TMC", datetime.date(1998, 2, 10)),
    "TCL": pnp.Vendor(u"Technical Concepts Ltd", "TCL", datetime.date(1996, 11, 29)),
    "TIL": pnp.Vendor(u"Technical Illusions Inc.", "TIL", datetime.date(2014, 2, 14)),
    "TSD": pnp.Vendor(u"TechniSat Digital GmbH", "TSD", datetime.date(2005, 7, 14)),
    "NXS": pnp.Vendor(u"Technology Nexus Secure Open Systems AB", "NXS", datetime.date(1998, 5, 8)),
    "TPE": pnp.Vendor(u"Technology Power Enterprises Inc", "TPE", datetime.date(1996, 11, 29)),
    "TTS": pnp.Vendor(u"TechnoTrend Systemtechnik GmbH", "TTS", datetime.date(1996, 11, 29)),
    "TEC": pnp.Vendor(u"Tecmar Inc", "TEC", datetime.date(1996, 11, 29)),
    "TCN": pnp.Vendor(u"Tecnetics (PTY) Ltd", "TCN", datetime.date(1996, 11, 29)),
    "TNM": pnp.Vendor(u"TECNIMAGEN SA", "TNM", datetime.date(2005, 5, 2)),
    "TVD": pnp.Vendor(u"Tecnovision", "TVD", datetime.date(2006, 3, 13)),
    "RXT": pnp.Vendor(u"Tectona SoftSolutions (P) Ltd.,", "RXT", datetime.date(2004, 6, 2)),
    "TKN": pnp.Vendor(u"Teknor Microsystem Inc", "TKN", datetime.date(1996, 11, 29)),
    "TRM": pnp.Vendor(u"Tekram Technology Company Ltd", "TRM", datetime.date(1996, 11, 29)),
    "TEK": pnp.Vendor(u"Tektronix Inc", "TEK", datetime.date(1999, 5, 16)),
    "TWX": pnp.Vendor(u"TEKWorx Limited", "TWX", datetime.date(2009, 12, 24)),
    "TCT": pnp.Vendor(u"Telecom Technology Centre Co. Ltd.", "TCT", datetime.date(1999, 7, 16)),
    "TTC": pnp.Vendor(u"Telecommunications Techniques Corporation", "TTC", datetime.date(1996, 11, 29)),
    "TLF": pnp.Vendor(u"Teleforce.,co,ltd", "TLF", datetime.date(2012, 11, 19)),
    "TAT": pnp.Vendor(u"Teleliaison Inc", "TAT", datetime.date(1997, 4, 29)),
    "TLK": pnp.Vendor(u"Telelink AG", "TLK", datetime.date(1998, 9, 1)),
    "TPS": pnp.Vendor(u"Teleprocessing Systeme GmbH", "TPS", datetime.date(1997, 1, 24)),
    "TAG": pnp.Vendor(u"Teles AG", "TAG", datetime.date(1996, 11, 29)),
    "TLS": pnp.Vendor(u"Teleste Educational OY", "TLS", datetime.date(1996, 11, 29)),
    "TSI": pnp.Vendor(u"TeleVideo Systems", "TSI", datetime.date(1996, 11, 29)),
    "PFT": pnp.Vendor(u"Telia ProSoft AB", "PFT", datetime.date(1999, 9, 13)),
    "TLD": pnp.Vendor(u"Telindus", "TLD", datetime.date(1996, 11, 29)),
    "TLX": pnp.Vendor(u"Telxon Corporation", "TLX", datetime.date(1996, 11, 29)),
    "TNY": pnp.Vendor(u"Tennyson Tech Pty Ltd", "TNY", datetime.date(1996, 11, 29)),
    "TDC": pnp.Vendor(u"Teradici", "TDC", datetime.date(2007, 10, 11)),
    "TER": pnp.Vendor(u"TerraTec Electronic GmbH", "TER", datetime.date(1997, 3, 21)),
    "TXN": pnp.Vendor(u"Texas Insturments", "TXN", datetime.date(1996, 11, 29)),
    "TMI": pnp.Vendor(u"Texas Microsystem", "TMI", datetime.date(1996, 11, 29)),
    "TXT": pnp.Vendor(u"Textron Defense System", "TXT", datetime.date(1996, 11, 29)),
    "CKC": pnp.Vendor(u"The Concept Keyboard Company Ltd", "CKC", datetime.date(1997, 6, 2)),
    "LNX": pnp.Vendor(u"The Linux Foundation", "LNX", datetime.date(2014, 4, 4)),
    "PXL": pnp.Vendor(u"The Moving Pixel Company", "PXL", datetime.date(2003, 11, 24)),
    "ITN": pnp.Vendor(u"The NTI Group", "ITN", datetime.date(1996, 11, 29)),
    "TOG": pnp.Vendor(u"The OPEN Group", "TOG", datetime.date(1999, 9, 13)),
    "PAN": pnp.Vendor(u"The Panda Project", "PAN", datetime.date(1996, 11, 29)),
    "PRG": pnp.Vendor(u"The Phoenix Research Group Inc", "PRG", datetime.date(1997, 9, 19)),
    "TSG": pnp.Vendor(u"The Software Group Ltd", "TSG", datetime.date(1996, 11, 29)),
    "TMX": pnp.Vendor(u"Thermotrex Corporation", "TMX", datetime.date(1996, 11, 29)),
    "TLL": pnp.Vendor(u"Thinklogical", "TLL", datetime.date(2015, 6, 1)),
    "TCO": pnp.Vendor(u"Thomas-Conrad Corporation", "TCO", datetime.date(1996, 11, 29)),
    "TCR": pnp.Vendor(u"Thomson Consumer Electronics", "TCR", datetime.date(1998, 8, 20)),
    "TPT": pnp.Vendor(u"Thruput Ltd", "TPT", datetime.date(2010, 6, 16)),
    "THN": pnp.Vendor(u"Thundercom Holdings Sdn. Bhd.", "THN", datetime.date(1997, 3, 21)),
    "TWA": pnp.Vendor(u"Tidewater Association", "TWA", datetime.date(1996, 11, 29)),
    "TMM": pnp.Vendor(u"Time Management, Inc.", "TMM", datetime.date(1999, 3, 20)),
    "TKS": pnp.Vendor(u"TimeKeeping Systems, Inc.", "TKS", datetime.date(1998, 8, 31)),
    "TPD": pnp.Vendor(u"Times (Shanghai) Computer Co., Ltd.", "TPD", datetime.date(2013, 12, 12)),
    "TIP": pnp.Vendor(u"TIPTEL AG", "TIP", datetime.date(1998, 2, 24)),
    "TIX": pnp.Vendor(u"Tixi.Com GmbH", "TIX", datetime.date(1998, 10, 16)),
    "TMT": pnp.Vendor(u"T-Metrics Inc.", "TMT", datetime.date(2000, 2, 21)),
    "TNC": pnp.Vendor(u"TNC Industrial Company Ltd", "TNC", datetime.date(1998, 2, 27)),
    "TAB": pnp.Vendor(u"Todos Data System AB", "TAB", datetime.date(1997, 8, 20)),
    "TOE": pnp.Vendor(u"TOEI Electronics Co., Ltd.", "TOE", datetime.date(2001, 10, 2)),
    "TON": pnp.Vendor(u"TONNA", "TON", datetime.date(2012, 3, 14)),
    "TPV": pnp.Vendor(u"Top Victory Electronics ( Fujian ) Company Ltd", "TPV", datetime.date(1999, 5, 16)),
    "TPK": pnp.Vendor(u"TOPRE CORPORATION", "TPK", datetime.date(2009, 2, 13)),
    "TPR": pnp.Vendor(u"Topro Technology Inc", "TPR", datetime.date(1998, 5, 8)),
    "TTA": pnp.Vendor(u"Topson Technology Co., Ltd.", "TTA", datetime.date(1998, 9, 23)),
    "SFM": pnp.Vendor(u"TORNADO Company", "SFM", datetime.date(1997, 4, 15)),
    "TGS": pnp.Vendor(u"Torus Systems Ltd", "TGS", datetime.date(1996, 11, 29)),
    "TRS": pnp.Vendor(u"Torus Systems Ltd", "TRS", datetime.date(1996, 11, 29)),
    "TAI": pnp.Vendor(u"Toshiba America Info Systems Inc", "TAI", datetime.date(1996, 11, 29)),
    "TSB": pnp.Vendor(u"Toshiba America Info Systems Inc", "TSB", datetime.date(1996, 11, 29)),
    "TOS": pnp.Vendor(u"Toshiba Corporation", "TOS", datetime.date(1996, 11, 29)),
    "TTP": pnp.Vendor(u"Toshiba Corporation", "TTP", datetime.date(2015, 7, 7)),
    "TGC": pnp.Vendor(u"Toshiba Global Commerce Solutions, Inc.", "TGC", datetime.date(2012, 6, 26)),
    "LCD": pnp.Vendor(u"Toshiba Matsushita Display Technology Co., Ltd", "LCD", datetime.date(2000, 5, 24)),
    "PCS": pnp.Vendor(u"TOSHIBA PERSONAL COMPUTER SYSTEM CORPRATION", "PCS", datetime.date(2010, 6, 22)),
    "TLI": pnp.Vendor(u"TOSHIBA TELI CORPORATION", "TLI", datetime.date(2008, 1, 18)),
    "TTK": pnp.Vendor(u"Totoku Electric Company Ltd", "TTK", datetime.date(1996, 11, 29)),
    "TSE": pnp.Vendor(u"Tottori Sanyo Electric", "TSE", datetime.date(1996, 11, 29)),
    "TSL": pnp.Vendor(u"Tottori SANYO Electric Co., Ltd.", "TSL", datetime.date(2001, 11, 6)),
    "TPC": pnp.Vendor(u"Touch Panel Systems Corporation", "TPC", datetime.date(1997, 9, 2)),
    "TKO": pnp.Vendor(u"TouchKo, Inc.", "TKO", datetime.date(2006, 1, 12)),
    "TOU": pnp.Vendor(u"Touchstone Technology", "TOU", datetime.date(2001, 5, 7)),
    "TSY": pnp.Vendor(u"TouchSystems", "TSY", datetime.date(2008, 1, 18)),
    "TWK": pnp.Vendor(u"TOWITOKO electronics GmbH", "TWK", datetime.date(1998, 4, 14)),
    "CSB": pnp.Vendor(u"Transtex SA", "CSB", datetime.date(2001, 3, 15)),
    "TST": pnp.Vendor(u"Transtream Inc", "TST", datetime.date(1997, 4, 29)),
    "TSV": pnp.Vendor(u"TRANSVIDEO", "TSV", datetime.date(2010, 5, 4)),
    "TRE": pnp.Vendor(u"Tremetrics", "TRE", datetime.date(1997, 4, 24)),
    "RDM": pnp.Vendor(u"Tremon Enterprises Company Ltd", "RDM", datetime.date(1996, 11, 29)),
    "TTI": pnp.Vendor(u"Trenton Terminals Inc", "TTI", datetime.date(1996, 11, 29)),
    "TRX": pnp.Vendor(u"Trex Enterprises", "TRX", datetime.date(2000, 2, 21)),
    "OZO": pnp.Vendor(u"Tribe Computer Works Inc", "OZO", datetime.date(1996, 11, 29)),
    "TRI": pnp.Vendor(u"Tricord Systems", "TRI", datetime.date(1996, 11, 29)),
    "TDS": pnp.Vendor(u"Tri-Data Systems Inc", "TDS", datetime.date(1996, 11, 29)),
    "TTY": pnp.Vendor(u"TRIDELITY Display Solutions GmbH", "TTY", datetime.date(2010, 7, 19)),
    "TRD": pnp.Vendor(u"Trident Microsystem Inc", "TRD", datetime.date(1996, 11, 29)),
    "TMS": pnp.Vendor(u"Trident Microsystems Ltd", "TMS", datetime.date(2002, 7, 15)),
    "TGI": pnp.Vendor(u"TriGem Computer Inc", "TGI", datetime.date(1996, 11, 29)),
    "TGM": pnp.Vendor(u"TriGem Computer,Inc.", "TGM", datetime.date(2001, 7, 5)),
    "TIC": pnp.Vendor(u"Trigem KinfoComm", "TIC", datetime.date(2003, 2, 26)),
    "TRC": pnp.Vendor(u"Trioc AB", "TRC", datetime.date(2000, 1, 13)),
    "TBB": pnp.Vendor(u"Triple S Engineering Inc", "TBB", datetime.date(1997, 9, 26)),
    "TRT": pnp.Vendor(u"Tritec Electronic AG", "TRT", datetime.date(2012, 1, 11)),
    "TRA": pnp.Vendor(u"TriTech Microelectronics International", "TRA", datetime.date(1997, 1, 24)),
    "TRB": pnp.Vendor(u"Triumph Board a.s.", "TRB", datetime.date(2013, 9, 27)),
    "TRV": pnp.Vendor(u"Trivisio Prototyping GmbH", "TRV", datetime.date(2011, 11, 18)),
    "TXL": pnp.Vendor(u"Trixel Ltd", "TXL", datetime.date(2000, 8, 10)),
    "MKV": pnp.Vendor(u"Trtheim Technology", "MKV", datetime.date(1997, 3, 17)),
    "TVI": pnp.Vendor(u"Truevision", "TVI", datetime.date(1996, 11, 29)),
    "TTE": pnp.Vendor(u"TTE, Inc.", "TTE", datetime.date(2005, 1, 18)),
    "TCI": pnp.Vendor(u"Tulip Computers Int'l B.V.", "TCI", datetime.date(1996, 11, 29)),
    "TBC": pnp.Vendor(u"Turbo Communication, Inc", "TBC", datetime.date(1998, 9, 1)),
    "TBS": pnp.Vendor(u"Turtle Beach System", "TBS", datetime.date(1996, 11, 29)),
    "TUT": pnp.Vendor(u"Tut Systems", "TUT", datetime.date(1997, 8, 19)),
    "TVR": pnp.Vendor(u"TV Interactive Corporation", "TVR", datetime.date(1996, 11, 29)),
    "TVO": pnp.Vendor(u"TV One Ltd", "TVO", datetime.date(2008, 9, 2)),
    "TVV": pnp.Vendor(u"TV1 GmbH", "TVV", datetime.date(2012, 2, 6)),
    "TVS": pnp.Vendor(u"TVS Electronics Limited", "TVS", datetime.date(2008, 5, 20)),
    "TWH": pnp.Vendor(u"Twinhead International Corporation", "TWH", datetime.date(1996, 11, 29)),
    "TYN": pnp.Vendor(u"Tyan Computer Corporation", "TYN", datetime.date(1996, 11, 29)),
    "USE": pnp.Vendor(u"U. S. Electronics Inc.", "USE", datetime.date(2013, 10, 28)),
    "NRL": pnp.Vendor(u"U.S. Naval Research Lab", "NRL", datetime.date(1996, 11, 29)),
    "TSP": pnp.Vendor(u"U.S. Navy", "TSP", datetime.date(2002, 10, 17)),
    "USD": pnp.Vendor(u"U.S. Digital Corporation", "USD", datetime.date(1996, 11, 29)),
    "USR": pnp.Vendor(u"U.S. Robotics Inc", "USR", datetime.date(1996, 11, 29)),
    "UBL": pnp.Vendor(u"Ubinetics Ltd.", "UBL", datetime.date(2002, 5, 23)),
    "UJR": pnp.Vendor(u"Ueda Japan Radio Co., Ltd.", "UJR", datetime.date(2003, 7, 9)),
    "UFO": pnp.Vendor(u"UFO Systems Inc", "UFO", datetime.date(1996, 11, 29)),
    "UAS": pnp.Vendor(u"Ultima Associates Pte Ltd", "UAS", datetime.date(1997, 1, 2)),
    "UEC": pnp.Vendor(u"Ultima Electronics Corporation", "UEC", datetime.date(1998, 9, 1)),
    "ULT": pnp.Vendor(u"Ultra Network Tech", "ULT", datetime.date(1996, 11, 29)),
    "UMG": pnp.Vendor(u"Umezawa Giken Co.,Ltd", "UMG", datetime.date(2008, 4, 10)),
    "UBI": pnp.Vendor(u"Ungermann-Bass Inc", "UBI", datetime.date(1996, 11, 29)),
    "UNY": pnp.Vendor(u"Unicate", "UNY", datetime.date(1998, 7, 21)),
    "UDN": pnp.Vendor(u"Uniden Corporation", "UDN", datetime.date(2004, 10, 18)),
    "UIC": pnp.Vendor(u"Uniform Industrial Corporation", "UIC", datetime.date(1996, 11, 29)),
    "UNI": pnp.Vendor(u"Uniform Industry Corp.", "UNI", datetime.date(2001, 11, 6)),
    "UFG": pnp.Vendor(u"UNIGRAF-USA", "UFG", datetime.date(2008, 10, 9)),
    "UNB": pnp.Vendor(u"Unisys Corporation", "UNB", datetime.date(1996, 11, 29)),
    "UNC": pnp.Vendor(u"Unisys Corporation", "UNC", datetime.date(1996, 11, 29)),
    "UNM": pnp.Vendor(u"Unisys Corporation", "UNM", datetime.date(1996, 11, 29)),
    "UNO": pnp.Vendor(u"Unisys Corporation", "UNO", datetime.date(1996, 11, 29)),
    "UNS": pnp.Vendor(u"Unisys Corporation", "UNS", datetime.date(1996, 11, 29)),
    "UNT": pnp.Vendor(u"Unisys Corporation", "UNT", datetime.date(1996, 11, 29)),
    "UNA": pnp.Vendor(u"Unisys DSD", "UNA", datetime.date(1996, 11, 29)),
    "WKH": pnp.Vendor(u"Uni-Take Int'l Inc.", "WKH", datetime.date(2002, 6, 17)),
    "UMC": pnp.Vendor(u"United Microelectr Corporation", "UMC", datetime.date(1996, 11, 29)),
    "UNP": pnp.Vendor(u"Unitop", "UNP", datetime.date(2001, 11, 6)),
    "UEI": pnp.Vendor(u"Universal Electronics Inc", "UEI", datetime.date(1997, 8, 20)),
    "UET": pnp.Vendor(u"Universal Empowering Technologies", "UET", datetime.date(1997, 9, 26)),
    "UMM": pnp.Vendor(u"Universal Multimedia", "UMM", datetime.date(2001, 10, 8)),
    "USI": pnp.Vendor(u"Universal Scientific Industrial Co., Ltd.", "USI", datetime.date(2003, 11, 4)),
    "JGD": pnp.Vendor(u"University College", "JGD", datetime.date(1996, 11, 29)),
    "UWC": pnp.Vendor(u"Uniwill Computer Corp.", "UWC", datetime.date(2004, 4, 16)),
    "UTD": pnp.Vendor(u"Up to Date Tech", "UTD", datetime.date(1996, 11, 29)),
    "UPP": pnp.Vendor(u"UPPI", "UPP", datetime.date(1998, 4, 14)),
    "RUP": pnp.Vendor(u"Ups Manufactoring s.r.l.", "RUP", datetime.date(2001, 3, 15)),
    "ASD": pnp.Vendor(u"USC Information Sciences Institute", "ASD", datetime.date(1997, 4, 8)),
    "USA": pnp.Vendor(u"Utimaco Safeware AG", "USA", datetime.date(1998, 5, 4)),
    "VAD": pnp.Vendor(u"Vaddio, LLC", "VAD", datetime.date(2012, 11, 30)),
    "VDM": pnp.Vendor(u"Vadem", "VDM", datetime.date(1996, 11, 29)),
    "VAI": pnp.Vendor(u"VAIO Corporation", "VAI", datetime.date(2014, 4, 18)),
    "VAL": pnp.Vendor(u"Valence Computing Corporation", "VAL", datetime.date(1996, 11, 29)),
    "VBT": pnp.Vendor(u"Valley Board Ltda", "VBT", datetime.date(2001, 3, 15)),
    "VLB": pnp.Vendor(u"ValleyBoard Ltda.", "VLB", datetime.date(1998, 4, 5)),
    "VLV": pnp.Vendor(u"Valve Corporation", "VLV", datetime.date(2013, 3, 6)),
    "ITI": pnp.Vendor(u"VanErum Group", "ITI", datetime.date(2013, 10, 1)),
    "VAR": pnp.Vendor(u"Varian Australia Pty Ltd", "VAR", datetime.date(2000, 4, 19)),
    "VTV": pnp.Vendor(u"VATIV Technologies", "VTV", datetime.date(2006, 4, 12)),
    "VBR": pnp.Vendor(u"VBrick Systems Inc.", "VBR", datetime.date(2009, 8, 19)),
    "VCX": pnp.Vendor(u"VCONEX", "VCX", datetime.date(2005, 6, 15)),
    "VDC": pnp.Vendor(u"VDC Display Systems", "VDC", datetime.date(2009, 4, 29)),
    "VEC": pnp.Vendor(u"Vector Informatik GmbH", "VEC", datetime.date(1997, 9, 10)),
    "VCM": pnp.Vendor(u"Vector Magnetics, LLC", "VCM", datetime.date(2006, 4, 12)),
    "VEK": pnp.Vendor(u"Vektrex", "VEK", datetime.date(1996, 12, 13)),
    "VFI": pnp.Vendor(u"VeriFone Inc", "VFI", datetime.date(1998, 5, 29)),
    "VMI": pnp.Vendor(u"Vermont Microsystems", "VMI", datetime.date(1996, 11, 29)),
    "VTX": pnp.Vendor(u"Vestax Corporation", "VTX", datetime.date(2012, 2, 14)),
    "VES": pnp.Vendor(u"Vestel Elektronik Sanayi ve Ticaret A. S.", "VES", datetime.date(1997, 9, 19)),
    "VIM": pnp.Vendor(u"Via Mons Ltd.", "VIM", datetime.date(2012, 8, 29)),
    "VIA": pnp.Vendor(u"VIA Tech Inc", "VIA", datetime.date(1996, 11, 29)),
    "VCJ": pnp.Vendor(u"Victor Company of Japan, Limited", "VCJ", datetime.date(2009, 2, 6)),
    "VDA": pnp.Vendor(u"Victor Data Systems", "VDA", datetime.date(2000, 5, 24)),
    "VIC": pnp.Vendor(u"Victron B.V.", "VIC", datetime.date(1996, 11, 29)),
    "VDO": pnp.Vendor(u"Video & Display Oriented Corporation", "VDO", datetime.date(1996, 11, 29)),
    "URD": pnp.Vendor(u"Video Computer S.p.A.", "URD", datetime.date(1998, 2, 24)),
    "JWD": pnp.Vendor(u"Video International Inc.", "JWD", datetime.date(2000, 2, 21)),
    "VPI": pnp.Vendor(u"Video Products Inc", "VPI", datetime.date(2010, 5, 4)),
    "VLT": pnp.Vendor(u"VideoLan Technologies", "VLT", datetime.date(1997, 10, 17)),
    "VSI": pnp.Vendor(u"VideoServer", "VSI", datetime.date(1997, 6, 25)),
    "VTB": pnp.Vendor(u"Videotechnik Breithaupt", "VTB", datetime.date(2013, 7, 23)),
    "VTN": pnp.Vendor(u"VIDEOTRON CORP.", "VTN", datetime.date(2010, 5, 4)),
    "VDS": pnp.Vendor(u"Vidisys GmbH & Company", "VDS", datetime.date(1996, 11, 29)),
    "VDT": pnp.Vendor(u"Viditec, Inc.", "VDT", datetime.date(1999, 11, 8)),
    "VSC": pnp.Vendor(u"ViewSonic Corporation", "VSC", datetime.date(1996, 11, 29)),
    "VTK": pnp.Vendor(u"Viewteck Co., Ltd.", "VTK", datetime.date(2001, 10, 8)),
    "VIK": pnp.Vendor(u"Viking Connectors", "VIK", datetime.date(1996, 11, 29)),
    "VNC": pnp.Vendor(u"Vinca Corporation", "VNC", datetime.date(1996, 11, 29)),
    "NHT": pnp.Vendor(u"Vinci Labs", "NHT", datetime.date(2006, 3, 3)),
    "VML": pnp.Vendor(u"Vine Micros Limited", "VML", datetime.date(2004, 6, 16)),
    "VIN": pnp.Vendor(u"Vine Micros Ltd", "VIN", datetime.date(2000, 4, 19)),
    "VCC": pnp.Vendor(u"Virtual Computer Corporation", "VCC", datetime.date(1996, 11, 29)),
    "VRC": pnp.Vendor(u"Virtual Resources Corporation", "VRC", datetime.date(1996, 11, 29)),
    "VQ@": pnp.Vendor(u"Vision Quest", "VQ@", datetime.date(2009, 10, 26)),
    "VSP": pnp.Vendor(u"Vision Systems GmbH", "VSP", datetime.date(1996, 11, 29)),
    "VIS": pnp.Vendor(u"Visioneer", "VIS", datetime.date(1996, 11, 29)),
    "VIT": pnp.Vendor(u"Visitech AS", "VIT", datetime.date(2006, 9, 5)),
    "VLK": pnp.Vendor(u"Vislink International Ltd", "VLK", datetime.date(2012, 8, 27)),
    "VCI": pnp.Vendor(u"VistaCom Inc", "VCI", datetime.date(1996, 11, 29)),
    "VIR": pnp.Vendor(u"Visual Interface, Inc", "VIR", datetime.date(1998, 11, 27)),
    "VTL": pnp.Vendor(u"Vivid Technology Pte Ltd", "VTL", datetime.date(1996, 11, 29)),
    "VIZ": pnp.Vendor(u"VIZIO, Inc", "VIZ", datetime.date(2012, 6, 6)),
    "VTI": pnp.Vendor(u"VLSI Tech Inc", "VTI", datetime.date(1996, 11, 29)),
    "VMW": pnp.Vendor(u"VMware Inc.,", "VMW", datetime.date(2011, 10, 18)),
    "VTG": pnp.Vendor(u"Voice Technologies Group Inc", "VTG", datetime.date(1997, 4, 24)),
    "GDT": pnp.Vendor(u"Vortex Computersysteme GmbH", "GDT", datetime.date(1996, 11, 29)),
    "VPX": pnp.Vendor(u"VPixx Technologies Inc.", "VPX", datetime.date(2013, 12, 5)),
    "VRM": pnp.Vendor(u"VRmagic Holding AG", "VRM", datetime.date(2013, 4, 12)),
    "VSR": pnp.Vendor(u"V-Star Electronics Inc.", "VSR", datetime.date(2000, 2, 21)),
    "VTS": pnp.Vendor(u"VTech Computers Ltd", "VTS", datetime.date(1996, 11, 29)),
    "VTC": pnp.Vendor(u"VTel Corporation", "VTC", datetime.date(1996, 11, 29)),
    "VUT": pnp.Vendor(u"Vutrix (UK) Ltd", "VUT", datetime.date(2003, 7, 22)),
    "VWB": pnp.Vendor(u"Vweb Corp.", "VWB", datetime.date(2004, 3, 12)),
    "WAC": pnp.Vendor(u"Wacom Tech", "WAC", datetime.date(1996, 11, 29)),
    "JPW": pnp.Vendor(u"Wallis Hamilton Industries", "JPW", datetime.date(1999, 7, 16)),
    "MLT": pnp.Vendor(u"Wanlida Group Co., Ltd.", "MLT", datetime.date(2014, 4, 24)),
    "WAL": pnp.Vendor(u"Wave Access", "WAL", datetime.date(1996, 12, 13)),
    "AWS": pnp.Vendor(u"Wave Systems", "AWS", datetime.date(1996, 11, 29)),
    "WVM": pnp.Vendor(u"Wave Systems Corporation", "WVM", datetime.date(1997, 12, 5)),
    "WAV": pnp.Vendor(u"Wavephore", "WAV", datetime.date(1996, 11, 29)),
    "SEL": pnp.Vendor(u"Way2Call Communications", "SEL", datetime.date(1997, 3, 20)),
    "WBS": pnp.Vendor(u"WB Systemtechnik GmbH", "WBS", datetime.date(1997, 9, 8)),
    "WEL": pnp.Vendor(u"W-DEV", "WEL", datetime.date(2010, 11, 1)),
    "WPI": pnp.Vendor(u"Wearnes Peripherals International (Pte) Ltd", "WPI", datetime.date(1998, 3, 31)),
    "WTK": pnp.Vendor(u"Wearnes Thakral Pte", "WTK", datetime.date(1996, 11, 29)),
    "WEB": pnp.Vendor(u"WebGear Inc", "WEB", datetime.date(1998, 1, 30)),
    "WMO": pnp.Vendor(u"Westermo Teleindustri AB", "WMO", datetime.date(2000, 1, 13)),
    "WDC": pnp.Vendor(u"Western Digital", "WDC", datetime.date(1996, 11, 29)),
    "WDE": pnp.Vendor(u"Westinghouse Digital Electronics", "WDE", datetime.date(2003, 5, 23)),
    "WEY": pnp.Vendor(u"WEY Design AG", "WEY", datetime.date(2004, 10, 18)),
    "WHI": pnp.Vendor(u"Whistle Communications", "WHI", datetime.date(1998, 10, 24)),
    "WLD": pnp.Vendor(u"Wildfire Communications Inc", "WLD", datetime.date(1997, 2, 13)),
    "WNI": pnp.Vendor(u"WillNet Inc.", "WNI", datetime.date(2000, 4, 19)),
    "WEC": pnp.Vendor(u"Winbond Electronics Corporation", "WEC", datetime.date(1996, 11, 29)),
    "WNX": pnp.Vendor(u"Wincor Nixdorf International GmbH", "WNX", datetime.date(2004, 9, 20)),
    "WMT": pnp.Vendor(u"Winmate Communication Inc", "WMT", datetime.date(2001, 3, 15)),
    "WNV": pnp.Vendor(u"Winnov L.P.", "WNV", datetime.date(1997, 3, 7)),
    "WRC": pnp.Vendor(u"WiNRADiO Communications", "WRC", datetime.date(1997, 9, 11)),
    "WIN": pnp.Vendor(u"Wintop Technology Inc", "WIN", datetime.date(1996, 12, 29)),
    "WWP": pnp.Vendor(u"Wipotec Wiege- und Positioniersysteme GmbH", "WWP", datetime.date(2014, 4, 8)),
    "WIL": pnp.Vendor(u"WIPRO Information Technology Ltd", "WIL", datetime.date(1996, 11, 29)),
    "WIP": pnp.Vendor(u"Wipro Infotech", "WIP", datetime.date(2004, 1, 9)),
    "WSP": pnp.Vendor(u"Wireless And Smart Products Inc.", "WSP", datetime.date(1999, 3, 20)),
    "WCI": pnp.Vendor(u"Wisecom Inc", "WCI", datetime.date(1996, 11, 29)),
    "WST": pnp.Vendor(u"Wistron Corporation", "WST", datetime.date(2010, 9, 3)),
    "WML": pnp.Vendor(u"Wolfson Microelectronics Ltd", "WML", datetime.date(1997, 7, 30)),
    "WVV": pnp.Vendor(u"WolfVision GmbH", "WVV", datetime.date(2012, 9, 18)),
    "WCS": pnp.Vendor(u"Woodwind Communications Systems Inc", "WCS", datetime.date(1996, 11, 29)),
    "WYT": pnp.Vendor(u"Wooyoung Image & Information Co.,Ltd.", "WYT", datetime.date(2008, 1, 18)),
    "WTI": pnp.Vendor(u"WorkStation Tech", "WTI", datetime.date(1996, 11, 29)),
    "WWV": pnp.Vendor(u"World Wide Video, Inc.", "WWV", datetime.date(1998, 10, 24)),
    "WXT": pnp.Vendor(u"Woxter Technology Co. Ltd", "WXT", datetime.date(2010, 9, 3)),
    "XTN": pnp.Vendor(u"X-10 (USA) Inc", "XTN", datetime.date(1997, 2, 24)),
    "XTE": pnp.Vendor(u"X2E GmbH", "XTE", datetime.date(2009, 9, 23)),
    "XAC": pnp.Vendor(u"XAC Automation Corp", "XAC", datetime.date(1999, 2, 22)),
    "XDM": pnp.Vendor(u"XDM Ltd.", "XDM", datetime.date(2010, 11, 22)),
    "MAD": pnp.Vendor(u"Xedia Corporation", "MAD", datetime.date(1996, 11, 29)),
    "XLX": pnp.Vendor(u"Xilinx, Inc.", "XLX", datetime.date(2007, 8, 1)),
    "XIN": pnp.Vendor(u"Xinex Networks Inc", "XIN", datetime.date(1997, 2, 7)),
    "XIO": pnp.Vendor(u"Xiotech Corporation", "XIO", datetime.date(1998, 5, 29)),
    "XRC": pnp.Vendor(u"Xircom Inc", "XRC", datetime.date(1996, 11, 29)),
    "XIT": pnp.Vendor(u"Xitel Pty ltd", "XIT", datetime.date(1996, 11, 29)),
    "XIR": pnp.Vendor(u"Xirocm Inc", "XIR", datetime.date(1996, 11, 29)),
    "XNT": pnp.Vendor(u"XN Technologies, Inc.", "XNT", datetime.date(2003, 7, 14)),
    "UHB": pnp.Vendor(u"XOCECO", "UHB", datetime.date(1998, 11, 27)),
    "XRO": pnp.Vendor(u"XORO ELECTRONICS (CHENGDU) LIMITED", "XRO", datetime.date(2005, 5, 23)),
    "XST": pnp.Vendor(u"XS Technologies Inc", "XST", datetime.date(1998, 1, 20)),
    "XSN": pnp.Vendor(u"Xscreen AS", "XSN", datetime.date(2006, 2, 14)),
    "XSY": pnp.Vendor(u"XSYS", "XSY", datetime.date(1998, 4, 23)),
    "YMH": pnp.Vendor(u"Yamaha Corporation", "YMH", datetime.date(1996, 11, 29)),
    "XYC": pnp.Vendor(u"Xycotec Computer GmbH", "XYC", datetime.date(2002, 9, 3)),
    "BUF": pnp.Vendor(u"Yasuhiko Shirai Melco Inc", "BUF", datetime.date(1996, 11, 29)),
    "YED": pnp.Vendor(u"Y-E Data Inc", "YED", datetime.date(1996, 11, 29)),
    "YHQ": pnp.Vendor(u"Yokogawa Electric Corporation", "YHQ", datetime.date(1996, 11, 29)),
    "TPZ": pnp.Vendor(u"Ypoaz Systems Inc", "TPZ", datetime.date(1996, 11, 29)),
    "ZMZ": pnp.Vendor(u"Z Microsystems", "ZMZ", datetime.date(2005, 8, 10)),
    "ZTT": pnp.Vendor(u"Z3 Technology", "ZTT", datetime.date(2010, 12, 14)),
    "ZMT": pnp.Vendor(u"Zalman Tech Co., Ltd.", "ZMT", datetime.date(2007, 5, 7)),
    "ZAN": pnp.Vendor(u"Zandar Technologies plc", "ZAN", datetime.date(2003, 12, 3)),
    "ZAZ": pnp.Vendor(u"Zazzle Technologies", "ZAZ", datetime.date(2008, 1, 18)),
    "ZBR": pnp.Vendor(u"Zebra Technologies International, LLC", "ZBR", datetime.date(2003, 9, 15)),
    "ZAX": pnp.Vendor(u"Zefiro Acoustics", "ZAX", datetime.date(1996, 11, 29)),
    "ZCT": pnp.Vendor(u"ZeitControl cardsystems GmbH", "ZCT", datetime.date(1999, 1, 20)),
    "ZEN": pnp.Vendor(u"ZENIC Inc.", "ZEN", datetime.date(2015, 4, 17)),
    "ZDS": pnp.Vendor(u"Zenith Data Systems", "ZDS", datetime.date(1996, 11, 29)),
    "ZGT": pnp.Vendor(u"Zenith Data Systems", "ZGT", datetime.date(1996, 11, 29)),
    "ZSE": pnp.Vendor(u"Zenith Data Systems", "ZSE", datetime.date(1996, 11, 29)),
    "ZNI": pnp.Vendor(u"Zetinet Inc", "ZNI", datetime.date(1996, 11, 29)),
    "TLE": pnp.Vendor(u"Zhejiang Tianle Digital Electric Co., Ltd.", "TLE", datetime.date(2014, 1, 17)),
    "RSR": pnp.Vendor(u"Zhong Shan City Richsound Electronic Industrial Ltd.", "RSR", datetime.date(2015, 1, 27)),
    "ZNX": pnp.Vendor(u"Znyx Adv. Systems", "ZNX", datetime.date(1996, 11, 29)),
    "ZTI": pnp.Vendor(u"Zoom Telephonics Inc", "ZTI", datetime.date(1996, 11, 29)),
    "ZRN": pnp.Vendor(u"Zoran Corporation", "ZRN", datetime.date(2005, 3, 31)),
    "ZOW": pnp.Vendor(u"Zowie Intertainment, Inc", "ZOW", datetime.date(1999, 2, 22)),
    "ZTM": pnp.Vendor(u"ZT Group Int'l Inc.", "ZTM", datetime.date(2007, 6, 14)),
    "ZTE": pnp.Vendor(u"ZTE Corporation", "ZTE", datetime.date(2010, 9, 3)),
    "SIX": pnp.Vendor(u"Zuniq Data Corporation", "SIX", datetime.date(1996, 11, 29)),
    "ZYD": pnp.Vendor(u"Zydacron Inc", "ZYD", datetime.date(1997, 4, 10)),
    "ZTC": pnp.Vendor(u"ZyDAS Technology Corporation", "ZTC", datetime.date(2000, 5, 24)),
    "ZYP": pnp.Vendor(u"Zypcom Inc", "ZYP", datetime.date(1997, 3, 19)),
    "ZYT": pnp.Vendor(u"Zytex Computers", "ZYT", datetime.date(1996, 11, 29)),
    "HPA": pnp.Vendor(u"Zytor Communications", "HPA", datetime.date(2010, 7, 2)),
    "AEJ": pnp.Vendor(u"Alpha Electronics Company", "AEJ", datetime.date(1996, 11, 29)),
    "BOE": pnp.Vendor(u"BOE", "BOE", datetime.date(2004, 12, 2)),
    "FIR": pnp.Vendor(u"Chaplet Systems Inc", "FIR", datetime.date(1996, 11, 29)),
    "CMG": pnp.Vendor(u"Chenming Mold Ind. Corp.", "CMG", datetime.date(2003, 11, 14)),
    "COO": pnp.Vendor(u"coolux GmbH", "COO", datetime.date(2010, 9, 30)),
    "DGC": pnp.Vendor(u"Data General Corporation", "DGC", datetime.date(1996, 11, 29)),
    "EXA": pnp.Vendor(u"Exabyte", "EXA", datetime.date(1996, 11, 29)),
    "HRL": pnp.Vendor(u"Herolab GmbH", "HRL", datetime.date(1998, 3, 17)),
    "HCP": pnp.Vendor(u"Hitachi Computer Products Inc", "HCP", datetime.date(1996, 11, 29)),
    "ICS": pnp.Vendor(u"Integrated Circuit Systems", "ICS", datetime.date(1996, 11, 29)),
    "IRD": pnp.Vendor(u"Irdata", "IRD", datetime.date(2001, 4, 24)),
    "JWL": pnp.Vendor(u"Jewell Instruments, LLC", "JWL", datetime.date(2001, 6, 21)),
    "MQP": pnp.Vendor(u"MultiQ Products AB", "MQP", datetime.date(1999, 3, 20)),
    "NAC": pnp.Vendor(u"Ncast Corporation", "NAC", datetime.date(2006, 2, 14)),
    "ODM": pnp.Vendor(u"ODME Inc.", "ODM", datetime.date(1998, 9, 23)),
    "PMX": pnp.Vendor(u"Photomatrix", "PMX", datetime.date(1996, 11, 29)),
    "QSI": pnp.Vendor(u"Quantum Solutions, Inc.", "QSI", datetime.date(2000, 1, 13)),
    "RHT": pnp.Vendor(u"Red Hat, Inc.", "RHT", datetime.date(2011, 2, 17)),
    "ZYX": pnp.Vendor(u"Zyxel", "ZYX", datetime.date(1996, 11, 29)),
    "JAZ": pnp.Vendor(u"Carrera Computer Inc", "JAZ", datetime.date(1994, 1, 1)),
    "CGA": pnp.Vendor(u"Chunghwa Picture Tubes, LTD", "CGA", datetime.date(1994, 1, 1)),
    "EMC": pnp.Vendor(u"eMicro Corporation", "EMC", datetime.date(1994, 1, 1)),
    "HEC": pnp.Vendor(u"Hisense Electric Co., Ltd.", "HEC", datetime.date(1994, 1, 1)),
    "PNS": pnp.Vendor(u"PanaScope", "PNS", datetime.date(1994, 1, 1)),
    "SPC": pnp.Vendor(u"SpinCore Technologies, Inc", "SPC", datetime.date(1994, 1, 1)),
    "SVR": pnp.Vendor(u"Sensics, Inc.", "SVR", datetime.date(2015, 8, 27)),
    "IAD": pnp.Vendor(u"IAdea Corporation", "IAD", datetime.date(2015, 9, 10)),
    "ELU": pnp.Vendor(u"Express Industrial, Ltd.", "ELU", datetime.date(2015, 9, 10)),
    "HPE": pnp.Vendor(u"Hewlett Packard Enterprise", "HPE", datetime.date(2015, 9, 22)),
    "KGI": pnp.Vendor(u"Klipsch Group, Inc", "KGI", datetime.date(2015, 9, 22)),
    "TKG": pnp.Vendor(u"Tek Gear", "TKG", datetime.date(2015, 10, 16)),
    "ZMC": pnp.Vendor(u"HangZhou ZMCHIVIN", "ZMC", datetime.date(2015, 10, 16)),
    "HVR": pnp.Vendor(u"HTC Corportation", "HVR", datetime.date(2015, 10, 16)),
    "ZBX": pnp.Vendor(u"Zebax Technologies", "ZBX", datetime.date(2015, 10, 16)),
    "SWO": pnp.Vendor(u"Guangzhou Shirui Electronics Co., Ltd.", "SWO", datetime.date(2015, 10, 16)),
    "PIC": pnp.Vendor(u"Picturall Ltd.", "PIC", datetime.date(2015, 11, 13)),
    "SKM": pnp.Vendor(u"Guangzhou Teclast Information Technology Limited", "SKM", datetime.date(2015, 11, 18)),
    "GAC": pnp.Vendor(u"GreenArrays, Inc.", "GAC", datetime.date(2015, 11, 18)),
    "TAV": pnp.Vendor(u"Thales Avionics", "TAV", datetime.date(2015, 11, 18)),
    "EXR": pnp.Vendor(u"Explorer Inc.", "EXR", datetime.date(2015, 11, 18)),
    "AVG": pnp.Vendor(u"Avegant Corporation", "AVG", datetime.date(2015, 12, 2)),
    "MIV": pnp.Vendor(u"MicroImage Video Systems", "MIV", datetime.date(2015, 12, 8)),
    "AUS": pnp.Vendor(u"ASUSTek COMPUTER INC", "AUS", datetime.date(2015, 12, 21)),
    "STQ": pnp.Vendor(u"Synthetel Corporation", "STQ", datetime.date(2015, 12, 21)),
    "HPN": pnp.Vendor(u"HP Inc.", "HPN", datetime.date(2015, 12, 21)),
    "MTJ": pnp.Vendor(u"MicroTechnica Co.,Ltd.", "MTJ", datetime.date(2016, 1, 4)),
    "GEC": pnp.Vendor(u"Gechic Corporation", "GEC", datetime.date(2016, 1, 4)),
    "MEU": pnp.Vendor(u"MPL AG, Elektronik-Unternehmen", "MEU", datetime.date(2016, 1, 15)),
    "DSA": pnp.Vendor(u"Display Solution AG", "DSA", datetime.date(2016, 2, 3)),
    "PRP": pnp.Vendor(u"UEFI Forum", "PRP", datetime.date(2016, 2, 3)),
    "TTX": pnp.Vendor(u"Taitex Corporation", "TTX", datetime.date(2016, 2, 3)),
    "ECH": pnp.Vendor(u"EchoStar Corporation", "ECH", datetime.date(2016, 2, 26)),
    "TOL": pnp.Vendor(u"TCL Corporation", "TOL", datetime.date(2016, 3, 30)),
    "ADZ": pnp.Vendor(u"ADDER TECHNOLOGY LTD", "ADZ", datetime.date(2016, 3, 30)),
    "HKC": pnp.Vendor(u"HKC OVERSEAS LIMITED", "HKC", datetime.date(2016, 3, 30)),
    "KYN": pnp.Vendor(u"KEYENCE CORPORATION", "KYN", datetime.date(2016, 3, 30)),
    "TET": pnp.Vendor(u"TETRADYNE CO., LTD.", "TET", datetime.date(2016, 4, 27)),
    "ABS": pnp.Vendor(u"Abaco Systems, Inc.", "ABS", datetime.date(2016, 4, 27)),
    "MVN": pnp.Vendor(u"Meta Company", "MVN", datetime.date(2016, 5, 25)),
    "ERS": pnp.Vendor(u"Eizo Rugged Solutions", "ERS", datetime.date(2016, 5, 25)),
    "VLC": pnp.Vendor(u"VersaLogic Corporation", "VLC", datetime.date(2016, 5, 25)),
    "CYP": pnp.Vendor(u"CYPRESS SEMICONDUCTOR CORPORATION", "CYP", datetime.date(2016, 5, 25)),
    "MDF": pnp.Vendor(u"MILDEF AB", "MDF", datetime.date(2016, 6, 23)),
    "FOV": pnp.Vendor(u"FOVE INC", "FOV", datetime.date(2016, 7, 1)),
    "NES": pnp.Vendor(u"INNES", "NES", datetime.date(2016, 7, 1)),
    "HUK": pnp.Vendor(u"Hoffmann + Krippner GmbH", "HUK", datetime.date(2016, 7, 1)),
    "AXE": pnp.Vendor(u"Axell Corporation", "AXE", datetime.date(2016, 8, 3)),
    "UMT": pnp.Vendor(u"UltiMachine", "UMT", datetime.date(2016, 8, 11)),
    "KPT": pnp.Vendor(u"TPK Holding Co., Ltd", "KPT", datetime.date(2016, 8, 16)),
    "AAN": pnp.Vendor(u"AAEON Technology Inc.", "AAN", datetime.date(2016, 9, 1)),
    "TDG": pnp.Vendor(u"Six15 Technologies", "TDG", datetime.date(2016, 9, 14)),
}
